@@ -422,7 +422,7 @@ void NedBeam::draw(cairo_t *cr) {
 			chord1->getLength() / NOTE_32, chord2->getLength() / NOTE_32); fflush(stdout);
 			*/
 
-		draw_half = (lptr0 == NULL || chord0->getLength() != chord1->getLength());
+		draw_half = (lptr0 == NULL || (chord0->getLength() != chord1->getLength() && !((chord0->getDotCount() == 1 && chord0->getLength() == (chord1->getLength() << 1)))));
 		//if (lptr0 == NULL || chord0->getLength() != chord1->getLength() || chord1->getLength() >= chord2->getLength()) {
 		  switch (chord1->getLength()) {
 		    case NOTE_64:
@@ -440,7 +440,7 @@ void NedBeam::draw(cairo_t *cr) {
 			}
 		  }
 		//}
-		draw_half = (lptr2 == last);
+		draw_half = (lptr2 == last || (chord1->getDotCount() == 1 && chord1->getLength() == (chord2->getLength() << 1)));
 		//if (lptr2 == last || chord2->getLength() >= chord1->getLength()) {
 		   switch (chord2->getLength()) {
 		     case NOTE_64:
@@ -513,12 +513,13 @@ void NedBeam::drawPostscript(cairo_t *cr) {
 	double topy = getMainWindow()->getTopY();
 	double zoom_factor = getMainWindow()->getCurrentZoomFactor();
 	double leftx = getMainWindow()->getLeftX();
-	GList *lptr1, *lptr2, *last;
-	NedChordOrRest *chord1, *chord2, *lastchord;
+	GList *lptr1, *lptr2, *lptr0 = NULL, *last;
+	NedChordOrRest *chord0 = NULL, *chord1, *chord2, *lastchord;
 	double xpos1, xpos2, ypos1, ypos2;
 	double mid_xpos, mid_ypos;
 	double lastxpos, lastypos;
 	int tval;
+	bool draw_half;
 	cairo_glyph_t glyph;
 	double h_2 = BEAM_THICK / 2.0;
 
@@ -542,12 +543,13 @@ void NedBeam::drawPostscript(cairo_t *cr) {
 	cairo_line_to(cr, X_POS_PAGE_REL(xpos1), Y_POS_STAFF_REL(ypos1 + h_2));
 	cairo_close_path(cr);
 	cairo_fill(cr);
-	for (lptr2 = g_list_next(lptr1); lptr2; lptr1 = lptr2, lptr2 = g_list_next(lptr2), chord1 = chord2, xpos1 = xpos2, ypos1 = ypos2) {
+	for (lptr2 = g_list_next(lptr1); lptr2; lptr0 = lptr1, lptr1 = lptr2, lptr2 = g_list_next(lptr2), chord0 = chord1, chord1 = chord2, xpos1 = xpos2, ypos1 = ypos2) {
 		chord2 = (NedChordOrRest *) lptr2->data;
 		xpos2 = m_up ? chord2->getBeamXPos() : chord2->getBeamXPos();
 		ypos2 = m_start_y - (xpos2 - m_start_x) * m_slope;
 		mid_xpos = xpos1 + (xpos2 - xpos1) / 2.0;
 		mid_ypos = ypos1 + (ypos2 - ypos1) / 2.0;
+		draw_half = (lptr0 == NULL || (chord0->getLength() != chord1->getLength() && !((chord0->getDotCount() == 1 && chord0->getLength() == (chord1->getLength() << 1)))));
 		switch (chord1->getLength()) {
 		  case NOTE_64:
 			cairo_new_path(cr);
@@ -558,49 +560,60 @@ void NedBeam::drawPostscript(cairo_t *cr) {
 			cairo_close_path(cr);
 			cairo_fill(cr);
 		  case NOTE_32:
-			cairo_new_path(cr);
-			cairo_move_to(cr, X_POS_PAGE_REL(xpos1), Y_POS_STAFF_REL(ypos1 + 2 * dir * FLAG_DIST - h_2));
-			cairo_line_to(cr, X_POS_PAGE_REL(mid_xpos), Y_POS_STAFF_REL(mid_ypos + 2 * dir * FLAG_DIST - h_2));
-			cairo_line_to(cr, X_POS_PAGE_REL(mid_xpos), Y_POS_STAFF_REL(mid_ypos + 2 * dir * FLAG_DIST + h_2));
-			cairo_line_to(cr, X_POS_PAGE_REL(xpos1), Y_POS_STAFF_REL(ypos1 + 2 * dir * FLAG_DIST + h_2));
-			cairo_close_path(cr);
-			cairo_fill(cr);
+			if (draw_half || chord2->getLength() <= NOTE_32) {
+				cairo_new_path(cr);
+				cairo_move_to(cr, X_POS_PAGE_REL(xpos1), Y_POS_STAFF_REL(ypos1 + 2 * dir * FLAG_DIST - h_2));
+				cairo_line_to(cr, X_POS_PAGE_REL(mid_xpos), Y_POS_STAFF_REL(mid_ypos + 2 * dir * FLAG_DIST - h_2));
+				cairo_line_to(cr, X_POS_PAGE_REL(mid_xpos), Y_POS_STAFF_REL(mid_ypos + 2 * dir * FLAG_DIST + h_2));
+				cairo_line_to(cr, X_POS_PAGE_REL(xpos1), Y_POS_STAFF_REL(ypos1 + 2 * dir * FLAG_DIST + h_2));
+				cairo_close_path(cr);
+				cairo_fill(cr);
+			}
 		  case NOTE_16:
-			cairo_new_path(cr);
-			cairo_move_to(cr, X_POS_PAGE_REL(xpos1), Y_POS_STAFF_REL(ypos1 + dir * FLAG_DIST - h_2));
-			cairo_line_to(cr, X_POS_PAGE_REL(mid_xpos), Y_POS_STAFF_REL(mid_ypos + dir * FLAG_DIST - h_2));
-			cairo_line_to(cr, X_POS_PAGE_REL(mid_xpos), Y_POS_STAFF_REL(mid_ypos + dir * FLAG_DIST + h_2));
-			cairo_line_to(cr, X_POS_PAGE_REL(xpos1), Y_POS_STAFF_REL(ypos1 + dir * FLAG_DIST + h_2));
-			cairo_close_path(cr);
-			cairo_fill(cr);
+			if (draw_half || chord2->getLength() <= NOTE_16) {
+				cairo_new_path(cr);
+				cairo_move_to(cr, X_POS_PAGE_REL(xpos1), Y_POS_STAFF_REL(ypos1 + dir * FLAG_DIST - h_2));
+				cairo_line_to(cr, X_POS_PAGE_REL(mid_xpos), Y_POS_STAFF_REL(mid_ypos + dir * FLAG_DIST - h_2));
+				cairo_line_to(cr, X_POS_PAGE_REL(mid_xpos), Y_POS_STAFF_REL(mid_ypos + dir * FLAG_DIST + h_2));
+				cairo_line_to(cr, X_POS_PAGE_REL(xpos1), Y_POS_STAFF_REL(ypos1 + dir * FLAG_DIST + h_2));
+				cairo_close_path(cr);
+				cairo_fill(cr);
+			}
 		}
-		if (lptr2 == last || chord2->getLength() >= chord1->getLength()) {
+		draw_half = (lptr2 == last || (chord1->getDotCount() == 1 && chord1->getLength() == (chord2->getLength() << 1)));
+		//if (lptr2 == last || chord2->getLength() >= chord1->getLength()) {
 		   switch (chord2->getLength()) {
 		     case NOTE_64:
-			cairo_new_path(cr);
-			cairo_move_to(cr, X_POS_PAGE_REL(mid_xpos), Y_POS_STAFF_REL(mid_ypos + 3 * dir * FLAG_DIST - h_2));
-			cairo_line_to(cr, X_POS_PAGE_REL(xpos2), Y_POS_STAFF_REL(ypos2 + 3 * dir * FLAG_DIST - h_2));
-			cairo_line_to(cr, X_POS_PAGE_REL(xpos2), Y_POS_STAFF_REL(ypos2 + 3 * dir * FLAG_DIST + h_2));
-			cairo_line_to(cr, X_POS_PAGE_REL(mid_xpos), Y_POS_STAFF_REL(mid_ypos + 3 * dir * FLAG_DIST + h_2));
-			cairo_close_path(cr);
-			cairo_fill(cr);
+			if (draw_half || chord1->getLength() <= NOTE_64) {
+				cairo_new_path(cr);
+				cairo_move_to(cr, X_POS_PAGE_REL(mid_xpos), Y_POS_STAFF_REL(mid_ypos + 3 * dir * FLAG_DIST - h_2));
+				cairo_line_to(cr, X_POS_PAGE_REL(xpos2), Y_POS_STAFF_REL(ypos2 + 3 * dir * FLAG_DIST - h_2));
+				cairo_line_to(cr, X_POS_PAGE_REL(xpos2), Y_POS_STAFF_REL(ypos2 + 3 * dir * FLAG_DIST + h_2));
+				cairo_line_to(cr, X_POS_PAGE_REL(mid_xpos), Y_POS_STAFF_REL(mid_ypos + 3 * dir * FLAG_DIST + h_2));
+				cairo_close_path(cr);
+				cairo_fill(cr);
+			}
 		     case NOTE_32:
-			cairo_new_path(cr);
-			cairo_move_to(cr, X_POS_PAGE_REL(mid_xpos), Y_POS_STAFF_REL(mid_ypos + 2 * dir * FLAG_DIST - h_2));
-			cairo_line_to(cr, X_POS_PAGE_REL(xpos2), Y_POS_STAFF_REL(ypos2 + 2 * dir * FLAG_DIST - h_2));
-			cairo_line_to(cr, X_POS_PAGE_REL(xpos2), Y_POS_STAFF_REL(ypos2 + 2 * dir * FLAG_DIST + h_2));
-			cairo_line_to(cr, X_POS_PAGE_REL(mid_xpos), Y_POS_STAFF_REL(mid_ypos + 2 * dir * FLAG_DIST + h_2));
-			cairo_close_path(cr);
-			cairo_fill(cr);
+			if (draw_half || chord1->getLength() <= NOTE_32) {
+				cairo_new_path(cr);
+				cairo_move_to(cr, X_POS_PAGE_REL(mid_xpos), Y_POS_STAFF_REL(mid_ypos + 2 * dir * FLAG_DIST - h_2));
+				cairo_line_to(cr, X_POS_PAGE_REL(xpos2), Y_POS_STAFF_REL(ypos2 + 2 * dir * FLAG_DIST - h_2));
+				cairo_line_to(cr, X_POS_PAGE_REL(xpos2), Y_POS_STAFF_REL(ypos2 + 2 * dir * FLAG_DIST + h_2));
+				cairo_line_to(cr, X_POS_PAGE_REL(mid_xpos), Y_POS_STAFF_REL(mid_ypos + 2 * dir * FLAG_DIST + h_2));
+				cairo_close_path(cr);
+				cairo_fill(cr);
+			}
 		     case NOTE_16:
-			cairo_new_path(cr);
-			cairo_move_to(cr, X_POS_PAGE_REL(mid_xpos), Y_POS_STAFF_REL(mid_ypos + dir * FLAG_DIST - h_2));
-			cairo_line_to(cr, X_POS_PAGE_REL(xpos2), Y_POS_STAFF_REL(ypos2 + dir * FLAG_DIST - h_2));
-			cairo_line_to(cr, X_POS_PAGE_REL(xpos2), Y_POS_STAFF_REL(ypos2 + dir * FLAG_DIST + h_2));
-			cairo_line_to(cr, X_POS_PAGE_REL(mid_xpos), Y_POS_STAFF_REL(mid_ypos + dir * FLAG_DIST + h_2));
-			cairo_close_path(cr);
-			cairo_fill(cr);
-		   }
+			if (draw_half || chord1->getLength() <= NOTE_16) {
+				cairo_new_path(cr);
+				cairo_move_to(cr, X_POS_PAGE_REL(mid_xpos), Y_POS_STAFF_REL(mid_ypos + dir * FLAG_DIST - h_2));
+				cairo_line_to(cr, X_POS_PAGE_REL(xpos2), Y_POS_STAFF_REL(ypos2 + dir * FLAG_DIST - h_2));
+				cairo_line_to(cr, X_POS_PAGE_REL(xpos2), Y_POS_STAFF_REL(ypos2 + dir * FLAG_DIST + h_2));
+				cairo_line_to(cr, X_POS_PAGE_REL(mid_xpos), Y_POS_STAFF_REL(mid_ypos + dir * FLAG_DIST + h_2));
+				cairo_close_path(cr);
+				cairo_fill(cr);
+			}
+		   //}
 		}
 	}
 	cairo_stroke(cr);
