@@ -117,7 +117,7 @@ class NedChordOrRest {
 		void flipStem(NedCommandList *command_list);
 		void print();
 		void draw(cairo_t *cr, bool *freetexts_or_lyrics_present);
-		void drawTexts(cairo_t *cr, double scale, double last_left_bbox_edge);
+		void drawTexts(cairo_t *cr, double scale, double last_left_bbox_edge, bool last);
 		double getRealXpos() {return m_xpos;}
 		double getXPos() {/* if (m_tmp_xpos < 0.0) */return m_xpos; /* return m_tmp_xpos; */}
 		double getLeftBboxEdge() {return m_xpos + m_bbox.x;}
@@ -210,7 +210,7 @@ class NedChordOrRest {
 		void tieAllNotes(NedChordOrRest *other_chord);
 		static void handleOpenTies(NedCommandList *command_list, GList *pool);
 		bool isTied();
-		void tieCompleteTo(NedChordOrRest *other_chord);
+		void tieCompleteTo(NedChordOrRest *other_chord, bool check_pitch);
 		int getDotCount() {return m_dot_count;}
 		void setDotCount(int dot_count) {m_dot_count = dot_count;}
 		NedBbox *getBBox() {return &m_bbox;}
