@@ -33,8 +33,9 @@ const char *NedChordPainter::modies[] = {"Major", "Minor", "dim", "aug", "sus",
 					"11", "7sus4", "13", "6add9", "-5", "7-5", "7maj5", "maj9", NULL};
 const char *NedChordPainter::modies2[] = {"", "m", "dim", "aug", "sus", "6", "7", "maj7", "9", "add9", "m6", "m7", "mmaj7", "m9", 
 					"11", "7sus4", "13", "6add9", "-5", "7-5", "7maj5", "maj9", NULL};
-const unsigned int NedChordPainter::lower[] = {0, 1, 0, 0, 0, 0, 0, 0, 0, 0, 1, 1, 1, 1, 
+const unsigned int NedChordPainter::minor[] = {0, 1, 0, 0, 0, 0, 0, 0, 0, 0, 1, 1, 1, 1, 
 					0, 0, 0, 0, 0, 0, 0, 0, 0};
+const char NedChordPainter::addoff[] = {0, 1, -1, 0, 1, -1, 0, 0, 1, -1, 0, 1, -1, 0, 1, -1, 0};
 const char *NedChordPainter::modies3[] = {"", "", "dim", "aug", "sus", "6", "7", "maj7", "9", "add9", "6", "7", "maj7", "9", 
 					"11", "7sus4", "13", "6add9", "-5", "7-5", "7maj5", "maj9", NULL};
 const char *NedChordPainter::modies4[] = {"", "m", "dim", "aug", "sus4", "6", "7", "maj7", "9", "", "m6", "m7", "", "m9", 
@@ -215,7 +216,7 @@ void NedChordPainter::draw_chord(cairo_t *cr, struct chord_str *chord_descr, cha
 	int mod_idx;
 	char rname[128];
 	unsigned int block_for_barre = 0;
-	double arc_y;
+	double arc_y, xdist;
 	bool restore_font = false;
 	int fret_count = limit_fret ? chord_descr->numfrets : F_COUNT;
 	const char *root_name, *mody_name;
@@ -339,23 +340,47 @@ void NedChordPainter::draw_chord(cairo_t *cr, struct chord_str *chord_descr, cha
 			mod_idx = ((status >> ROOT_BITS) & ((1 << MODI_BITS) - 1));
 			mody_name = NedChordPainter::modies3[mod_idx];
 			strcpy(rname, root_name);
-			if (lower[mod_idx]) {
-				rname[0] = tolower(rname[0]);
-			}
+			xdist = 0.0;
 			if (rname[1] != '\0') {
 				rname[1] = '\0';
 			}
+			if (minor[mod_idx]) {
+				if (addoff[(status & ROOT_MASK)]) {
+					rname[1] = ' ';
+					rname[2] = 'm';
+					rname[3] = '\0';
+				}
+				else {
+					rname[1] = 'm';
+					rname[2] = '\0';
+#define MINOR_X_DIST 60.0
+				}
+				xdist = MINOR_X_DIST;
+			}
 			cairo_show_text(cr, rname);
-			cairo_move_to(cr, TEXT_X_NAME_START + /* strlen(root_name) * */ CHORD_MODYFIER_X_DIST * zoom, TEXT_Y_NAME_START - CHORD_MODYFIER_Y_DIST * zoom);
-			cairo_set_font_size(cr, CHORD_NAME_SIZE2_M * zoom);
-			cairo_show_text(cr, mody_name);
+#define IDX_X_OFFS 10.0
+			cairo_select_font_face(cr, "Sans", CAIRO_FONT_SLANT_ITALIC, CAIRO_FONT_WEIGHT_BOLD);
+			cairo_set_font_size(cr, CHORD_NAME_SIZE3_R * zoom);
+			cairo_move_to(cr, TEXT_X_NAME_START + CHORD_HALF_TONE_X_DIST * zoom, TEXT_Y_NAME_START + CHORD_HALF_TONE_Y_DIST * zoom);
+			switch (addoff[(status & ROOT_MASK)]) {
+				case 1: cairo_show_text(cr, "#"); break;
+				case -1: cairo_show_text(cr, "b"); break;
+			}
+			/*
 			if (root_name[1] != '\0') {
 				rname[0] = root_name[1];
 				cairo_select_font_face(cr, "Sans", CAIRO_FONT_SLANT_ITALIC, CAIRO_FONT_WEIGHT_BOLD);
 				cairo_set_font_size(cr, (rname[0] == 'b' ? CHORD_NAME_SIZE3_R : CHORD_NAME_SIZE4_R) * zoom);
-				cairo_move_to(cr, TEXT_X_NAME_START + CHORD_HALF_TONE_X_DIST * zoom, TEXT_Y_NAME_START + CHORD_HALF_TONE_Y_DIST * zoom);
+				cairo_move_to(cr, TEXT_X_NAME_START + (CHORD_HALF_TONE_X_DIST + xdist) * zoom, TEXT_Y_NAME_START + CHORD_HALF_TONE_Y_DIST * zoom);
 				cairo_show_text(cr, rname);
 			}
+			*/
+			if (addoff[(status & ROOT_MASK)]) {
+				xdist += IDX_X_OFFS;
+			}
+			cairo_move_to(cr, TEXT_X_NAME_START + (CHORD_MODYFIER_X_DIST + xdist) * zoom, TEXT_Y_NAME_START - CHORD_MODYFIER_Y_DIST * zoom);
+			cairo_set_font_size(cr, CHORD_NAME_SIZE2_M * zoom);
+			cairo_show_text(cr, mody_name);
 			cairo_stroke(cr);
 		}
 		restore_font = true;
