@@ -63,6 +63,10 @@ void NedClipBoard::execute(bool adjust) {
 		if (element->from_voice == NULL) {
 			element->from_staff->deleteStaffElements(false, element->chords_or_rests_to_move, m_reftime, m_duration);
 			if (!m_delete_only) {
+				if (element->to_staff == NULL) {
+					printf("element = 0x%x\n", element); fflush(stdout);
+					NedResource::Abort("element->to_staff == NULL");
+				}
 				element->to_staff->insertIntoStaff(element->chords_or_rests_to_move, m_duration);
 				if (g_list_length(element->chords_or_rests_to_move) > 0) {
 					element->from_staff->getMainWindow()->setAndUpdateClefTypeAndKeySig();
