@@ -24,8 +24,16 @@
 #include "resource.h"
 
 
-NedChangeTimeSigCommand::NedChangeTimeSigCommand(NedMainWindow *main_window, int newnum, int newdenom) :
-m_main_window(main_window), m_new_num(newnum), m_new_denom(newdenom) {}
+NedChangeTimeSigCommand::NedChangeTimeSigCommand(NedMainWindow *main_window, int newnum, int newdenom, unsigned int newsymbol) :
+m_main_window(main_window), m_new_num(newnum), m_new_denom(newdenom), m_new_symbol(newsymbol) {
+	unsigned int duration = m_main_window->m_numerator * WHOLE_NOTE / m_main_window->m_denominator;
+	if (duration == m_new_num * WHOLE_NOTE / m_new_denom) {
+		m_new_upbeat_inverse = m_main_window->m_upbeat_inverse;
+	}
+	else {
+		m_new_upbeat_inverse = 0;
+	}
+}
 
 
 void NedChangeTimeSigCommand::execute(bool adjust /* = false */) {
@@ -34,10 +42,12 @@ void NedChangeTimeSigCommand::execute(bool adjust /* = false */) {
 #endif
 	m_old_num = m_main_window->m_numerator;
 	m_old_denom = m_main_window->m_denominator;
+	m_old_symbol = m_main_window->m_timesig_symbol;
 	m_old_upbeat_inverse = m_main_window->m_upbeat_inverse; // friend !!
 	m_main_window->m_numerator = m_new_num; // friend !!
 	m_main_window->m_denominator = m_new_denom; // friend !!
-	m_main_window->m_upbeat_inverse = 0; // friend !!
+	m_main_window->m_timesig_symbol = m_new_symbol; // friend !!
+	m_main_window->m_upbeat_inverse = m_new_upbeat_inverse; // friend !!
 }
 
 
@@ -47,5 +57,6 @@ void NedChangeTimeSigCommand::unexecute(bool adjust /* = false */) {
 #endif
 	m_main_window->m_numerator = m_old_num; // friend !!
 	m_main_window->m_denominator = m_old_denom; // friend !!
+	m_main_window->m_timesig_symbol = m_old_symbol; // friend !!
 	m_main_window->m_upbeat_inverse = m_old_upbeat_inverse; // friend !!
 }
