@@ -30,14 +30,15 @@ class NedMainWindow;
 
 class NedChangeTimeSigCommand : public NedCommand {
 	public:	
-		NedChangeTimeSigCommand(NedMainWindow *main_window, int newnum, int newdenom);
+		NedChangeTimeSigCommand(NedMainWindow *main_window, int newnum, int newdenom, unsigned int newsymbol);
 		virtual void execute(bool adjust = false);
 		virtual void unexecute(bool adjust = false);
 	private:
 		NedMainWindow *m_main_window;
 		int m_new_num, m_new_denom;
 		int m_old_num, m_old_denom;
-		int m_old_upbeat_inverse;
+		unsigned int m_old_symbol, m_new_symbol;
+		int m_new_upbeat_inverse, m_old_upbeat_inverse;
 		
 		
 };
