@@ -25,8 +25,8 @@
 #include "resource.h"
 #include "mainwindow.h"
 
-NedRemoveStaffElemCommand::NedRemoveStaffElemCommand(NedMainWindow *main_window, NedChordOrRest *staffelem, bool do_adjust) :
-m_staff_elem(staffelem), m_main_window(main_window), m_do_adjust(do_adjust) {
+NedRemoveStaffElemCommand::NedRemoveStaffElemCommand(NedMainWindow *main_window, int staff_nr, NedChordOrRest *staffelem, bool do_adjust) :
+m_staff_nr(staff_nr), m_staff_elem(staffelem), m_main_window(main_window), m_do_adjust(do_adjust) {
 	m_staff = staffelem->getStaff();
 }
 
@@ -40,7 +40,7 @@ void NedRemoveStaffElemCommand::execute(bool adjust /* = false */) {
 	}
 	m_staff->removeStaffElement(m_staff_elem);
 	if (m_do_adjust && (m_staff_elem->getType() & (TYPE_KEYSIG | TYPE_CLEF)) != 0) {
-		m_main_window->adjustAccidentals();
+		m_main_window->adjustAccidentals(m_staff_nr);
 	}
 }
 
@@ -54,6 +54,6 @@ void NedRemoveStaffElemCommand::unexecute(bool adjust /* = false */) {
 	}
 	m_staff->insertStaffElement(m_staff_elem);
 	if (m_do_adjust && (m_staff_elem->getType() & (TYPE_KEYSIG | TYPE_CLEF)) != 0) {
-		m_main_window->adjustAccidentals();
+		m_main_window->adjustAccidentals(m_staff_nr);
 	}
 }
