@@ -32,10 +32,11 @@ class NedStaff;
 
 class NedRemoveStaffElemCommand : public NedCommand {
 	public:	
-		NedRemoveStaffElemCommand(NedMainWindow *main_window, NedChordOrRest *staffelem, bool do_adjust);
+		NedRemoveStaffElemCommand(NedMainWindow *main_window, int staff_nr, NedChordOrRest *staffelem, bool do_adjust);
 		virtual void execute(bool adjust = false);
 		virtual void unexecute(bool adjust = false);
 	private:
+		int m_staff_nr;
 		NedStaff *m_staff;
 		NedChordOrRest *m_staff_elem;
 		NedMainWindow *m_main_window;
