@@ -141,12 +141,11 @@ void NedCrescendo::draw(cairo_t *cr, double leftx, double topy, double zoom_fact
 }
 
 void NedCrescendo::startContextDialog(GtkWidget *ref) {
-	int newvol;
+	int newvoldiff;
 	bool state;
-	unsigned int startvol = getLineStartPoint()->getElement()->determineVolume();
-	NedVolumeDialog *voldialog = new NedVolumeDialog(GTK_WINDOW(ref), startvol + m_volume_diff);
-	voldialog->getValues(&state, &newvol);
+	NedVolumeDialog *voldialog = new NedVolumeDialog(GTK_WINDOW(ref), m_volume_diff, true);
+	voldialog->getValues(&state, &newvoldiff);
 	if (state) {
-		m_volume_diff = newvol - startvol;
+		m_volume_diff = newvoldiff;
 	}
 }
