@@ -29,7 +29,8 @@ double NedChordNameDialog::m_font_size = 0.4;
 bool NedChordNameDialog::m_chord_name_dialog_active = false;
 double NedChordNameDialog::m_chord_name_y_dist = 0.4;
 
-NedChordNameDialog::NedChordNameDialog(NedMainWindow *main_window, GtkWindow *parent, char *roottext, char *uptext, char *downtext, double fontsize, double ydist) :
+NedChordNameDialog::NedChordNameDialog(NedMainWindow *main_window, GtkWindow *parent, char *roottext, char *uptext, char *downtext, double fontsize,
+		 double ydist, bool ydist_relenvant) :
 m_main_window(main_window) {
 	if (fontsize > 0.0) {
 		m_font_size = fontsize;
@@ -83,7 +84,7 @@ m_main_window(main_window) {
 	ydist_frame = gtk_frame_new(_("position"));
 	m_ydist_spin_box = gtk_spin_button_new_with_range (0.01, 2.0, 0.05);
         gtk_spin_button_set_value(GTK_SPIN_BUTTON(m_ydist_spin_box), m_chord_name_y_dist);
-	if (ydist < -1.5) {
+	if (!ydist_relenvant) {
 		gtk_widget_set_sensitive(m_ydist_spin_box, FALSE);
 	}
 
