@@ -29,7 +29,8 @@
 
 class NedChordNameDialog {
 	public:
-		NedChordNameDialog(NedMainWindow *main_window, GtkWindow *parent, char *roottext, char *uptext, char *downtext, double fontsize, double ydist);
+		NedChordNameDialog(NedMainWindow *main_window, GtkWindow *parent, char *roottext, char *uptext, char *downtext,
+			 double fontsize, double ydist, bool ydist_relenvant);
 		~NedChordNameDialog();
 		void getValues(bool *state, char **roottext, char **uptext, char **downtext, double *fontsize, double *ydist);
 		static bool isAlreadyActive() {return m_chord_name_dialog_active;}
