@@ -128,7 +128,7 @@ void NedClefConfigDialog::getValues(bool *state, int *clef_number, int *octave_s
 }
 
 gboolean NedClefConfigDialog::draw_clefs(GtkWidget *widget, GdkEventExpose *event, gpointer data) {
-#define ZOOM_LEVEL 8
+#define ZOOM_LEVEL 9
 	NedClefConfigDialog *the_dialog = (NedClefConfigDialog *) data;
 	cairo_scaled_font_t *scaled_font;
 	cairo_glyph_t glyph;
@@ -204,8 +204,8 @@ gboolean NedClefConfigDialog::draw_clefs(GtkWidget *widget, GdkEventExpose *even
 				  }
 				glyph.index = BASE + 1; y_offs = -DEMO_LINE_DIST; break;
 		case NEUTRAL_CLEF1: 
-				glyph.index = BASE + 27; break;
 		case NEUTRAL_CLEF2: 
+		case NEUTRAL_CLEF3: 
 				glyph.index = BASE + 27; break;
 	}
 	glyph.x = 50.0;
@@ -222,6 +222,11 @@ gboolean NedClefConfigDialog::draw_clefs(GtkWidget *widget, GdkEventExpose *even
 					glyph.y = 120.0;
 					cairo_show_glyphs(cr, &glyph, 1);
 					break;
+		case NEUTRAL_CLEF3: glyph.index = NUMBERBASE + 3; 
+					glyph.x = 60.0;
+					glyph.y = 120.0;
+					cairo_show_glyphs(cr, &glyph, 1);
+					break;
 	}
 	if (octave_shift) {
 		glyph.x = 50.0 + oct_x_offs;
