@@ -32,7 +32,7 @@
 #define MAX_LINE_LENGTH 80
 
 NedLyricsEditor::NedLyricsEditor(GtkWindow *parent, NedMainWindow *main_window, int staff_nr):
- m_main_window(main_window), m_last_folder(NULL), m_current_verse(0), m_state(false) {
+ m_main_window(main_window), m_last_folder(NULL), m_current_verse(0), m_staff_nr(staff_nr) {
 	GtkWidget *buttons_frame;
 	GtkWidget *buttons_vbox;
 	GtkWidget *main_hbox;
@@ -64,10 +64,10 @@ NedLyricsEditor::NedLyricsEditor(GtkWindow *parent, NedMainWindow *main_window,
 	GtkWidget *view5;
 
 
-	m_dialog = gtk_dialog_new_with_buttons(_("Lyrics"), parent, (GtkDialogFlags) (GTK_DIALOG_MODAL | GTK_DIALOG_DESTROY_WITH_PARENT),
-		GTK_STOCK_OK, GTK_RESPONSE_ACCEPT, GTK_STOCK_CANCEL, GTK_RESPONSE_REJECT, NULL);
+	m_dialog = gtk_dialog_new_with_buttons(_("Lyrics"), parent, (GtkDialogFlags) 0,
+		GTK_STOCK_OK, GTK_RESPONSE_ACCEPT, GTK_STOCK_APPLY, GTK_RESPONSE_APPLY, GTK_STOCK_CANCEL, GTK_RESPONSE_REJECT, NULL);
 
-	g_signal_connect(m_dialog, "response", G_CALLBACK (OnClose), (void *) this);
+	g_signal_connect(m_dialog, "response", G_CALLBACK (ResponseCallBack), (void *) this);
 
 
 	view1 = gtk_text_view_new();
@@ -156,20 +156,21 @@ NedLyricsEditor::NedLyricsEditor(GtkWindow *parent, NedMainWindow *main_window,
 
 }
 
-void NedLyricsEditor::OnClose(GtkDialog *dialog, gint result, gpointer data) {
+void NedLyricsEditor::ResponseCallBack(GtkDialog *dialog, gint result, gpointer data) {
 	NedLyricsEditor *lyrics_editor = (NedLyricsEditor *) data;
 	switch (result) {
 		case GTK_RESPONSE_ACCEPT:
-			lyrics_editor->m_state = TRUE;
-		break;
-		default:
-			lyrics_editor->m_state = FALSE;
+		case GTK_RESPONSE_APPLY:
+			for (int i = 0; i < MAX_LYRICS_LINES; i++) {
+				gtk_text_buffer_get_start_iter(lyrics_editor->m_buffer[i], &(lyrics_editor->m_itr1[i]));
+				gtk_text_buffer_get_start_iter(lyrics_editor->m_buffer[i], &(lyrics_editor->m_itr2[i]));
+				lyrics_editor->m_newchar[i] = TRUE;
+			}
+			lyrics_editor->m_main_window->NedMainWindow::updateLyrics(lyrics_editor, lyrics_editor->m_staff_nr);
 		break;
 	}
-	for (int i = 0; i < MAX_LYRICS_LINES; i++) {
-		gtk_text_buffer_get_start_iter(lyrics_editor->m_buffer[i], &(lyrics_editor->m_itr1[i]));
-		gtk_text_buffer_get_start_iter(lyrics_editor->m_buffer[i], &(lyrics_editor->m_itr2[i]));
-		lyrics_editor->m_newchar[i] = TRUE;
+	if (result != GTK_RESPONSE_APPLY) {
+		delete lyrics_editor;
 	}
 }
 
