@@ -33,8 +33,8 @@
 #define MAX_MEASURE_TYPE END_BAR
 
 
-NedMeasureConfigDialog::NedMeasureConfigDialog(GtkWindow *parent, int measure_type, bool alter1, bool alter2, bool allow_alter, bool hide_following, int num, int denom) :
-m_measure_type(measure_type & REP_TYPE_MASK), m_num(num), m_denom(denom), m_hide_following(hide_following), m_allow_alter(allow_alter), m_delete_timesig(false)  {
+NedMeasureConfigDialog::NedMeasureConfigDialog(GtkWindow *parent, int measure_type, bool alter1, bool alter2, bool allow_alter, bool hide_following, int num, int denom, unsigned int sym) :
+m_measure_type(measure_type & REP_TYPE_MASK), m_num(num), m_denom(denom), m_symbol(sym), m_hide_following(hide_following), m_allow_alter(allow_alter), m_delete_timesig(false)  {
 	GtkWidget *dialog;
 	GtkWidget *hbox;
 	GtkWidget *measure_type_frame;
@@ -91,7 +91,7 @@ m_measure_type(measure_type & REP_TYPE_MASK), m_num(num), m_denom(denom), m_hide
 	g_signal_connect(m_alter1_check_box, "toggled", G_CALLBACK(alter1_checked), (void *) this);
 	gtk_toggle_button_set_active(GTK_TOGGLE_BUTTON(m_alter1_check_box), alter1 && m_allow_alter);
 	gtk_toggle_button_set_active(GTK_TOGGLE_BUTTON(m_alter2_check_box), alter2 && m_allow_alter);
-	gtk_widget_set_sensitive(m_alter1_check_box, measure_type == REPEAT_CLOSE);
+	gtk_widget_set_sensitive(m_alter1_check_box, m_allow_alter && measure_type == REPEAT_CLOSE);
 	gtk_widget_set_sensitive(m_alter2_check_box, (measure_type == REPEAT_CLOSE) && alter1 && m_allow_alter);
 	gtk_box_pack_start(GTK_BOX(alter_box), m_alter1_check_box, TRUE, TRUE, 0);
 	gtk_box_pack_start(GTK_BOX(alter_box), m_alter2_check_box, TRUE, TRUE, 0);
@@ -115,7 +115,6 @@ m_measure_type(measure_type & REP_TYPE_MASK), m_num(num), m_denom(denom), m_hide
 	denominator_label = gtk_label_new(_("Denominator:"));
 	m_numerator = gtk_spin_button_new_with_range (1.0, 20.0, 1.0);
 	gtk_spin_button_set_value(GTK_SPIN_BUTTON(m_numerator), m_num);
-	gtk_widget_set_sensitive(m_numerator, FALSE);
 	m_denominator = gtk_combo_box_new_text();
 	gtk_combo_box_append_text(GTK_COMBO_BOX(m_denominator), "2");
 	gtk_combo_box_append_text(GTK_COMBO_BOX(m_denominator), "4");
@@ -133,15 +132,39 @@ m_measure_type(measure_type & REP_TYPE_MASK), m_num(num), m_denom(denom), m_hide
 	else {
 		gtk_combo_box_set_active(GTK_COMBO_BOX(m_denominator), 3);
 	}
+	m_com_time_bu = gtk_toggle_button_new();
+	gtk_button_set_image(GTK_BUTTON(m_com_time_bu),  gtk_image_new_from_stock("comm-icon", GTK_ICON_SIZE_SMALL_TOOLBAR));
+	m_cut_time_bu = gtk_toggle_button_new();
+	gtk_button_set_image(GTK_BUTTON(m_cut_time_bu),  gtk_image_new_from_stock("cut-icon", GTK_ICON_SIZE_SMALL_TOOLBAR));
+	g_signal_connect(m_com_time_bu, "toggled", G_CALLBACK (OnCommButtonToggled), (void *) this);
+	g_signal_connect(m_cut_time_bu, "toggled", G_CALLBACK (OnCutButtonToggled), (void *) this);
+	switch (sym) {
+		 case TIME_SYMBOL_COMMON_TIME: gtk_toggle_button_set_active(GTK_TOGGLE_BUTTON(m_com_time_bu), TRUE);
+		 			gtk_spin_button_set_value(GTK_SPIN_BUTTON(m_numerator), 4);
+		 			gtk_combo_box_set_active(GTK_COMBO_BOX(m_denominator), 1);
+		 			break;
+		 case TIME_SYMBOL_CUT_TIME: gtk_toggle_button_set_active(GTK_TOGGLE_BUTTON(m_cut_time_bu), TRUE);
+		 			gtk_spin_button_set_value(GTK_SPIN_BUTTON(m_numerator), 2);
+					gtk_combo_box_set_active(GTK_COMBO_BOX(m_denominator), 0);
+					break;
+		default:                gtk_toggle_button_set_active(GTK_TOGGLE_BUTTON(m_cut_time_bu), FALSE);
+					gtk_toggle_button_set_active(GTK_TOGGLE_BUTTON(m_com_time_bu), FALSE);
+					break;
+	}
 	gtk_widget_set_sensitive(m_denominator, FALSE);
+	gtk_widget_set_sensitive(m_numerator, FALSE);
+	gtk_widget_set_sensitive(m_com_time_bu, FALSE);
+	gtk_widget_set_sensitive(m_cut_time_bu, FALSE);
 	m_timsig_check_box = gtk_check_button_new_with_label(_("enable timesig"));
-	g_signal_connect(m_timsig_check_box, "toggled", G_CALLBACK(time_sig_checked), (void *) this);
+	g_signal_connect(m_timsig_check_box, "toggled", G_CALLBACK(OnTimesigToggeled), (void *) this);
 	m_delete_timsig_check_box = gtk_check_button_new_with_label(_("delete timesig"));
 	g_signal_connect(m_delete_timsig_check_box, "toggled", G_CALLBACK(delete_time_sig_checked), (void *) this);
 	gtk_widget_set_sensitive(m_delete_timsig_check_box, FALSE);
 	gtk_box_pack_start (GTK_BOX (time_signature_upper_hbox), numerator_label, FALSE, FALSE, 0);
+	gtk_box_pack_end (GTK_BOX (time_signature_upper_hbox), m_com_time_bu, FALSE, FALSE, 0);
 	gtk_box_pack_end (GTK_BOX (time_signature_upper_hbox), m_numerator, FALSE, FALSE, 0);
 	gtk_box_pack_start (GTK_BOX (time_signature_lower_hbox), denominator_label, FALSE, FALSE, 0);
+	gtk_box_pack_end (GTK_BOX (time_signature_lower_hbox), m_cut_time_bu, FALSE, FALSE, 0);
 	gtk_box_pack_end (GTK_BOX (time_signature_lower_hbox), m_denominator, FALSE, FALSE, 0);
 	gtk_box_pack_start (GTK_BOX (time_signature_vbox), time_signature_upper_hbox, FALSE, FALSE, 0);
 	gtk_box_pack_start (GTK_BOX (time_signature_vbox), time_signature_lower_hbox, FALSE, FALSE, 0);
@@ -178,21 +201,48 @@ void NedMeasureConfigDialog::OnClose(GtkDialog *dialog, gint result, gpointer da
 		case 2: measure_type_dialog->m_denom = 8; break;
 		default: measure_type_dialog->m_denom = 16; break;
 	}
+	if (gtk_toggle_button_get_active(GTK_TOGGLE_BUTTON(measure_type_dialog->m_com_time_bu))) {
+		measure_type_dialog->m_symbol = TIME_SYMBOL_COMMON_TIME;
+		measure_type_dialog->m_num = measure_type_dialog->m_denom = 4;
+	}
+	else if (gtk_toggle_button_get_active(GTK_TOGGLE_BUTTON(measure_type_dialog->m_cut_time_bu))) {
+		measure_type_dialog->m_symbol = TIME_SYMBOL_CUT_TIME;
+		measure_type_dialog->m_num = measure_type_dialog->m_denom = 2;
+	}
+	else {
+		measure_type_dialog->m_symbol = TIME_SYMBOL_NONE;
+	}
 	gtk_widget_destroy (GTK_WIDGET(dialog));
 }
 
-void NedMeasureConfigDialog::time_sig_checked (GtkToggleButton *togglebutton, gpointer data) {
+void NedMeasureConfigDialog::OnTimesigToggeled(GtkToggleButton *togglebutton, gpointer data) {
 	NedMeasureConfigDialog *measure_type_dialog = (NedMeasureConfigDialog *) data;
 	if (gtk_toggle_button_get_active(GTK_TOGGLE_BUTTON(measure_type_dialog->m_timsig_check_box))) {
-		 gtk_widget_set_sensitive(measure_type_dialog->m_numerator, TRUE);
-		 gtk_widget_set_sensitive(measure_type_dialog->m_denominator, TRUE);
-		 gtk_widget_set_sensitive(measure_type_dialog->m_delete_timsig_check_box, TRUE);
+		 gtk_widget_set_sensitive(measure_type_dialog->m_com_time_bu, TRUE);
+		 gtk_widget_set_sensitive(measure_type_dialog->m_cut_time_bu, TRUE);
+		 if (gtk_toggle_button_get_active(GTK_TOGGLE_BUTTON(measure_type_dialog->m_com_time_bu))) {
+		 	gtk_toggle_button_set_active(GTK_TOGGLE_BUTTON(measure_type_dialog->m_cut_time_bu), FALSE);
+		 	gtk_widget_set_sensitive(measure_type_dialog->m_delete_timsig_check_box, TRUE);
+		 }
+		 else if (gtk_toggle_button_get_active(GTK_TOGGLE_BUTTON(measure_type_dialog->m_cut_time_bu))) {
+		 	gtk_toggle_button_set_active(GTK_TOGGLE_BUTTON(measure_type_dialog->m_com_time_bu), FALSE);
+		 	gtk_widget_set_sensitive(measure_type_dialog->m_delete_timsig_check_box, TRUE);
+		 }
+		 else {
+		 	gtk_widget_set_sensitive(measure_type_dialog->m_numerator, TRUE);
+		 	gtk_widget_set_sensitive(measure_type_dialog->m_denominator, TRUE);
+		 	gtk_widget_set_sensitive(measure_type_dialog->m_delete_timsig_check_box, TRUE);
+		 }
 	}
 	else {
 		 gtk_widget_set_sensitive(measure_type_dialog->m_numerator, FALSE);
 		 gtk_widget_set_sensitive(measure_type_dialog->m_denominator, FALSE);
 		 gtk_toggle_button_set_active(GTK_TOGGLE_BUTTON(measure_type_dialog->m_delete_timsig_check_box), FALSE);
 		 gtk_widget_set_sensitive(measure_type_dialog->m_delete_timsig_check_box, FALSE);
+		 gtk_toggle_button_set_active(GTK_TOGGLE_BUTTON(measure_type_dialog->m_cut_time_bu), FALSE);
+		 gtk_toggle_button_set_active(GTK_TOGGLE_BUTTON(measure_type_dialog->m_com_time_bu), FALSE);
+		 gtk_widget_set_sensitive(measure_type_dialog->m_cut_time_bu, FALSE);
+		 gtk_widget_set_sensitive(measure_type_dialog->m_com_time_bu, FALSE);
 		 measure_type_dialog->m_delete_timesig = false;
 	}
 }
@@ -202,7 +252,7 @@ void NedMeasureConfigDialog::delete_time_sig_checked (GtkToggleButton *togglebut
 	the_dialog->m_delete_timesig = gtk_toggle_button_get_active(GTK_TOGGLE_BUTTON(the_dialog->m_delete_timsig_check_box));
 }
 
-void NedMeasureConfigDialog::getValues(bool *state, int *measure_type, bool *alter1, bool *alter2, bool *hide_following, bool *timsig_state, bool *delete_timesig, int *num, int *denom) {
+void NedMeasureConfigDialog::getValues(bool *state, int *measure_type, bool *alter1, bool *alter2, bool *hide_following, bool *timsig_state, bool *delete_timesig, int *num, int *denom, unsigned int *sym ) {
 	*state = m_state;
 	*measure_type = m_measure_type;
 	*alter1 = m_alter1 && m_measure_type == 2;
@@ -212,6 +262,7 @@ void NedMeasureConfigDialog::getValues(bool *state, int *measure_type, bool *alt
 	*denom = m_denom;
 	*timsig_state = m_timesig_state;
 	*delete_timesig = m_delete_timesig;
+	*sym = m_symbol;
 }
 
 gboolean NedMeasureConfigDialog::draw_measure_types(GtkWidget *widget, GdkEventExpose *event, gpointer data) {
@@ -347,6 +398,8 @@ void NedMeasureConfigDialog::previous_measure_type (GtkButton *button, gpointer
 		}
 	}
 	else {
+		gtk_widget_set_sensitive(the_dialog->m_hide_box, TRUE);
+		gtk_toggle_button_set_active(GTK_TOGGLE_BUTTON(the_dialog->m_hide_box), FALSE);
 		gtk_widget_set_sensitive(the_dialog->m_hide_box, FALSE);
 	}
 	rect.x = rect.y = 0;
@@ -390,6 +443,8 @@ void NedMeasureConfigDialog::next_measure_type (GtkButton *button, gpointer data
 		}
 	}
 	else {
+		gtk_widget_set_sensitive(the_dialog->m_hide_box, TRUE);
+		gtk_toggle_button_set_active(GTK_TOGGLE_BUTTON(the_dialog->m_hide_box), FALSE);
 		gtk_widget_set_sensitive(the_dialog->m_hide_box, FALSE);
 	}
 	rect.x = rect.y = 0;
@@ -409,3 +464,36 @@ void NedMeasureConfigDialog::alter1_checked (GtkToggleButton *togglebutton, gpoi
 	}
 }
 
+void NedMeasureConfigDialog::OnCommButtonToggled(GtkToggleButton *togglebutton, gpointer data) {
+	NedMeasureConfigDialog *the_dialog = (NedMeasureConfigDialog *) data;
+
+	if (gtk_toggle_button_get_active(GTK_TOGGLE_BUTTON(the_dialog->m_com_time_bu))) {
+		gtk_toggle_button_set_active(GTK_TOGGLE_BUTTON(the_dialog->m_cut_time_bu), FALSE);
+		gtk_spin_button_set_value(GTK_SPIN_BUTTON(the_dialog->m_numerator), 4);
+		gtk_combo_box_set_active(GTK_COMBO_BOX(the_dialog->m_denominator), 1);
+		gtk_widget_set_sensitive(the_dialog->m_numerator, FALSE);
+		gtk_widget_set_sensitive(the_dialog->m_denominator, FALSE);
+	}
+	else if (!gtk_toggle_button_get_active(GTK_TOGGLE_BUTTON(the_dialog->m_cut_time_bu))) {
+		gtk_widget_set_sensitive(the_dialog->m_numerator, TRUE);
+		gtk_widget_set_sensitive(the_dialog->m_denominator, TRUE);
+	}
+}
+
+void NedMeasureConfigDialog::OnCutButtonToggled(GtkToggleButton *togglebutton, gpointer data) {
+	NedMeasureConfigDialog *the_dialog = (NedMeasureConfigDialog *) data;
+
+	if (gtk_toggle_button_get_active(GTK_TOGGLE_BUTTON(the_dialog->m_cut_time_bu))) {
+		gtk_toggle_button_set_active(GTK_TOGGLE_BUTTON(the_dialog->m_com_time_bu), FALSE);
+		gtk_spin_button_set_value(GTK_SPIN_BUTTON(the_dialog->m_numerator), 2);
+		gtk_combo_box_set_active(GTK_COMBO_BOX(the_dialog->m_denominator), 0);
+		gtk_widget_set_sensitive(the_dialog->m_numerator, FALSE);
+		gtk_widget_set_sensitive(the_dialog->m_denominator, FALSE);
+	}
+	else if (!gtk_toggle_button_get_active(GTK_TOGGLE_BUTTON(the_dialog->m_com_time_bu))) {
+		gtk_widget_set_sensitive(the_dialog->m_numerator, TRUE);
+		gtk_widget_set_sensitive(the_dialog->m_denominator, TRUE);
+	}
+}
+
+
