@@ -30,15 +30,17 @@
 
 class NedMeasureConfigDialog {
 	public:
-		NedMeasureConfigDialog(GtkWindow *parent, int measure_type, bool alter1, bool alter2, bool allow_alter, bool hide_following, int num, int denom);
-		void getValues(bool *state, int *measure_type, bool *alter1, bool *alter2, bool *hide_following, bool *timsig_state, bool *delete_timesig, int *num, int *denom);
+		NedMeasureConfigDialog(GtkWindow *parent, int measure_type, bool alter1, bool alter2, bool allow_alter, bool hide_following, int num, int denom, unsigned int sym);
+		void getValues(bool *state, int *measure_type, bool *alter1, bool *alter2, bool *hide_following, bool *timsig_state, bool *delete_timesig, int *num, int *denom, unsigned int *sym);
 	private:
 		static void OnClose(GtkDialog *dialog, gint result, gpointer data);
+		static void OnTimesigToggeled (GtkToggleButton *togglebutton, gpointer data);
+		static void OnCommButtonToggled(GtkToggleButton *togglebutton, gpointer data);
+		static void OnCutButtonToggled(GtkToggleButton *togglebutton, gpointer data);
 		static gboolean draw_measure_types(GtkWidget *widget, GdkEventExpose *event, gpointer data);
 		static void previous_measure_type(GtkButton *button, gpointer user_data);
 		static void next_measure_type(GtkButton *button, gpointer user_data);
 		static void alter1_checked (GtkToggleButton *togglebutton, gpointer data);
-		static void time_sig_checked (GtkToggleButton *togglebutton, gpointer data);
 		static void delete_time_sig_checked (GtkToggleButton *togglebutton, gpointer data);
 		GtkWidget *m_measure_type_show_window;
 		GtkWidget *m_meas_bu_up;
@@ -48,12 +50,15 @@ class NedMeasureConfigDialog {
 		GtkWidget *m_hide_box;
 		GtkWidget *m_numerator;
 		GtkWidget *m_denominator;
+		GtkWidget *m_com_time_bu;
+		GtkWidget *m_cut_time_bu;
 		GtkWidget *m_timsig_check_box;
 		GtkWidget *m_delete_timsig_check_box;
 		bool m_state;
 		int m_measure_type;
 		int m_original_type;
 		int m_num, m_denom;
+		unsigned int m_symbol;
 		bool m_alter1;
 		bool m_alter2;
 		bool m_hide_following;
