@@ -28,16 +28,9 @@
 #define MIDIIMPORT_DIALOG_HEIGHT 450
 
 
-NedMidiImportDialog::NedMidiImportDialog(GtkWindow *parent, char **folder, char **filename) : m_with_triplets(true), m_with_single_triplets(true),
-	m_tempo_change_density(20), m_volume_change_density(20), m_voice_num(4),
-	m_last_folder(folder), m_filename(filename) {
+NedMidiImportDialog::NedMidiImportDialog(GtkWindow *parent, char **folder, char **filename) : m_with_triplets(true),
+	m_tempo_change_density(20), m_volume_change_density(20), m_last_folder(folder), m_filename(filename) {
 	GtkWidget *dialog;
-	GtkWidget *triplet_frame;
-	GtkWidget *clef_frame;
-	GtkWidget *triplet_vbox;
-	GtkWidget *voice_frame;
-	GtkWidget *voice_hbox;
-	GtkWidget *voice_label;
 	GtkWidget *tempo_sensity_frame;
 	GtkWidget *volume_sensity_frame;
 
@@ -71,36 +64,21 @@ NedMidiImportDialog::NedMidiImportDialog(GtkWindow *parent, char **folder, char
 	gtk_file_chooser_add_filter(GTK_FILE_CHOOSER(m_file_chooser), file_filter1);
 	gtk_file_chooser_add_filter(GTK_FILE_CHOOSER(m_file_chooser), file_filter2);
 
-	triplet_frame = gtk_frame_new(_("triplets"));
+	left_vbox = gtk_vbox_new(FALSE, 2);
+	right_vbox = gtk_vbox_new(FALSE, 2);
 
-	triplet_vbox = gtk_vbox_new(FALSE, 2);
+	m_with_triplet_button = gtk_toggle_button_new_with_label(_("triplet recognition"));
+	gtk_toggle_button_set_active(GTK_TOGGLE_BUTTON(m_with_triplet_button), TRUE);
+	m_sort_instruments_button = gtk_toggle_button_new_with_label(_("sort instruments"));
+	m_force_piano_button = gtk_toggle_button_new_with_label(_("force piano"));
+	m_dont_split_button = gtk_toggle_button_new_with_label(_("don't split tracks"));
+	g_signal_connect(m_force_piano_button, "toggled", G_CALLBACK (OnPianoForcePressed), (void *) this);
+	g_signal_connect(m_dont_split_button, "toggled", G_CALLBACK (OnDontSplitPressed), (void *) this);
 
-	m_with_triplet_box = gtk_check_button_new_with_label(_("triplet recognition"));
-	m_with_single_triplets_box = gtk_check_button_new_with_label(_("triplets with rests"));
-	//gtk_toggle_button_set_active(GTK_TOGGLE_BUTTON(m_with_triplet_box), TRUE);
-	//gtk_toggle_button_set_active(GTK_TOGGLE_BUTTON(m_with_single_triplets_box), TRUE);
-	g_signal_connect(m_with_triplet_box, "toggled", G_CALLBACK(triplet_modus_changed), (void *) this);
-	gtk_box_pack_start(GTK_BOX(triplet_vbox), m_with_triplet_box, TRUE, TRUE, 0);
-	gtk_box_pack_start(GTK_BOX(triplet_vbox), m_with_single_triplets_box, TRUE, TRUE, 0);
-
-	gtk_container_add (GTK_CONTAINER(triplet_frame), triplet_vbox);
-
-	clef_frame = gtk_frame_new(_("clef"));
-	m_with_alto_clef_box = gtk_check_button_new_with_label(_("use alto clef"));
-	gtk_container_add (GTK_CONTAINER(clef_frame), m_with_alto_clef_box);
-
-	voice_frame = gtk_frame_new(_("voices"));
-
-	voice_hbox = gtk_vbox_new(FALSE, 2);
-
-	voice_label = gtk_label_new(_("Number of voices:"));
-	m_voice_num_spin_box = gtk_spin_button_new_with_range(1.0, 4.0, 1.0);
-	gtk_spin_button_set_value(GTK_SPIN_BUTTON(m_voice_num_spin_box), 4.0);
-
-	gtk_box_pack_start(GTK_BOX(voice_hbox), voice_label, TRUE, TRUE, 0);
-	gtk_box_pack_start(GTK_BOX(voice_hbox), m_voice_num_spin_box, TRUE, TRUE, 0);
-
-	gtk_container_add (GTK_CONTAINER(voice_frame), voice_hbox);
+	gtk_container_add (GTK_CONTAINER(left_vbox), m_with_triplet_button);
+	gtk_container_add (GTK_CONTAINER(left_vbox), m_sort_instruments_button);
+	gtk_container_add (GTK_CONTAINER(left_vbox), m_force_piano_button);
+	gtk_container_add (GTK_CONTAINER(left_vbox), m_dont_split_button);
 
 	tempo_sensity_frame = gtk_frame_new(_("tempo density"));
 
@@ -114,29 +92,17 @@ NedMidiImportDialog::NedMidiImportDialog(GtkWindow *parent, char **folder, char
 	gtk_range_set_value(GTK_RANGE(m_volume_change_density_scale), 20.0);
 	gtk_container_add (GTK_CONTAINER(volume_sensity_frame), m_volume_change_density_scale);
 
-	m_force_piano_button = gtk_toggle_button_new_with_label(_("force piano"));
-	m_force_one_staff_button = gtk_toggle_button_new_with_label(_("force one staff"));
-	g_signal_connect(m_force_piano_button, "pressed", G_CALLBACK (OnPianoForcePressed), (void *) this);
-	g_signal_connect(m_force_one_staff_button, "pressed", G_CALLBACK (OnOnStaffForcePressed), (void *) this);
-
-	main_hbox = gtk_hbox_new(FALSE, 2);
-	left_vbox = gtk_vbox_new(FALSE, 2);
-	right_vbox = gtk_vbox_new(FALSE, 2);
-
-	main_vbox = gtk_vbox_new(FALSE, 2);
-
-	gtk_box_pack_start(GTK_BOX(left_vbox), triplet_frame, FALSE, TRUE, 0);
-	gtk_box_pack_start(GTK_BOX(left_vbox), clef_frame, FALSE, TRUE, 0);
-	gtk_box_pack_start(GTK_BOX(left_vbox), voice_frame, FALSE, TRUE, 0);
 
 	gtk_box_pack_start(GTK_BOX(right_vbox), tempo_sensity_frame, FALSE, TRUE, 0);
 	gtk_box_pack_start(GTK_BOX(right_vbox), volume_sensity_frame, FALSE, TRUE, 0);
-	gtk_box_pack_start(GTK_BOX(right_vbox), m_force_piano_button, FALSE, TRUE, 0);
-	gtk_box_pack_start(GTK_BOX(right_vbox), m_force_one_staff_button, FALSE, TRUE, 0);
+
+	main_hbox = gtk_hbox_new(FALSE, 2);
 
 	gtk_box_pack_start(GTK_BOX(main_hbox), left_vbox, TRUE, TRUE, 0);
 	gtk_box_pack_start(GTK_BOX(main_hbox), right_vbox, TRUE, TRUE, 0);
 
+	main_vbox = gtk_vbox_new(FALSE, 2);
+
 	gtk_box_pack_start (GTK_BOX(main_vbox), main_hbox, FALSE, FALSE, 0);
 	gtk_box_pack_start (GTK_BOX(main_vbox), m_file_chooser, TRUE, TRUE, 0);
 
@@ -150,9 +116,6 @@ NedMidiImportDialog::NedMidiImportDialog(GtkWindow *parent, char **folder, char
 void NedMidiImportDialog::OnClose(GtkDialog *dialog, gint result, gpointer data) {
 	char *s;
 	NedMidiImportDialog *midi_import_dialog = (NedMidiImportDialog *) data;
-	midi_import_dialog->m_with_triplets = gtk_toggle_button_get_active(GTK_TOGGLE_BUTTON(midi_import_dialog->m_with_triplet_box));
-	midi_import_dialog->m_with_single_triplets = gtk_toggle_button_get_active(GTK_TOGGLE_BUTTON(midi_import_dialog->m_with_single_triplets_box));
-	midi_import_dialog->m_with_alto_clef = gtk_toggle_button_get_active(GTK_TOGGLE_BUTTON(midi_import_dialog->m_with_alto_clef_box));
 	/*
 	printf("current folder = %s, filename = %s\n", gtk_file_chooser_get_current_folder(GTK_FILE_CHOOSER(midi_import_dialog->m_file_chooser)),
 		gtk_file_chooser_get_filename(GTK_FILE_CHOOSER(midi_import_dialog->m_file_chooser)));
@@ -182,24 +145,23 @@ void NedMidiImportDialog::OnClose(GtkDialog *dialog, gint result, gpointer data)
 			midi_import_dialog->m_state = FALSE;
 		break;
 	}
+	midi_import_dialog->m_with_triplets = gtk_toggle_button_get_active(GTK_TOGGLE_BUTTON(midi_import_dialog->m_with_triplet_button));
 	midi_import_dialog->m_tempo_change_density = (int) gtk_range_get_value(GTK_RANGE(midi_import_dialog->m_tempo_change_density_scale));
 	midi_import_dialog->m_volume_change_density = (int) gtk_range_get_value(GTK_RANGE(midi_import_dialog->m_volume_change_density_scale));
-	midi_import_dialog->m_voice_num = (int) gtk_spin_button_get_value(GTK_SPIN_BUTTON(midi_import_dialog->m_voice_num_spin_box));
 	midi_import_dialog->m_force_piano = gtk_toggle_button_get_active(GTK_TOGGLE_BUTTON(midi_import_dialog->m_force_piano_button));
-	midi_import_dialog->m_force_one_staff = gtk_toggle_button_get_active(GTK_TOGGLE_BUTTON(midi_import_dialog->m_force_one_staff_button));
+	midi_import_dialog->m_sort_instruments = gtk_toggle_button_get_active(GTK_TOGGLE_BUTTON(midi_import_dialog->m_sort_instruments_button));
+	midi_import_dialog->m_dont_split = gtk_toggle_button_get_active(GTK_TOGGLE_BUTTON(midi_import_dialog->m_dont_split_button));
 	gtk_widget_destroy (GTK_WIDGET(dialog));
 }
 
 
-void NedMidiImportDialog::getValues(bool *state, bool *with_triplets, bool *with_single_triplets, bool *with_alto_clef, int *voice_count,
-			int *tempo_change_density, int *volume_change_density, bool *force_piano, bool *force_one_staff) {
+void NedMidiImportDialog::getValues(bool *state, bool *with_triplets, int *tempo_change_density, int *volume_change_density,
+		bool *force_piano, bool *sort_instruments, bool *dont_split) {
 	*state = m_state;
 	*with_triplets = m_with_triplets;
-	*with_single_triplets = m_with_single_triplets;
-	*with_alto_clef = m_with_alto_clef;
-	*voice_count = m_voice_num;
 	*force_piano = m_force_piano;
-	*force_one_staff = m_force_one_staff;
+	*sort_instruments = m_sort_instruments;
+	*dont_split = m_dont_split;
 	*tempo_change_density = (int)(100.0 - m_tempo_change_density);
 	*volume_change_density = (int)(100.0 - m_volume_change_density);
 	if (*tempo_change_density < 0) *tempo_change_density = 0;
@@ -209,27 +171,26 @@ void NedMidiImportDialog::getValues(bool *state, bool *with_triplets, bool *with
 }
 
 
-void NedMidiImportDialog::triplet_modus_changed (GtkToggleButton *togglebutton, gpointer data) {
-	NedMidiImportDialog *the_dialog = (NedMidiImportDialog *) data;
-	if (gtk_toggle_button_get_active(GTK_TOGGLE_BUTTON(the_dialog->m_with_triplet_box))) {
-		gtk_widget_set_sensitive(the_dialog->m_with_single_triplets_box, TRUE);
-		gtk_toggle_button_set_active(GTK_TOGGLE_BUTTON(the_dialog->m_with_single_triplets_box), TRUE);
-	}
-	else {
-		gtk_toggle_button_set_active(GTK_TOGGLE_BUTTON(the_dialog->m_with_single_triplets_box), FALSE);
-		gtk_widget_set_sensitive(the_dialog->m_with_single_triplets_box, FALSE);
-	}
-}
-
 void NedMidiImportDialog::OnPianoForcePressed(GtkButton *button, gpointer data) {
 	NedMidiImportDialog *the_dialog = (NedMidiImportDialog *) data;
-
-	gtk_toggle_button_set_active(GTK_TOGGLE_BUTTON(the_dialog->m_force_one_staff_button), FALSE);
+	if (gtk_toggle_button_get_active(GTK_TOGGLE_BUTTON(the_dialog->m_force_piano_button))) {
+		gtk_toggle_button_set_active(GTK_TOGGLE_BUTTON(the_dialog->m_dont_split_button), FALSE);
+		gtk_widget_set_sensitive(the_dialog->m_dont_split_button, FALSE);
+	}
+	else {
+		gtk_widget_set_sensitive(the_dialog->m_dont_split_button, TRUE);
+	}
 }
 
-void NedMidiImportDialog::OnOnStaffForcePressed(GtkButton *button, gpointer data) {
+void NedMidiImportDialog::OnDontSplitPressed(GtkButton *button, gpointer data) {
 	NedMidiImportDialog *the_dialog = (NedMidiImportDialog *) data;
 
-	gtk_toggle_button_set_active(GTK_TOGGLE_BUTTON(the_dialog->m_force_piano_button), FALSE);
+	if (gtk_toggle_button_get_active(GTK_TOGGLE_BUTTON(the_dialog->m_dont_split_button))) {
+		gtk_toggle_button_set_active(GTK_TOGGLE_BUTTON(the_dialog->m_force_piano_button), FALSE);
+		gtk_widget_set_sensitive(the_dialog->m_force_piano_button, FALSE);
+	}
+	else {
+		 gtk_widget_set_sensitive(the_dialog->m_force_piano_button, TRUE);
+	}
 }
 
