@@ -30,31 +30,26 @@
 class NedMidiImportDialog {
 	public:
 		NedMidiImportDialog(GtkWindow *parent, char **folder, char **filename);
-		void getValues(bool *state, bool *with_triplets, bool *with_single_triplets, bool *with_alto_clef, int *voice_count,
-			int *tempo_change_density, int *volume_change_density, bool *force_piano, bool *force_one_staff);
+		void getValues(bool *state, bool *with_triplets, int *tempo_change_density, int *volume_change_density,
+			bool *force_piano, bool *sort_instruments, bool *dont_split);
 	private:
 		static void OnClose(GtkDialog *dialog, gint result, gpointer data);
 		static void OnPianoForcePressed(GtkButton *button, gpointer data);
-		static void OnOnStaffForcePressed(GtkButton *button, gpointer data);
-		static void triplet_modus_changed(GtkToggleButton *togglebutton, gpointer data);
-		GtkWidget *m_with_triplet_box;
-		GtkWidget *m_with_single_triplets_box;
-		GtkWidget *m_with_alto_clef_box;
-		GtkWidget *m_voice_num_spin_box;
+		static void OnDontSplitPressed(GtkButton *button, gpointer data);
+		GtkWidget *m_with_triplet_button;
 		GtkWidget *m_tempo_change_density_scale;
 		GtkWidget *m_volume_change_density_scale;
 		GtkWidget *m_file_chooser;
 		GtkWidget *m_force_piano_button;
-		GtkWidget *m_force_one_staff_button;
+		GtkWidget *m_sort_instruments_button;
+		GtkWidget *m_dont_split_button;
 		bool m_state;
 		bool m_with_triplets;
-		bool m_with_single_triplets;
-		bool m_with_alto_clef;
 		int m_tempo_change_density;
 		int m_volume_change_density;
-		int m_voice_num;
 		bool m_force_piano;
-		bool m_force_one_staff;
+		bool m_sort_instruments;
+		bool m_dont_split;
 		gchar **m_last_folder;
 		gchar **m_filename;
 };
