@@ -28,7 +28,8 @@
 
 NedMuteDialog::NedMuteDialog(GtkWindow *parent, bool *mutes, struct staff_context_str *staff_contexts, int numstaffs) : m_mutes(mutes), m_numstaffs(numstaffs) {
 	GtkWidget *dialog;
-	int i;
+	bool is_muted;
+	int i, j;
 	char Str[128];
 	dialog = gtk_dialog_new_with_buttons(_("Muting"), parent, (GtkDialogFlags) (GTK_DIALOG_MODAL | GTK_DIALOG_DESTROY_WITH_PARENT),
 		GTK_STOCK_OK, GTK_RESPONSE_ACCEPT, GTK_STOCK_CANCEL, GTK_RESPONSE_REJECT, NULL);
@@ -46,7 +47,7 @@ NedMuteDialog::NedMuteDialog(GtkWindow *parent, bool *mutes, struct staff_contex
 	  m_checkboxes= new GtkWidget*[numstaffs];
 	}
 	catch(std::exception& e){
-	  NedResource::Abort("NedMuteDialog: allocation error");
+	  NedResource::Abort("NedMuteDialog: allocation error1");
 	}
 
 	for (i = 0; i < numstaffs; i++) {
@@ -57,7 +58,11 @@ NedMuteDialog::NedMuteDialog(GtkWindow *parent, bool *mutes, struct staff_contex
 		else {
 			m_checkboxes[i] = gtk_check_button_new_with_label(staff_contexts[i].m_staff_name->getText());
 		}
-		gtk_toggle_button_set_active(GTK_TOGGLE_BUTTON(m_checkboxes[i]), staff_contexts[i].m_muted);
+		is_muted = true;
+		for (j = 0; j < VOICE_COUNT; j++) {
+			if (!staff_contexts[i].m_muted[j]) is_muted = false;
+		}
+		gtk_toggle_button_set_active(GTK_TOGGLE_BUTTON(m_checkboxes[i]), is_muted);
 		gtk_box_pack_start(GTK_BOX(buttonbox), m_checkboxes[i], FALSE, FALSE, 0);
 	}
 
