@@ -57,6 +57,7 @@ ScoreInfo::~ScoreInfo() {
 	}
 }
 
+#define TITLELENGTH 100
 
 
 NedScoreInfoConfigDialog::NedScoreInfoConfigDialog(GtkWindow *parent, NedMainWindow *main_window, ScoreInfo *scoreinfo) :
@@ -76,7 +77,7 @@ m_scoreinfo(scoreinfo), m_main_window(main_window) {
 	grid = gtk_table_new(2, 5, FALSE);
 
 	label = gtk_label_new(_("Title:"));
-	m_title = gtk_entry_new_with_max_length(50);
+	m_title = gtk_entry_new_with_max_length(TITLELENGTH);
 	if (m_scoreinfo->title != NULL) {
 		gtk_entry_set_text(GTK_ENTRY(m_title), m_scoreinfo->title->getText());
 	}
@@ -84,7 +85,7 @@ m_scoreinfo(scoreinfo), m_main_window(main_window) {
 	gtk_table_attach(GTK_TABLE(grid), m_title, 1, 2, 0, 1, (GtkAttachOptions) (GTK_EXPAND | GTK_FILL) , (GtkAttachOptions) 0,  0, 0);
 
 	label = gtk_label_new(_("Subject:"));
-	m_subject = gtk_entry_new_with_max_length(50);
+	m_subject = gtk_entry_new_with_max_length(TITLELENGTH);
 	if (m_scoreinfo->subject != NULL) {
 		gtk_entry_set_text(GTK_ENTRY(m_subject), m_scoreinfo->subject->getText());
 	}
@@ -92,7 +93,7 @@ m_scoreinfo(scoreinfo), m_main_window(main_window) {
 	gtk_table_attach(GTK_TABLE(grid), m_subject, 1, 2, 1, 2, (GtkAttachOptions) (GTK_EXPAND | GTK_FILL) , (GtkAttachOptions) 0,  0, 0);
 
 	label = gtk_label_new(_("Composer:"));
-	m_composer = gtk_entry_new_with_max_length(50);
+	m_composer = gtk_entry_new_with_max_length(TITLELENGTH);
 	if (m_scoreinfo->composer != NULL) {
 		gtk_entry_set_text(GTK_ENTRY(m_composer), m_scoreinfo->composer->getText());
 	}
@@ -100,7 +101,7 @@ m_scoreinfo(scoreinfo), m_main_window(main_window) {
 	gtk_table_attach(GTK_TABLE(grid), m_composer, 1, 2, 2, 3, (GtkAttachOptions) (GTK_EXPAND | GTK_FILL) , (GtkAttachOptions) 0,  0, 0);
 
 	label = gtk_label_new(_("Arranger:"));
-	m_arranger = gtk_entry_new_with_max_length(50);
+	m_arranger = gtk_entry_new_with_max_length(TITLELENGTH);
 	if (m_scoreinfo->arranger != NULL) {
 		gtk_entry_set_text(GTK_ENTRY(m_arranger), m_scoreinfo->arranger->getText());
 	}
@@ -108,7 +109,7 @@ m_scoreinfo(scoreinfo), m_main_window(main_window) {
 	gtk_table_attach(GTK_TABLE(grid), m_arranger, 1, 2, 3, 4, (GtkAttachOptions) (GTK_EXPAND | GTK_FILL) , (GtkAttachOptions) 0,  0, 0);
 
 	label = gtk_label_new(_("Copyright:"));
-	m_copyright = gtk_entry_new_with_max_length(50);
+	m_copyright = gtk_entry_new_with_max_length(TITLELENGTH);
 	if (m_scoreinfo->copyright != NULL) {
 		gtk_entry_set_text(GTK_ENTRY(m_copyright), m_scoreinfo->copyright->getText());
 	}
