@@ -38,12 +38,12 @@ _("F sharp Major; d sharp minor")
 };
 
 
-NedStaffContextDialog::NedStaffContextDialog(GtkWindow *parent, NedMainWindow *main_window, bool different_voices, bool allow_delete_system, int staff_count, int staff_pos, char *staff_name, char *staff_short_name, char *group_name, char* group_short_name, int clef_number, int octave_shift, int key_signature_number, int numerator,  int demoninator, unsigned int symbol, int volume[VOICE_COUNT], int midi_program[VOICE_COUNT], int channel, int tempo, int pan[VOICE_COUNT], int chorus, int play_transposed, int reverb, bool muted) :
+NedStaffContextDialog::NedStaffContextDialog(GtkWindow *parent, NedMainWindow *main_window, bool different_voices, bool allow_delete_system, int staff_count, int staff_pos, char *staff_name, char *staff_short_name, char *group_name, char* group_short_name, int clef_number, int octave_shift, int key_signature_number, int numerator,  int demoninator, unsigned int symbol, int volume[VOICE_COUNT], int midi_program[VOICE_COUNT], int channel, int tempo, int pan[VOICE_COUNT], int chorus, int play_transposed, int reverb, bool muted[VOICE_COUNT]) :
 m_different_voices(different_voices), m_octave_shift(octave_shift), m_tempo(tempo), m_chorus(chorus), m_play_transposed(play_transposed), m_reverb(reverb), m_channel_value(channel),
 m_state(false), m_numerator_value(numerator), m_denominator_value(demoninator), m_symbol(symbol),
 m_key_signature_number(key_signature_number), m_current_clef(clef_number),  m_config_changed(false),
 m_delete_staff(false), m_staff_pos(staff_pos), 
-m_staff_count(staff_count), m_staff_name(staff_name), m_staff_short_name(staff_short_name), m_group_name(group_name), m_group_short_name(group_short_name), m_muted(muted)  {
+m_staff_count(staff_count), m_staff_name(staff_name), m_staff_short_name(staff_short_name), m_group_name(group_name), m_group_short_name(group_short_name)  {
 	GtkWidget *dialog;
 	GtkWidget *label_score;
 	GtkWidget *label_midi;
@@ -79,8 +79,11 @@ m_staff_count(staff_count), m_staff_name(staff_name), m_staff_short_name(staff_s
 	GtkTreeViewColumn *instrument_column;
 	GtkTreeViewColumn *instrument_num_column;
 	GtkWidget *channel_frame;
-	GtkWidget *mute_frame;
 	GtkWidget *mute_channel_vbox;
+	GtkWidget *mute_frame;
+	GtkWidget *mute_vbox;
+	GtkWidget *mute_hbox1;
+	GtkWidget *mute_hbox2;
 	GtkWidget *voices_frame;
 	GtkWidget *vrb_vbox;
 	GtkWidget *vrb_hbox1;
@@ -99,6 +102,9 @@ m_staff_count(staff_count), m_staff_name(staff_name), m_staff_short_name(staff_s
 	GtkWidget *group_name_frame;
 	GtkWidget *group_short_name_frame;
 	GtkWidget *group_name_vbox;
+
+	bool all_muted;
+
 	int i;
 	char Str[128];
 
@@ -106,6 +112,7 @@ m_staff_count(staff_count), m_staff_name(staff_name), m_staff_short_name(staff_s
 		m_midi_program_number[i] = midi_program[i];
 		m_pan[i] = pan[i];
 		m_volume[i] = volume[i];
+		m_muted[i] = muted[i];
 	}
 		
 	m_newclef = m_current_clef;
@@ -328,13 +335,44 @@ m_staff_count(staff_count), m_staff_name(staff_name), m_staff_short_name(staff_s
 	gtk_container_add (GTK_CONTAINER(channel_frame), m_channel_spin_box);
 
 	mute_frame = gtk_frame_new(_("muting"));
-        m_mute_box = gtk_check_button_new();
-        gtk_toggle_button_set_active(GTK_TOGGLE_BUTTON(m_mute_box), m_muted);
-        gtk_container_add (GTK_CONTAINER(mute_frame), m_mute_box);
+        m_mute_all_check = gtk_check_button_new_with_label (_("all"));
+        m_mute_1_check = gtk_check_button_new_with_label ("1");
+        m_mute_2_check = gtk_check_button_new_with_label ("2");
+        m_mute_3_check = gtk_check_button_new_with_label ("3");
+        m_mute_4_check = gtk_check_button_new_with_label ("4");
+	
+	mute_vbox = gtk_vbox_new (FALSE, 0);
+	mute_hbox1 = gtk_hbox_new (FALSE, 0);
+	mute_hbox2 = gtk_hbox_new (FALSE, 0);
 
+	gtk_box_pack_start (GTK_BOX (mute_vbox), m_mute_all_check, FALSE, FALSE, 0);
+	gtk_box_pack_start (GTK_BOX (mute_hbox1), m_mute_1_check, FALSE, FALSE, 0);
+	gtk_box_pack_start (GTK_BOX (mute_hbox1), m_mute_2_check, FALSE, FALSE, 0);
+	gtk_box_pack_start (GTK_BOX (mute_hbox2), m_mute_3_check, FALSE, FALSE, 0);
+	gtk_box_pack_start (GTK_BOX (mute_hbox2), m_mute_4_check, FALSE, FALSE, 0);
+
+	gtk_box_pack_start (GTK_BOX (mute_vbox), mute_hbox1, FALSE, FALSE, 0);
+	gtk_box_pack_start (GTK_BOX (mute_vbox), mute_hbox2, FALSE, FALSE, 0);
+
+	all_muted = true;
+	for (i = 0; i < VOICE_COUNT; i++) {
+		if (!muted[i]) all_muted = false;
+	}
+
+        gtk_toggle_button_set_active(GTK_TOGGLE_BUTTON(m_mute_all_check), all_muted);
+        gtk_toggle_button_set_active(GTK_TOGGLE_BUTTON(m_mute_1_check), muted[0]);
+        gtk_toggle_button_set_active(GTK_TOGGLE_BUTTON(m_mute_2_check), muted[1]);
+        gtk_toggle_button_set_active(GTK_TOGGLE_BUTTON(m_mute_3_check), muted[2]);
+        gtk_toggle_button_set_active(GTK_TOGGLE_BUTTON(m_mute_4_check), muted[3]);
+	gtk_container_add(GTK_CONTAINER(mute_frame), mute_vbox);
 
 	voices_frame = gtk_frame_new(_("voices"));
 	m_radio_all = gtk_radio_button_new_with_label(NULL, _("all"));
+	g_signal_connect(m_mute_all_check, "toggled", G_CALLBACK (OnAllMutedToggle), (void *) this);
+	m_handlrs[0] = g_signal_connect(m_mute_1_check, "toggled", G_CALLBACK (OnSingleMutedToggle), (void *) this);
+	m_handlrs[1] = g_signal_connect(m_mute_2_check, "toggled", G_CALLBACK (OnSingleMutedToggle), (void *) this);
+	m_handlrs[2] = g_signal_connect(m_mute_3_check, "toggled", G_CALLBACK (OnSingleMutedToggle), (void *) this);
+	m_handlrs[3] = g_signal_connect(m_mute_4_check, "toggled", G_CALLBACK (OnSingleMutedToggle), (void *) this);
 	m_radio_1 = gtk_radio_button_new_with_label_from_widget(GTK_RADIO_BUTTON (m_radio_all), "1");
 	m_radio_2 = gtk_radio_button_new_with_label_from_widget(GTK_RADIO_BUTTON (m_radio_all), "2");
 	m_radio_3 = gtk_radio_button_new_with_label_from_widget(GTK_RADIO_BUTTON (m_radio_all), "3");
@@ -602,9 +640,24 @@ void NedStaffContextDialog::OnClose(GtkDialog *dialog, gint result, gpointer dat
 		context_dialog->m_reverb = newreverb;
 		context_dialog->m_config_changed = TRUE;
 	}
-	newmute = gtk_toggle_button_get_active(GTK_TOGGLE_BUTTON(context_dialog->m_mute_box));
-	if (newmute != context_dialog->m_muted) {
-		context_dialog->m_muted = newmute;
+	newmute = gtk_toggle_button_get_active(GTK_TOGGLE_BUTTON(context_dialog->m_mute_1_check));
+	if (context_dialog->m_muted[0] != newmute) {
+		context_dialog->m_muted[0] = newmute;
+		context_dialog->m_config_changed = TRUE;
+	}
+	newmute = gtk_toggle_button_get_active(GTK_TOGGLE_BUTTON(context_dialog->m_mute_2_check));
+	if (context_dialog->m_muted[1] != newmute) {
+		context_dialog->m_muted[1] = newmute;
+		context_dialog->m_config_changed = TRUE;
+	}
+	newmute = gtk_toggle_button_get_active(GTK_TOGGLE_BUTTON(context_dialog->m_mute_3_check));
+	if (context_dialog->m_muted[2] != newmute) {
+		context_dialog->m_muted[2] = newmute;
+		context_dialog->m_config_changed = TRUE;
+	}
+	newmute = gtk_toggle_button_get_active(GTK_TOGGLE_BUTTON(context_dialog->m_mute_4_check));
+	if (context_dialog->m_muted[3] != newmute) {
+		context_dialog->m_muted[3] = newmute;
 		context_dialog->m_config_changed = TRUE;
 	}
 	context_dialog->m_do_adjust = gtk_toggle_button_get_active(GTK_TOGGLE_BUTTON(context_dialog->m_adjust_check_box));
@@ -722,7 +775,7 @@ void NedStaffContextDialog::OnClose(GtkDialog *dialog, gint result, gpointer dat
 	gtk_widget_destroy (GTK_WIDGET(dialog));
 }
 
-void NedStaffContextDialog::getValues(bool *state, bool *different_voices, bool *delete_staff, bool *delete_system, int *staff_pos, char **staff_name, char **staff_short_name, char **group_name, char **group_short_name, int *clef_number, int *octave_shift, int *key_signature_number, bool *ajdust_notes, int *numerator, int *demoninator,  unsigned int *symbol, int volume[VOICE_COUNT], int midi_program[VOICE_COUNT], int *channel, int *tempo, int pan[VOICE_COUNT], int *chorus, int *play_transposed, int *reverb, bool *config_changed, bool *muted) {
+void NedStaffContextDialog::getValues(bool *state, bool *different_voices, bool *delete_staff, bool *delete_system, int *staff_pos, char **staff_name, char **staff_short_name, char **group_name, char **group_short_name, int *clef_number, int *octave_shift, int *key_signature_number, bool *ajdust_notes, int *numerator, int *demoninator,  unsigned int *symbol, int volume[VOICE_COUNT], int midi_program[VOICE_COUNT], int *channel, int *tempo, int pan[VOICE_COUNT], int *chorus, int *play_transposed, int *reverb, bool *config_changed, bool muted[VOICE_COUNT]) {
 	int i;
 	*different_voices = m_different_voices;
 	*delete_staff = m_delete_staff;
@@ -754,6 +807,7 @@ void NedStaffContextDialog::getValues(bool *state, bool *different_voices, bool
 		volume[i] = m_volume[i];
 		midi_program[i] = m_midi_program_number[i];
 		pan[i] = m_pan[i];
+		muted[i] = m_muted[i];
 	}
 	if (m_state) {
 		*config_changed = m_config_changed;
@@ -1025,3 +1079,70 @@ void NedStaffContextDialog::OnVoiceToggle(GtkToggleButton *togglebutton, gpointe
 		}
 	}
 }
+
+void NedStaffContextDialog::OnAllMutedToggle(GtkToggleButton *togglebutton, gpointer data) {
+	bool toggle_state;
+
+	NedStaffContextDialog *context_dialog = (NedStaffContextDialog *) data;
+
+	toggle_state = gtk_toggle_button_get_active (togglebutton);
+
+	gtk_toggle_button_set_active(GTK_TOGGLE_BUTTON(context_dialog->m_mute_1_check), toggle_state);
+	gtk_toggle_button_set_active(GTK_TOGGLE_BUTTON(context_dialog->m_mute_2_check), toggle_state);
+	gtk_toggle_button_set_active(GTK_TOGGLE_BUTTON(context_dialog->m_mute_3_check), toggle_state);
+	gtk_toggle_button_set_active(GTK_TOGGLE_BUTTON(context_dialog->m_mute_4_check), toggle_state);
+}
+
+void NedStaffContextDialog::OnSingleMutedToggle(GtkToggleButton *togglebutton, gpointer data) {
+	int i;
+	bool toggle_state;
+	bool all_muted = true;
+	bool none_muted = true;
+	NedStaffContextDialog *context_dialog = (NedStaffContextDialog *) data;
+
+	toggle_state = gtk_toggle_button_get_active(GTK_TOGGLE_BUTTON(context_dialog->m_mute_1_check));
+	if (toggle_state) {
+		none_muted = false;
+	}
+	else {
+		all_muted = false;
+	}
+		
+	toggle_state = gtk_toggle_button_get_active(GTK_TOGGLE_BUTTON(context_dialog->m_mute_2_check));
+	if (toggle_state) {
+		none_muted = false;
+	}
+	else {
+		all_muted = false;
+	}
+	toggle_state = gtk_toggle_button_get_active(GTK_TOGGLE_BUTTON(context_dialog->m_mute_3_check));
+	if (toggle_state) {
+		none_muted = false;
+	}
+	else {
+		all_muted = false;
+	}
+	toggle_state = gtk_toggle_button_get_active(GTK_TOGGLE_BUTTON(context_dialog->m_mute_4_check));
+	if (toggle_state) {
+		none_muted = false;
+	}
+	else {
+		all_muted = false;
+	}
+
+	g_signal_handler_block(context_dialog->m_mute_1_check, context_dialog->m_handlrs[0]);
+	g_signal_handler_block(context_dialog->m_mute_2_check, context_dialog->m_handlrs[1]);
+	g_signal_handler_block(context_dialog->m_mute_3_check, context_dialog->m_handlrs[2]);
+	g_signal_handler_block(context_dialog->m_mute_4_check, context_dialog->m_handlrs[3]);
+	if (none_muted) {
+		gtk_toggle_button_set_active(GTK_TOGGLE_BUTTON(context_dialog->m_mute_all_check), FALSE);
+	}
+	if (all_muted) {
+		gtk_toggle_button_set_active(GTK_TOGGLE_BUTTON(context_dialog->m_mute_all_check), TRUE);
+	}
+	g_signal_handler_unblock(context_dialog->m_mute_1_check, context_dialog->m_handlrs[0]);
+	g_signal_handler_unblock(context_dialog->m_mute_2_check, context_dialog->m_handlrs[1]);
+	g_signal_handler_unblock(context_dialog->m_mute_3_check, context_dialog->m_handlrs[2]);
+	g_signal_handler_unblock(context_dialog->m_mute_4_check, context_dialog->m_handlrs[3]);
+	
+}
