@@ -24,7 +24,7 @@
 #include "resource.h"
 #include "config.h"
 
-NedTempoDialog::NedTempoDialog(GtkWindow *parent, unsigned int kind /* = NOTE_4 */, bool dot /* = false */, unsigned int tempo /* = 120 */) :
+NedTempoDialog::NedTempoDialog(GtkWindow *parent, bool relative, unsigned int kind /* = NOTE_4 */, bool dot /* = false */, unsigned int tempo /* = 120 */) :
 	m_kind(kind), m_dot(dot), m_tempo(tempo) {
 	GtkWidget *dialog;
 	GtkWidget *lab;
@@ -127,7 +127,6 @@ NedTempoDialog::NedTempoDialog(GtkWindow *parent, unsigned int kind /* = NOTE_4
 	gtk_box_pack_start(GTK_BOX(kind_hbox), vbox_note_16_dot, FALSE, FALSE, 0);
 	kind_frame = gtk_frame_new(_("kind"));
 	gtk_container_add (GTK_CONTAINER(kind_frame), kind_hbox);
-
 	switch (kind) {
 		case WHOLE_NOTE: gtk_toggle_button_set_active(GTK_TOGGLE_BUTTON(m_whole_kind), TRUE); break;
 		case NOTE_2: gtk_toggle_button_set_active(GTK_TOGGLE_BUTTON(m_kind_2), !m_dot);
@@ -140,7 +139,12 @@ NedTempoDialog::NedTempoDialog(GtkWindow *parent, unsigned int kind /* = NOTE_4
 			 gtk_toggle_button_set_active(GTK_TOGGLE_BUTTON(m_kind_16_dot), TRUE); break;
 	}
 
-	m_tempo_spin_box = gtk_spin_button_new_with_range (10.0, 999.0, 1.0);
+	if (relative) {
+		m_tempo_spin_box = gtk_spin_button_new_with_range (-999, 999.0, 1.0);
+	}
+	else {
+		m_tempo_spin_box = gtk_spin_button_new_with_range (10.0, 999.0, 1.0);
+	}
 	gtk_spin_button_set_value(GTK_SPIN_BUTTON(m_tempo_spin_box), tempo);
 
 	lab = gtk_label_new(_("tempo:"));
