@@ -29,7 +29,7 @@
 
 class NedTempoDialog {
 	public:
-		NedTempoDialog(GtkWindow *parent, unsigned int kind = NOTE_4, bool dot = false, unsigned int tempo = 120);
+		NedTempoDialog(GtkWindow *parent, bool relative, unsigned int kind = NOTE_4, bool dot = false, unsigned int tempo = 120);
 		void getValues(bool *state, unsigned int *kind, bool *dot, unsigned int *tempo);
 	private:
 		static void CloseCallBack(GtkDialog *dialog, gint result, gpointer data);
