@@ -20,6 +20,7 @@
 /****************************************************************************************/
 
 #include <math.h>
+#include <X11/Xlib.h>
 #include <gdk/gdkkeysyms.h>
 #include "tools.h"
 #include "localization.h"
@@ -35,7 +36,7 @@
 #define VERTI_BACKGROUND 2
 #define MINI_BACKGROUND  3
 
-#define MINI_BUTTON_AREA_HEIGHT (2 * m_mini_spaces + m_back_miniimg_height)
+#define MINI_BUTTON_AREA_HEIGHT (3 * m_mini_spaces + 2 * m_back_miniimg_height)
 
 #define NOTE_64_BUTTON       [0][ 2]
 #define NATURAL_BUTTON       [0][ 4]
@@ -64,6 +65,7 @@
 #define SFORZATO_BUTTON      [1][15]
 #define TENUTO_BUTTON        [1][16]
 
+#define TURN_BUTTON          [2][ 2]
 #define BOW_UP_BUTTON        [2][ 4]
 #define BOW_DOWN_BUTTON      [2][ 5]
 #define PED_ON_BUTTON        [2][ 6]
@@ -73,9 +75,10 @@
 #define OPEN_BUTTON          [2][11]
 #define MORDENT_BUTTON       [2][12]
 #define ARPEGGIO_BUTTON      [2][13]
+#define REV_TURN_BUTTON      [2][16]
 
-#define O_HIGH_NOTE_BUTTON   [3][ 2]
-#define C_HIGH_NOTE_BUTTON   [3][ 3]
+#define O_HIGH_NOTE_BUTTON   [3][ 1]
+#define C_HIGH_NOTE_BUTTON   [3][ 2]
 #define NORMAL_NOTE_BUTTON   [3][ 4]
 #define CROSS_NOTE1_BUTTON   [3][ 5]
 #define CROSS_NOTE2_BUTTON   [3][ 6]
@@ -90,19 +93,28 @@
 #define GUIT_STEM_BUTTON     [3][15]
 #define GUIT_NO_STEM_BUTTON  [3][16]
 
+#define TEMOLO1_NOTE_BUTTON  [4][ 4]
+#define TEMOLO2_NOTE_BUTTON  [4][ 5]
+#define TEMOLO3_NOTE_BUTTON  [4][ 6]
+#define TEMOLO4_NOTE_BUTTON  [4][ 8]
+
 
 X11button *NedTools::m_button_arrays[NUM_PANELS][17];
-X11button *NedTools::m_mini_button_arrays[4];
+X11button *NedTools::m_mini_button_arrays[8];
 
-X11buttonGroup NedTools::m_accidentals(true), NedTools::m_note_length_group(false), NedTools::m_note_head_group(false), NedTools::m_dot_group(true);
+X11buttonGroup NedTools::m_accidentals(true), NedTools::m_note_length_group(false), NedTools::m_note_head_group(false), NedTools::m_dot_group(true), NedTools::m_tremolo_group(true);
 
 static GdkPixbuf *nullbuf = NULL;
 
-NedTools::button_descr NedTools::m_mini_button_descriptions[4] = {
+NedTools::button_descr NedTools::m_mini_button_descriptions[8] = {
 	{&NedResource::m_quarternote_icon, PUSH_BUTTON, SCOPE_NONE, false, NULL},
 	{&NedResource::m_cross_icon, PUSH_BUTTON, SCOPE_NONE, false, NULL},
 	{&NedResource::m_bow_down_icon, PUSH_BUTTON, SCOPE_NONE, false, NULL},
-	{&NedResource::m_drum7_icon, PUSH_BUTTON, SCOPE_NONE, false, NULL}
+	{&NedResource::m_drum7_icon, PUSH_BUTTON, SCOPE_NONE, false, NULL},
+	{&NedResource::m_tremolo_icon2, PUSH_BUTTON, SCOPE_NONE, false, NULL},
+	{&nullbuf, EMPTY_BUTTON, SCOPE_NONE, false, NULL},
+	{&nullbuf, EMPTY_BUTTON, SCOPE_NONE, false, NULL},
+	{&nullbuf, EMPTY_BUTTON, SCOPE_NONE, false, NULL}
 };
 
 
@@ -133,19 +145,19 @@ NedTools::button_descr NedTools::m_button_descriptions[NUM_PANELS][17] = {
 
    {
 	{ &nullbuf, EMPTY_BUTTON, SCOPE_NONE, false, NULL }, {&NedResource::m_arrow_left_icon, PUSH_BUTTON, SCOPE_NONE, false, NULL }, 
-		{ &nullbuf, EMPTY_BUTTON, SCOPE_NONE, false, NULL }, { &NedResource::m_arrow_right_icon, PUSH_BUTTON, SCOPE_NONE, false, NULL },
+		{ &NedResource::m_turn_icon, TOGGLE_BUTTON, SCOPE_STATE, false, NULL }, { &NedResource::m_arrow_right_icon, PUSH_BUTTON, SCOPE_NONE, false, NULL },
 	{&NedResource::m_bow_up_icon, TOGGLE_BUTTON, SCOPE_STATE, false, NULL}, {&NedResource::m_bow_down_icon, TOGGLE_BUTTON, SCOPE_STATE, false, NULL},
 		{&NedResource::m_ped_on_icon, TOGGLE_BUTTON, SCOPE_STATE, false, NULL}, {&nullbuf, EMPTY_BUTTON, SCOPE_NONE, false, NULL},
 	{&NedResource::m_ped_off_icon, TOGGLE_BUTTON, SCOPE_STATE, false, NULL}, {&NedResource::m_trill_icon, TOGGLE_BUTTON, SCOPE_STATE, false, NULL},
 		{&NedResource::m_prall_icon, TOGGLE_BUTTON, SCOPE_STATE, false, NULL},
 	{&NedResource::m_open_icon, TOGGLE_BUTTON, SCOPE_STATE, false, NULL}, {&NedResource::m_mordent_icon, TOGGLE_BUTTON, SCOPE_STATE, false, NULL},
 		{&NedResource::m_arpeggio_icon, TOGGLE_BUTTON, SCOPE_STATE, false, NULL}, {&nullbuf, EMPTY_BUTTON, SCOPE_NONE, false, NULL},
-	{&nullbuf, EMPTY_BUTTON, SCOPE_NONE, false, NULL}, {&nullbuf, EMPTY_BUTTON, SCOPE_NONE, false, NULL}
+	{&nullbuf, EMPTY_BUTTON, SCOPE_NONE, false, NULL}, {&NedResource::m_revturn_icon, TOGGLE_BUTTON, SCOPE_STATE, false, NULL}
    },
 
    {
-	{ &nullbuf, EMPTY_BUTTON, SCOPE_NONE, false, NULL }, {&NedResource::m_arrow_left_icon, PUSH_BUTTON, SCOPE_NONE, false, NULL }, 
-		{ &NedResource::m_drum11_icon, TOGGLE_BUTTON, SCOPE_NOTE_HEAD, false, &m_note_head_group}, { &NedResource::m_drum12_icon, TOGGLE_BUTTON, SCOPE_NOTE_HEAD, false, &m_note_head_group },
+	{&NedResource::m_arrow_left_icon, PUSH_BUTTON, SCOPE_NONE, false, NULL }, { &NedResource::m_drum11_icon, TOGGLE_BUTTON, SCOPE_NOTE_HEAD, false, &m_note_head_group},
+		 { &NedResource::m_drum12_icon, TOGGLE_BUTTON, SCOPE_NOTE_HEAD, false, &m_note_head_group }, { &NedResource::m_arrow_right_icon, PUSH_BUTTON, SCOPE_NONE, false, NULL },
 	{&NedResource::m_normal_note_icon, TOGGLE_BUTTON, SCOPE_NOTE_HEAD, true, &m_note_head_group}, {&NedResource::m_drum1_icon, TOGGLE_BUTTON, SCOPE_NOTE_HEAD, false, &m_note_head_group},
 		{&NedResource::m_drum2_icon, TOGGLE_BUTTON, SCOPE_NOTE_HEAD, false, &m_note_head_group}, {&NedResource::m_drum3_icon, TOGGLE_BUTTON, SCOPE_NOTE_HEAD, false, &m_note_head_group},
 	{&NedResource::m_drum4_icon, TOGGLE_BUTTON, SCOPE_NOTE_HEAD, false, &m_note_head_group}, {&NedResource::m_drum5_icon, TOGGLE_BUTTON, SCOPE_NOTE_HEAD, false, &m_note_head_group},
@@ -153,6 +165,18 @@ NedTools::button_descr NedTools::m_button_descriptions[NUM_PANELS][17] = {
 	{&NedResource::m_drum7_icon, TOGGLE_BUTTON, SCOPE_NOTE_HEAD, false, &m_note_head_group}, {&NedResource::m_drum8_icon, TOGGLE_BUTTON, SCOPE_NOTE_HEAD, false, &m_note_head_group},
 		{&NedResource::m_drum9_icon, TOGGLE_BUTTON, SCOPE_NOTE_HEAD, false, &m_note_head_group}, {&NedResource::m_drum10_icon, TOGGLE_BUTTON, SCOPE_NOTE_HEAD, false, &m_note_head_group},
 	{&NedResource::m_guitar_note_icon, TOGGLE_BUTTON, SCOPE_NOTE_HEAD, false, &m_note_head_group}, {&NedResource::m_guitar_note_no_stem_icon, TOGGLE_BUTTON, SCOPE_NOTE_HEAD, false, &m_note_head_group}
+   },
+
+   {
+	{ &nullbuf, EMPTY_BUTTON, SCOPE_NONE, false, NULL }, {&NedResource::m_arrow_left_icon, PUSH_BUTTON, SCOPE_NONE, false, NULL }, 
+		{ &nullbuf, EMPTY_BUTTON, SCOPE_NONE, false, NULL }, { &nullbuf, EMPTY_BUTTON, SCOPE_NONE, false, NULL },
+	{&NedResource::m_tremolo_icon1, TOGGLE_BUTTON, SCOPE_STATE, false, &m_tremolo_group}, {&NedResource::m_tremolo_icon2, TOGGLE_BUTTON, SCOPE_STATE, false, &m_tremolo_group},
+		{&NedResource::m_tremolo_icon3, TOGGLE_BUTTON, SCOPE_STATE, false, &m_tremolo_group}, {&nullbuf, EMPTY_BUTTON, SCOPE_NONE, false, NULL },
+	{&NedResource::m_tremolo_icon4, TOGGLE_BUTTON, SCOPE_STATE, false, &m_tremolo_group}, {&nullbuf, EMPTY_BUTTON, SCOPE_NONE, false, NULL },
+		{&nullbuf, EMPTY_BUTTON, SCOPE_NONE, false, NULL },
+	{&nullbuf, EMPTY_BUTTON, SCOPE_NONE, false, NULL }, {&nullbuf, EMPTY_BUTTON, SCOPE_NONE, false, NULL },
+		{&nullbuf, EMPTY_BUTTON, SCOPE_NONE, false, NULL }, {&nullbuf, EMPTY_BUTTON, SCOPE_NONE, false, NULL },
+	{&nullbuf, EMPTY_BUTTON, SCOPE_NONE, false, NULL }, {&nullbuf, EMPTY_BUTTON, SCOPE_NONE, false, NULL }
    }
 
 };
@@ -333,8 +357,10 @@ void X11buttonGroup::resetAllButtons() {
 	
 #define CREATE_X11_EMPTY(back, up) createX11PixmapFromGdkPixbuffer(dpy, screen, d, ggc, NULL, back, up);
 
+#define CREATE_MINI_X11_EMPTY(back, up) createX11PixmapFromGdkPixbuffer(dpy, screen, d, ggc, NULL, back, up);
+
 NedTools::NedTools() :
-	m_back_pix(NULL), m_current_row(-1), m_current_column(-1), m_current_panel(0), m_buttons_created(false)
+	m_back_pix(NULL), m_current_row(-1), m_current_column(-1), m_current_panel(0), m_buttons_created(false), m_dpy(NULL)
 		 {
 	GdkColor bgcolor;
 	int wx, wy;
@@ -398,6 +424,7 @@ NedTools::~NedTools() {
 	m_note_length_group.removeAllButtons();
 	m_note_head_group.removeAllButtons();
 	m_dot_group.removeAllButtons();
+	m_tremolo_group.removeAllButtons();
 }
 
 void NedTools::updatePosition() {
@@ -492,6 +519,7 @@ unsigned int NedTools::getStatus() {
 	if (m_button_arrays STACCATISSIMO_BUTTON ->m_active) status |= STAT_STACCATISSIMO;
 	if (m_button_arrays SFORZATO_BUTTON ->m_active) status |= STAT_SFORZATO;
 	if (m_button_arrays TENUTO_BUTTON ->m_active) status |= STAT_TENUTO;
+	if (m_button_arrays TURN_BUTTON ->m_active) status |= STAT_TURN;
 	if (m_button_arrays BOW_UP_BUTTON ->m_active) status |= STAT_BOW_UP;
 	if (m_button_arrays BOW_DOWN_BUTTON ->m_active) status |= STAT_BOW_DOWN;
 	if (m_button_arrays PED_ON_BUTTON ->m_active) status |= STAT_PED_ON;
@@ -501,6 +529,11 @@ unsigned int NedTools::getStatus() {
 	if (m_button_arrays OPEN_BUTTON ->m_active) status |= STAT_OPEN;
 	if (m_button_arrays MORDENT_BUTTON ->m_active) status |= STAT_MORDENT;
 	if (m_button_arrays ARPEGGIO_BUTTON ->m_active) status |= STAT_ARPEGGIO;
+	if (m_button_arrays REV_TURN_BUTTON ->m_active) status |= STAT_REV_TURN;
+	if (m_button_arrays TEMOLO1_NOTE_BUTTON ->m_active) status |= STAT_TREMOLO1;
+	if (m_button_arrays TEMOLO2_NOTE_BUTTON ->m_active) status |= STAT_TREMOLO2;
+	if (m_button_arrays TEMOLO3_NOTE_BUTTON ->m_active) status |= STAT_TREMOLO3;
+	if (m_button_arrays TEMOLO4_NOTE_BUTTON ->m_active) status |= STAT_TREMOLO4;
 	return status;
 }
 
@@ -556,6 +589,7 @@ void NedTools::setButtons(unsigned int length, int dotcount, unsigned int chord_
 	if (chord_status & STAT_STACCATISSIMO) m_button_arrays STACCATISSIMO_BUTTON ->m_active = true;
 	if (chord_status & STAT_SFORZATO) m_button_arrays SFORZATO_BUTTON ->m_active = true;
 	if (chord_status & STAT_TENUTO) m_button_arrays TENUTO_BUTTON ->m_active = true;
+	if (chord_status & STAT_TURN) m_button_arrays TURN_BUTTON ->m_active = true;
 	if (chord_status & STAT_BOW_UP) m_button_arrays BOW_UP_BUTTON ->m_active = true;
 	if (chord_status & STAT_BOW_DOWN) m_button_arrays BOW_DOWN_BUTTON ->m_active = true;
 	if (chord_status & STAT_PED_ON) m_button_arrays PED_ON_BUTTON ->m_active = true;
@@ -565,6 +599,11 @@ void NedTools::setButtons(unsigned int length, int dotcount, unsigned int chord_
 	if (chord_status & STAT_OPEN) m_button_arrays OPEN_BUTTON ->m_active = true;
 	if (chord_status & STAT_MORDENT) m_button_arrays MORDENT_BUTTON ->m_active = true;
 	if (chord_status & STAT_ARPEGGIO) m_button_arrays ARPEGGIO_BUTTON ->m_active = true;
+	if (chord_status & STAT_REV_TURN) m_button_arrays REV_TURN_BUTTON ->m_active = true;
+	if ((chord_status & TREMOLO_MASK) == STAT_TREMOLO1) m_button_arrays TEMOLO1_NOTE_BUTTON ->m_active = true;
+	if ((chord_status & TREMOLO_MASK) == STAT_TREMOLO2) m_button_arrays TEMOLO2_NOTE_BUTTON ->m_active = true;
+	if ((chord_status & TREMOLO_MASK) == STAT_TREMOLO3) m_button_arrays TEMOLO3_NOTE_BUTTON ->m_active = true;
+	if ((chord_status & TREMOLO_MASK) == STAT_TREMOLO4) m_button_arrays TEMOLO4_NOTE_BUTTON ->m_active = true;
 
 	if (length == WHOLE_NOTE) m_button_arrays WHOLE_NOTE_BUTTON ->m_active = true;
 	else if (length == NOTE_2) m_button_arrays HALF_NOTE_BUTTON ->m_active = true;
@@ -595,6 +634,7 @@ void NedTools::setButtons(unsigned int length, int dotcount, unsigned int chord_
 	else if (note_head == GUITAR_NOTE_NO_STEM) m_button_arrays GUIT_NO_STEM_BUTTON ->m_active = true;
 	else m_button_arrays NORMAL_NOTE_BUTTON ->m_active = true;
 
+
 	m_button_arrays TIE_BUTTON ->m_active = tie_forward;
 	gdk_window_invalidate_rect(m_button_area->window, NULL, FALSE);
 
@@ -647,6 +687,7 @@ void NedTools::resetSomeButtons() {
 	m_button_arrays SFORZATO_BUTTON ->m_active = false;
 	m_button_arrays SFORZANDO_BUTTON ->m_active = false;
 	m_button_arrays TENUTO_BUTTON ->m_active = false;
+	m_button_arrays TURN_BUTTON ->m_active = false;
 	m_button_arrays BOW_UP_BUTTON ->m_active = false;
 	m_button_arrays BOW_DOWN_BUTTON ->m_active = false;
 	m_button_arrays PED_ON_BUTTON ->m_active = false;
@@ -656,6 +697,11 @@ void NedTools::resetSomeButtons() {
 	m_button_arrays OPEN_BUTTON ->m_active = false;
 	m_button_arrays MORDENT_BUTTON ->m_active = false;
 	m_button_arrays ARPEGGIO_BUTTON ->m_active = false;
+	m_button_arrays REV_TURN_BUTTON ->m_active = false;
+	m_button_arrays TEMOLO1_NOTE_BUTTON ->m_active = false;
+	m_button_arrays TEMOLO2_NOTE_BUTTON ->m_active = false;
+	m_button_arrays TEMOLO3_NOTE_BUTTON ->m_active = false;
+	m_button_arrays TEMOLO4_NOTE_BUTTON ->m_active = false;
 	gdk_window_invalidate_rect(m_button_area->window, NULL, FALSE);
 }
 
@@ -809,10 +855,16 @@ void NedTools::determine_image_and_dimensions(Display *dpy, Window win, GdkGC *g
 	}
 }
 
-void NedTools::determine_mini_image_and_dimensions(Display *dpy, Window win, GdkGC *ggc, GdkDrawable *d, int screen, GdkPixbuf *buf, XImage *img[2], int *w, int *h) {
+void NedTools::determine_mini_image_and_dimensions(Display *dpy, Window win, GdkGC *ggc, GdkDrawable *d, int screen, GdkPixbuf *buf, XImage *img[2], int type, int *w, int *h) {
 	*w = m_back_miniimg_width; *h = m_back_miniimg_height;
-	img[0] = CREATE_MINI_X11(buf, MINI_BACKGROUND, false);
-	img[1] = CREATE_MINI_X11(buf, MINI_BACKGROUND, true);
+	if (type == EMPTY_BUTTON) {
+		img[0] = CREATE_MINI_X11_EMPTY(MINI_BACKGROUND, false);
+		img[1] = CREATE_MINI_X11_EMPTY(MINI_BACKGROUND, true);
+	}
+	else {
+		img[0] = CREATE_MINI_X11(buf, MINI_BACKGROUND, false);
+		img[1] = CREATE_MINI_X11(buf, MINI_BACKGROUND, true);
+	}
 }
 
 void NedTools::createButtons(Display *dpy, Window win, GC xgc, GdkGC *ggc,  GdkDrawable *d, int screen) {
@@ -889,14 +941,24 @@ void NedTools::createMiniButtons(Display *dpy, Window win, GC xgc, GdkGC *ggc,
 	XImage *img[2];
 
 	for (column = 0; column < 4; column++) {
-		determine_mini_image_and_dimensions(dpy, win, ggc, d, screen, *(m_mini_button_descriptions[column].m_pixbuf), img, &w, &h);
+		determine_mini_image_and_dimensions(dpy, win, ggc, d, screen, *(m_mini_button_descriptions[column].m_pixbuf), img, m_mini_button_descriptions[column].m_type, &w, &h);
 		m_mini_button_arrays[column] = new X11button(dpy, win, xgc, screen, img, m_mini_spaces + column * (m_mini_spaces + m_back_miniimg_width), m_mini_spaces,
 				w, h, column, 0, 0, m_mini_button_descriptions[column].m_type, SCOPE_NONE, m_mini_button_descriptions[column].m_type != EMPTY_BUTTON,
 				m_mini_button_descriptions[column].m_default_state);
 
 	}
+	for (column = 4; column < 8; column++) {
+		determine_mini_image_and_dimensions(dpy, win, ggc, d, screen, *(m_mini_button_descriptions[column].m_pixbuf), img, m_mini_button_descriptions[column].m_type, &w, &h);
+		m_mini_button_arrays[column] = new X11button(dpy, win, xgc, screen, img, m_mini_spaces + (column - 4) * (m_mini_spaces + m_back_miniimg_width),
+				m_mini_spaces + 1 * (m_mini_spaces + m_back_miniimg_height),
+				w, h, column, 0, 0, m_mini_button_descriptions[column].m_type, SCOPE_NONE, m_mini_button_descriptions[column].m_type != EMPTY_BUTTON,
+				m_mini_button_descriptions[column].m_default_state);
+
+	}
 }
 
+
+
 gboolean NedTools::draw_menu(GtkWidget *widget, GdkEventExpose *event, gpointer data) {
 	NedTools *the_dialog = (NedTools *) data;
 	Display *dpy;
@@ -908,8 +970,7 @@ gboolean NedTools::draw_menu(GtkWidget *widget, GdkEventExpose *event, gpointer
 	
 	if (m_button_arrays[0][0] == NULL) {
 		the_dialog->m_back_pix = gdk_pixmap_new(the_dialog->m_button_area->window, 
-	4 * the_dialog->m_back_img_width, MINI_BUTTON_AREA_HEIGHT + 5 * the_dialog->m_back_img_height,
-		-1);
+	         4 * the_dialog->m_back_img_width, MINI_BUTTON_AREA_HEIGHT + 5 * the_dialog->m_back_img_height, -1);
 		the_dialog->m_copy_gc = gdk_gc_new(the_dialog->m_button_area->window);
 		the_dialog->m_blue_gc = gdk_gc_new(the_dialog->m_back_pix);
 		bgcolor.pixel = 1;
@@ -932,7 +993,7 @@ gboolean NedTools::draw_menu(GtkWidget *widget, GdkEventExpose *event, gpointer
 	for (bu_nr = 0; bu_nr < 17; bu_nr++) {
 		m_button_arrays[the_dialog->m_current_panel][bu_nr]->draw();
 	}
-	for (bu_nr = 0; bu_nr < 4; bu_nr++) {
+	for (bu_nr = 0; bu_nr < 8; bu_nr++) {
 		m_mini_button_arrays[bu_nr]->draw();
 	}
 
@@ -1015,7 +1076,7 @@ bool NedTools::OnButtonPress(GtkWidget *widget, GdkEventButton *event, gpointer
 	for (bu_nr = 0; bu_nr < 17; bu_nr++) {
 		m_button_arrays[the_dialog->m_current_panel][bu_nr]->handle_click(event->x, event->y);
 	}
-	for (bu_nr = 0; bu_nr < 4; bu_nr++) {
+	for (bu_nr = 0; bu_nr < 5; bu_nr++) {
 		m_mini_button_arrays[bu_nr]->handle_click(event->x, event->y);
 	}
 	gdk_window_invalidate_rect(the_dialog->m_button_area->window, NULL, FALSE);
@@ -1031,7 +1092,7 @@ bool NedTools::OnButtonRelease(GtkWidget *widget, GdkEventButton *event, gpointe
 			the_dialog->testForPanelChange(m_button_arrays[the_dialog->m_current_panel][bu_nr]);
 		}
 	}
-	for (bu_nr = 0; bu_nr < 4; bu_nr++) {
+	for (bu_nr = 0; bu_nr < 5; bu_nr++) {
 		if (m_mini_button_arrays[bu_nr]->handle_release(event->x, event->y)) {
 			the_dialog->m_current_panel = bu_nr;
 		}
@@ -1071,6 +1132,16 @@ void NedTools::testForPanelChange(X11button *button) {
 	            }
 	            break;
 	    case 3: switch (button->m_row) {
+		case 0: switch (button->m_column) {
+		   	case 0: m_current_panel--;
+				break;
+		   	case 3: m_current_panel++;
+				break;
+		        }
+		        break;
+	            }
+	            break;
+	    case 4: switch (button->m_row) {
 		case 0: switch (button->m_column) {
 		   	case 1: m_current_panel--;
 				break;
