@@ -29,7 +29,7 @@
 class NedMainWindow;
 class X11buttonGroup;
 
-#define NUM_PANELS 4
+#define NUM_PANELS 5
 
 class X11button {
 	public:
@@ -118,7 +118,7 @@ class NedTools {
 		void createMiniButtons(Display *dpy, Window win, GC xgc, GdkGC *ggc,  GdkDrawable *d, int screen);
 		void determine_image_and_dimensions(Display *dpy, Window win, GdkGC *ggc, GdkDrawable *d, int screen, int panel, int row, int column, int bu_nr,
 			GdkPixbuf *buf, XImage *img[2], int *w, int *h);
-		void determine_mini_image_and_dimensions(Display *dpy, Window win, GdkGC *ggc, GdkDrawable *d, int screen, GdkPixbuf *buf, XImage *img[2], int *w, int *h);
+		void determine_mini_image_and_dimensions(Display *dpy, Window win, GdkGC *ggc, GdkDrawable *d, int screen, GdkPixbuf *buf, XImage *img[2], int type, int *w, int *h);
 		void testForPanelChange(X11button *button);
 		static bool close_toolbox(GtkWidget *widget, GdkEvent  *event, gpointer data);
 		 class button_descr {
@@ -131,10 +131,14 @@ class NedTools {
 		};
 
 		static button_descr m_button_descriptions[NUM_PANELS][17];
-		static button_descr m_mini_button_descriptions[4];
+		static button_descr m_mini_button_descriptions[8];
 		static X11button *m_button_arrays[NUM_PANELS][17];
-		static X11button *m_mini_button_arrays[4];
+		static X11button *m_mini_button_arrays[8];
 		GdkGC *m_copy_gc, *m_blue_gc;
+		Display *m_dpy;
+		Window m_win;
+		GC m_xgc;
+		int m_screen;
                                       
 
 			
@@ -149,7 +153,7 @@ class NedTools {
 		GtkWidget *m_button_frame;
 		GtkWidget *m_toolbox;
 		GdkPixmap *m_back_pix;
-		static X11buttonGroup m_accidentals, m_note_length_group, m_note_head_group, m_dot_group;
+		static X11buttonGroup m_accidentals, m_note_length_group, m_note_head_group, m_dot_group, m_tremolo_group;
 		bool m_state;
 		int m_current_row, m_current_column;
 		int m_current_panel;
