@@ -124,7 +124,7 @@ void NedChordName::startContextDialog(GtkWidget *ref) {
 	NedChordNameDialog *dialog = new NedChordNameDialog (NULL, GTK_WINDOW(ref),
 			m_root_text != NULL ? m_root_text->getText() : NULL,
 			m_up_text != NULL ? m_up_text->getText() : NULL,
-			m_down_text != NULL ? m_down_text->getText() : NULL, m_fontsize, -1.5);
+			m_down_text != NULL ? m_down_text->getText() : NULL, m_fontsize, -1.5, false);
 	dialog->getValues(&state, &newroottext, &newuptext, &newdowntext, &m_fontsize, &dummy);
 	if (state) {
 		if (m_root_text != NULL) {
