@@ -35,8 +35,9 @@
 #define Y_POS_PAGE_REL_INVERSE(p) (((p) / current_scale + topy - (TOP_BOTTOM_BORDER + DEFAULT_BORDER)) / zoom_factor)
 
 NedFreeText::NedFreeText(char *text, GtkWidget *drawing_area, int anchor,  unsigned int tempo, bool enable_tempo, unsigned int volume, bool enable_volume,
-			unsigned short segno_sign, const char *font_family, double font_size, PangoStyle font_slant, PangoWeight font_weight) : NedFreeReplaceable(),
+			unsigned short segno_sign, int midi_pgm, unsigned int channel, bool enable_channel, const char *font_family, double font_size, PangoStyle font_slant, PangoWeight font_weight) : NedFreeReplaceable(),
 		m_midi_volume(volume), m_enable_volume_change(enable_volume), m_enable_tempo_change(enable_tempo), m_segno_sign(segno_sign), 
+			m_midi_pgm(midi_pgm), m_channel(channel), m_enable_channel(enable_channel),
 			m_font_family(font_family), m_font_size(font_size), m_font_slant(font_slant), m_font_weight(font_weight), m_anchor(anchor), m_tempo(tempo),
 			m_text(NULL), m_drawing_area(drawing_area) {
 		if (text != NULL) {
@@ -45,10 +46,10 @@ NedFreeText::NedFreeText(char *text, GtkWidget *drawing_area, int anchor,  unsig
 }
 
 NedFreeText::NedFreeText(char *text, GtkWidget *drawing_area, int anchor,  unsigned int tempo, bool enable_tempo, unsigned int volume, bool enable_volume,
-		unsigned short segno_sign, const char *font_family, double font_size, PangoStyle font_slant, PangoWeight font_weight, 
+		unsigned short segno_sign, int midi_pgm, unsigned int channel, bool enable_channel, const char *font_family, double font_size, PangoStyle font_slant, PangoWeight font_weight, 
 		NedChordOrRest *element) : NedFreeReplaceable(element), 
 			m_midi_volume(volume), m_enable_volume_change(enable_volume), m_enable_tempo_change(enable_tempo),
-			m_segno_sign(segno_sign), m_font_family(font_family),
+			m_segno_sign(segno_sign), m_midi_pgm(midi_pgm), m_channel(channel), m_enable_channel(enable_channel), m_font_family(font_family),
 			m_font_size(font_size), m_font_slant(font_slant), m_font_weight(font_weight), m_anchor(anchor), m_tempo(tempo),
 			m_text(NULL), m_drawing_area(drawing_area) {
 		if (text != NULL) {
@@ -57,10 +58,11 @@ NedFreeText::NedFreeText(char *text, GtkWidget *drawing_area, int anchor,  unsig
 }
 
 NedFreeText::NedFreeText(char *text, GtkWidget *drawing_area, int anchor,  unsigned int tempo, bool enable_tempo, unsigned int volume, bool enable_volume,
-		unsigned short segno_sign, const char *font_family, double font_size, PangoStyle font_slant, PangoWeight font_weight, 
+		unsigned short segno_sign, int midi_pgm, unsigned int channel, bool enable_channel, const char *font_family, double font_size, PangoStyle font_slant, PangoWeight font_weight, 
 		NedChordOrRest *element, double x, double y, bool relative) :
 			NedFreeReplaceable(element, x, y, relative), 
-		m_midi_volume(volume), m_enable_volume_change(enable_volume), m_enable_tempo_change(enable_tempo), m_segno_sign(segno_sign),
+		m_midi_volume(volume), m_enable_volume_change(enable_volume), m_enable_tempo_change(enable_tempo), m_segno_sign(segno_sign), m_midi_pgm(midi_pgm),
+			 m_channel(channel), m_enable_channel(enable_channel),
 			m_font_family(font_family), m_font_size(font_size),
 			m_font_slant(font_slant), m_font_weight(font_weight), m_anchor(anchor), m_tempo(tempo),
 			m_text(NULL), m_drawing_area(drawing_area) {
@@ -82,7 +84,7 @@ NedFreeReplaceable *NedFreeText::clone(struct addr_ref_str **slurlist, NedChordO
 	}
 	strcpy((char *) nfamily, m_font_family);
 	NedFreeText *freetext = new NedFreeText(m_text->getText(), drawing_area, m_anchor, m_tempo, m_enable_tempo_change, m_midi_volume, m_enable_volume_change,
-		m_segno_sign, nfamily, m_font_size, m_font_slant, m_font_weight, newelement, m_x, m_y, true);
+		m_segno_sign, m_midi_pgm, m_enable_channel, m_channel, nfamily, m_font_size, m_font_slant, m_font_weight, newelement, m_x, m_y, true);
 	return freetext;
 }
 
@@ -101,11 +103,15 @@ void NedFreeText::startContextDialog(GtkWidget *ref) {
 	int new_anchor;
 	unsigned int newvolume;
 	unsigned int newtempo;
+	unsigned int newchannel;
+	bool newenable_channel;
+	int new_midi_pgm;
 	double newfont_size;
 
 	NedTextDialog *dialog = new NedTextDialog (GTK_WINDOW(ref), m_text->getText(), m_anchor, m_tempo, m_enable_tempo_change, m_midi_volume, m_enable_volume_change,
-		m_segno_sign, m_font_family, m_font_size, m_font_slant, m_font_weight);
-	dialog->getValues(&state, &newtext, &new_anchor, &newtempo, &newenable_tempo, &newvolume, &newenable_volume, &newsegno_sign, &newfont_family, &newfont_size, &newfont_slant, &newfont_weight);
+		m_segno_sign, m_midi_pgm, m_channel, m_enable_channel, m_font_family, m_font_size, m_font_slant, m_font_weight);
+	dialog->getValues(&state, &newtext, &new_anchor, &newtempo, &newenable_tempo, &newvolume, &newenable_volume, &newsegno_sign, &new_midi_pgm,
+		&newchannel, &newenable_channel, &newfont_family, &newfont_size, &newfont_slant, &newfont_weight);
 	if (state) {
 		if (m_text != NULL) {
 			delete m_text;
@@ -119,6 +125,9 @@ void NedFreeText::startContextDialog(GtkWidget *ref) {
 				m_midi_volume = newvolume;
 				m_enable_volume_change = newenable_volume;
 				m_segno_sign = newsegno_sign;
+				m_midi_pgm = new_midi_pgm;
+				m_channel = newchannel;
+				m_enable_channel = newenable_channel;
 				m_font_family = newfont_family;
 				m_font_size = newfont_size;
 				m_font_slant = newfont_slant;
@@ -233,4 +242,5 @@ void NedFreeText::getLilyText(char *s) {
 			*s = *cptr;
 		}
 	}
+	*s = '\0';
 }
