@@ -34,12 +34,12 @@ class NedPangoCairoText;
 class NedFreeText : public NedFreeReplaceable {
 	public:
 		NedFreeText(char *text, GtkWidget *drawing_area, int anchor, unsigned int tempo, bool enable_tempo, unsigned int volume, bool enable_volume,
-				unsigned short segno_sign, const char *font_family, double font_size, PangoStyle font_slant, PangoWeight font_weight);
+				unsigned short segno_sign, int midi_pgm, unsigned int channel, bool enable_channel, const char *font_family, double font_size, PangoStyle font_slant, PangoWeight font_weight);
 		NedFreeText(char *text, GtkWidget *drawing_area, int anchor, unsigned int tempo, bool enable_tempo, unsigned int volume, bool enable_volume, 
-					unsigned short segno_sign, const char *font_family, double font_size, PangoStyle font_slant, PangoWeight font_weight,
+					unsigned short segno_sign, int midi_pgm, unsigned int channel, bool enable_channel, const char *font_family, double font_size, PangoStyle font_slant, PangoWeight font_weight,
 					NedChordOrRest *element);
 		NedFreeText(char *text, GtkWidget *drawing_area, int anchor, unsigned int tempo, bool enable_tempo, unsigned int volume, bool enable_volume,
-					unsigned short segno_sign, const char *font_family, double font_size, PangoStyle font_slant, PangoWeight font_weight,
+					unsigned short segno_sign, int midi_pgm, unsigned int channel, bool enable_channel, const char *font_family, double font_size, PangoStyle font_slant, PangoWeight font_weight,
 					NedChordOrRest *element,
 						double x, double y, bool relative);
 		virtual NedFreeReplaceable *clone(struct addr_ref_str **slurlist, NedChordOrRest *newelement, GtkWidget *drawing_area = NULL, NedMainWindow *main_window = NULL);
@@ -54,6 +54,9 @@ class NedFreeText : public NedFreeReplaceable {
 		unsigned int m_midi_volume;
 		bool m_enable_volume_change, m_enable_tempo_change;
 		unsigned short m_segno_sign;
+		int m_midi_pgm;
+		unsigned int m_channel;
+		bool m_enable_channel;
 		char *getText();
 		void getLilyText(char *s);
 		void setText(char *text, double zoom);
