@@ -23,6 +23,7 @@
 
 #define IDIOTSEDITOR_H
 #include "config.h"
+#include <X11/X.h>
 #include <X11/Xlib.h>
 #include <sys/time.h>
 #include <gtk/gtk.h>
@@ -32,6 +33,7 @@
 #include "paths.h"
 
 class NedIdiotsEditor;
+class NedIdCommandHistory;
 
 class pitch_info {
 	public:
@@ -58,6 +60,7 @@ class NedIdNote {
 			}
 
 		NedIdNote *cloneWithDifferentTime(unsigned long long sta, unsigned long long sto);
+		bool isInRect(double x, double y, double zoom_value, double xleft, double ytop);
 		void determineLines(int clef, int octave_shift, int key, char *offs_array);
 
 		~NedIdNote();
@@ -145,17 +148,18 @@ class NedIdKeysigChange : public NedIdSpecial {
 
 class NedIdiotsInstrument {
 	public:
-		NedIdiotsInstrument(int channel, int orig_channel, int midi_nr, int volume_change_density);
+		NedIdiotsInstrument(NedIdiotsEditor *id_edit,  int channel, int orig_channel, int midi_nr, int volume_change_density);
 		~NedIdiotsInstrument();
 		GList* trySplitInstrument(bool force_piano, bool dont_split);
 		void setInstNumber(int nr)  {m_inst_number = nr;}
-		void draw(Display *dpy, Window win, GC xgc, double zoom_value, double x, double y, double visible_start_pos, double visible_end_pos);
-		void draw_specials(cairo_t *cr, double zoom_value, double x, double y, double visible_start_pos, double visible_end_pos);
+		void draw(Display *dpy, Window win, GC xgc, GC border_gc, double zoom_value, double xleft, double ytop, double visible_start_pos, double visible_end_pos);
+		void draw_specials(cairo_t *cr, double zoom_value, double xleft, double ytop, double visible_start_pos, double visible_end_pos);
 		void closeNote(int pitch, unsigned long long end_time, int midi_nr);
 		int specCount();
 		void addNote(int pitch, int volume, unsigned long long  start, int midi_nr);
 		void addNote(NedIdNote *note);
 		void addKeySig(NedIdKeysigChange *kc);
+		void handle_button_press (GdkEventButton *event, double xleft, double ytop, double visible_start_pos, double visible_end_pos);
 		void enlargeNotesWithUnusualLength(NedIdiotsEditor *id);
 		void recognizeTriplets(NedIdiotsEditor *id);
 		void enlargeNotesToAvoidSmallRests(NedIdiotsEditor *id);
@@ -165,6 +169,7 @@ class NedIdiotsInstrument {
 		void setInstrumentName(char *name);
 		void snapStartOfNotes(NedIdiotsEditor *id);
 		void computeVolume();
+		void recomputeNotes(double zoom_value, double xleft, double ytop);
 		int getChannel() {return m_channel;}
 		int getClef() {return m_clef;}
 		int getOctaveShift() {return m_octave_shift;}
@@ -187,9 +192,11 @@ class NedIdiotsInstrument {
 		bool newVolumeNeeded(unsigned long long time, int *new_volume);
 		NedIdNote *findNote(GList *start, unsigned long long start_time, unsigned long long end_time, NedIdNote *not_note1, NedIdNote *not_note2);
                 void notesAus(char *s, int i);
+		NedIdiotsEditor *m_id_edit;
 		int m_clef, m_octave_shift;
 		GList *m_notes[VOICE_COUNT];
 		GList *m_specials;
+		NedIdNote *m_selected_note;
 		int m_inst_number;
 		int m_volume_change_density;
 		int m_midi_nr;
@@ -242,30 +249,48 @@ class NedIdiotsEditor {
 		int getChannel(int staff_nr);
 		int getVolume(int staff_nr);
 		int getKeySig(int staff_nr);
+		GtkWidget *getDrawingArea() {return m_drawing_area;}
+		GdkCursor *getPointCursor() {return m_pointer;}
+		GdkCursor *getFleurCursor() {return m_fleur;}
+		GdkCursor *getDoubldArrowCursor() {return m_double_arrow;}
+		NedIdCommandHistory *getCommandHistory() {return m_command_history;}
+		double getOffX() {return m_off_x;}
+		double getOffY() {return m_off_y;}
+		double getZoomValue() {return m_zoom_value;}
+		unsigned int getMinDenom() {return m_min_denom;}
+		
+		void repaint();
 		double m_tempo_inverse;
+		int motion_mode;
 	private:
 		void correct_times_of_specials();
 		bool delete_double_specials();
+		void initX11();
+		GdkCursor *m_double_arrow, *m_pointer, *m_fleur;
 		static const char *guiDescription;
 		static const GtkActionEntry file_entries[];
 		static gboolean handle_expose(GtkWidget *widget, GdkEventExpose *event, gpointer data);
-		void  draw_piano(cairo_t *cr, double y, int height);
+		void  draw_piano(cairo_t *cr, double ytop, int height);
 		static void select_instrument(GtkButton *button, gpointer data);
 		static void zoom_in(GtkWidget  *widget, void *data);
 		static void zoom_out(GtkWidget  *widget, void *data);
 		static void size_change_handler(GtkWidget *widget, GtkRequisition *requisition, gpointer data);
 		static void handle_scroll(GtkAdjustment *adjustment, gpointer data);
-		static void handle_map_event(GtkWidget *widget, gpointer data);
-
+		static gboolean handle_button_press (GtkWidget *widget,
+			 GdkEventButton *event, gpointer data);
+		static gboolean handle_motion (GtkWidget *widget, GdkEventMotion *event, gpointer data);
+		static gboolean handle_button_release (GtkWidget *widget,
+			 GdkEventButton *event, gpointer data);
+		static void do_undo(GtkWidget  *widget, void *data);
+		static void do_redo(GtkWidget  *widget, void *data);
 		void getNumDenom(unsigned long long time, unsigned int *num, unsigned int *denom);
 		static const char *pitch_tab[];
 #ifdef ORIORI
 		void draw();
 #endif
 		void draw_new();
-		void draw_specials (cairo_t *cr, double zoom_value, double x, double y, int width, double visible_start_pos, double visible_end_pos);
+		void draw_specials (cairo_t *cr, double zoom_value, double xleft, double ytop, int width, double visible_start_pos, double visible_end_pos);
 		void thin_out_temposigs();
-		void repaint();
 		void setHadjust();
 		void setVadjust();
 		double m_zoom_value;
@@ -289,13 +314,18 @@ class NedIdiotsEditor {
 		bool m_sort_according_instrument;
 		bool m_dont_split;
 		bool m_X11version;
+		unsigned int m_min_denom;
+		NedIdCommandHistory *m_command_history;
 
 		GList *m_instruments;
 		GList *m_specials;
 
+		double m_mouse_x, m_mouse_y;
+		double m_off_x, m_off_y;
+
 		Display *m_dpy;
 		Window m_win;
-		GC m_xgc;
+		GC m_xgc, m_x_border_gc;
 		Pixmap m_back_image;
 		int m_screen;
 
