@@ -77,7 +77,7 @@ struct staff_context_str {
 #define CON_BAR_START (1 << 4)
 #define CON_BAR_END   (1 << 5)
 	int m_pitch_offs;
-	bool m_muted;
+	bool m_muted[VOICE_COUNT];
 
 };
 
@@ -166,6 +166,7 @@ class NedMainWindow {
 		bool hasFocus();
 		int getLyricsMode();
 		void collectLyrics(NedLyricsEditor *leditor, int staff_nr);
+		void updateLyrics(NedLyricsEditor *leditor, int staff_nr);
 		NedCommandHistory *getCommandHistory() {return m_command_history;}
 		double getLeftX();
 		double getTopY();
