@@ -33,7 +33,7 @@
 #define X_PS_POS(p) ((DEFAULT_BORDER + LEFT_RIGHT_BORDER + (p)) * PS_ZOOM)
 #define Y_PS_POS_SYS_REL(p) ((page_height - ((p) + sys_y_pos)) * PS_ZOOM)
 
-NedMeasure::NedMeasure() : m_spread_fac(1.0), m_hide_following(false), m_measure_number(1), m_special_descr(NULL) {
+NedMeasure::NedMeasure() : m_staff_elements_width(0.0), m_measure_has_only_staff_members(false), m_spread_fac(1.0), m_special_spread(false), m_hide_following(false), m_measure_number(1), m_special_descr(NULL) {
 	m_measure_number_str[0] = '1';
 	m_measure_number_str[1] = '\0';
 }
@@ -88,11 +88,14 @@ double NedMeasure::shiftXpos(double extra_space_divided, double shift, bool out)
 	return shift;
 }
 
-double NedMeasure::computeAndSetPositions(double start_position, int *num_elements, double *extra_space_for_accidentals, bool out) {
+double NedMeasure::computeAndSetPositions(double start_position, int *num_elements, double *extra_space_for_accidentals, bool *measure_has_only_staff_members /* means keysig */, bool out) {
+	
+	double timesig_space = (m_special_descr && (m_special_descr->type & TIMESIG_TYPE_MASK)) ? TIME_SIG_WIDTH : 0.0;
 	start_position += getNeededSpaceAfter();
 	start = start_position;
 	start_position += getNeededSpaceBefore();
-	start_position = m_position_array.computeAndSetPositions(start_position, num_elements, extra_space_for_accidentals, m_measure_number, m_spread_fac, out);
+	start_position = m_position_array.computeAndSetPositions(start_position, num_elements, extra_space_for_accidentals, measure_has_only_staff_members, timesig_space, m_measure_number, m_spread_fac, out);
+	m_measure_has_only_staff_members = *measure_has_only_staff_members;
 	end = start_position;
 	return start_position;
 }
@@ -112,7 +115,7 @@ bool NedMeasure::nearRepeatElement(double x, double y) {
 		staff_border_dist = staff->getTopYBorder();
 		double repyoffs = staff_border_dist;
 		if (staff_border_dist > -MIN_STAFF_BORDER_DIST) repyoffs = -MIN_STAFF_BORDER_DIST;
-		repyoffs -= SEC_DIST;
+		repyoffs += SEC_DIST_ABOVE;
 		double ydist = yy - (repyoffs + REP_NUM_YPOS - 4 * LINE_DIST);
 		if (ydist < 0.0) ydist = - ydist;
 		if (ydist > MIN_NEAR_DIST) continue;
@@ -130,34 +133,35 @@ bool NedMeasure::isNearEnd(double x) {
 
 double NedMeasure::getNeededSpaceBefore() {
 	if (m_special_descr == NULL) return MEAS_BAR_SPACE;
-	double timesig_offs = (m_special_descr->type & TIMESIG_TYPE_MASK) ? TIME_SIG_WIDTH : 0.0;
-	switch (m_special_descr->type & REP_TYPE_MASK) {
-		case REPEAT_OPEN: return REP_THICK_LINE_DIST + timesig_offs;
-		case REPEAT_OPEN_CLOSE: return REP_THICK_LINE_DIST + REP_DOTS_X_DIST + timesig_offs;
-		case REPEAT_CLOSE: return REP_THICK_LINE_DIST + REP_DOTS_X_DIST + timesig_offs;
-		case DOUBLE_BAR: return REP_DOUBLE_LINE_DIST + timesig_offs;
+	switch (m_special_descr->type & TIMESIG_TYPE_MASK) {
+		case TIMESIG: return TIME_SIGNATURE_SPACE;
 	}
-	if (m_special_descr->type & TIMESIG_TYPE_MASK) {
-		return TIME_SIG_WIDTH;
+	switch (m_special_descr->type & REP_TYPE_MASK) {
+		case REPEAT_OPEN_CLOSE: return REP_THICK_LINE_DIST + REP_DOTS_X_DIST + REP_DOTS_X_EXTRA_DIST;
+		case REPEAT_OPEN: return REP_THICK_LINE_DIST + REP_DOTS_X_DIST;
+		case REPEAT_CLOSE: return REP_THICK_LINE_DIST + REP_DOTS_X_DIST;
+		case DOUBLE_BAR: return REP_DOUBLE_LINE_DIST;
+		case END_BAR: return 4 * REP_DOUBLE_LINE_DIST;
 	}
 	return MEAS_BAR_SPACE;
 }
+
 double NedMeasure::getNeededSpaceAfter() {
 	if (m_special_descr == NULL) return MEAS_BAR_SPACE;
 
 	switch (m_special_descr->type & REP_TYPE_MASK) {
-		case REPEAT_OPEN_CLOSE: return 3 * REP_THICK_LINE_DIST + REP_DOTS_X_DIST + REP_DOTS_X_EXTRA_DIST;
-		case REPEAT_OPEN: return REP_THICK_LINE_DIST + REP_DOTS_X_DIST;
+		case REPEAT_OPEN_CLOSE: return REP_THICK_LINE_DIST + REP_DOTS_X_DIST + REP_DOTS_X_EXTRA_DIST;
+		case REPEAT_OPEN: return REP_THICK_LINE_DIST + REP_DOTS_X_DIST + REP_DOTS_X_EXTRA_DIST;
 		case REPEAT_CLOSE: return REP_THICK_LINE_DIST + REP_DOTS_X_DIST + REP_DOTS_X_EXTRA_DIST;
-		case END_BAR: return 2 * REP_THICK_LINE_DIST;
 		case DOUBLE_BAR: return 3 * REP_DOUBLE_LINE_DIST;
+		case END_BAR: return 4 * REP_DOUBLE_LINE_DIST;
 	}
 	return MEAS_BAR_SPACE;
 }
 
 
-void NedMeasure::draw(cairo_t *cr, int special_position, double xpos, double content_x_pos, double sys_y_pos, double top, double bottom, double bottom2, double bottom_ori, double leftx, double topy,
-			double staff_border_dist, double zoom_factor, int zoom_level, bool rep_line_needed, bool out) {
+void NedMeasure::draw(cairo_t *cr, int special_position, double xpos, double content_x_pos, double sys_y_pos, double top, double bottom, double bottom_ori, double leftx, double topy,
+			double staff_border_dist, double zoom_factor, int zoom_level, bool rep_line_needed, int spec_measure_at_end, bool out) {
 	double line_xpos, normal_line_pos = start;
 	double repyoffs;
 	double line_bottom = bottom;
@@ -174,7 +178,7 @@ void NedMeasure::draw(cairo_t *cr, int special_position, double xpos, double con
 		cairo_set_line_width(cr, zoom_factor * MEASURE_LINE_THICK);
 		repyoffs = staff_border_dist;
 		if (staff_border_dist > -MIN_STAFF_BORDER_DIST) repyoffs = -MIN_STAFF_BORDER_DIST;
-		repyoffs -= SEC_DIST;
+		repyoffs += SEC_DIST_ABOVE;
 		if (special_position == SPECIAL_POSITION_START) {
 			cairo_move_to(cr, X_POS_PAGE_REL(xpos), Y_POS_STAFF_REL(repyoffs));
 		}
@@ -192,10 +196,12 @@ void NedMeasure::draw(cairo_t *cr, int special_position, double xpos, double con
 		}
 	}
 	if (special_position == SPECIAL_POSITION_END) {
-		if (m_special_descr == NULL) return;
-		if ((m_special_descr->type & REP_TYPE_MASK) == REPEAT_OPEN) return;
-		if ((m_special_descr->type & REP_TYPE_MASK) == REPEAT_OPEN_CLOSE) {
-			realtype = REPEAT_CLOSE;
+		normal_line_pos = xpos;
+		if (m_special_descr != NULL) {
+			//if ((m_special_descr->type & REP_TYPE_MASK) == REPEAT_OPEN) return;
+			if ((m_special_descr->type & REP_TYPE_MASK) == REPEAT_OPEN_CLOSE) {
+				realtype = REPEAT_CLOSE;
+			}
 		}
 	}
 	if (m_special_descr != NULL) {
@@ -204,7 +210,7 @@ void NedMeasure::draw(cairo_t *cr, int special_position, double xpos, double con
 					line_xpos = (special_position == SPECIAL_POSITION_START) ? xpos : start;
 					repyoffs = staff_border_dist;
 					if (staff_border_dist > -MIN_STAFF_BORDER_DIST) repyoffs = -MIN_STAFF_BORDER_DIST;
-					repyoffs -= SEC_DIST;
+					repyoffs += SEC_DIST_ABOVE;
 					cairo_new_path(cr);
 					cairo_set_line_width(cr, zoom_factor *  MEASURE_LINE_THICK);
 					cairo_move_to(cr, X_POS_PAGE_REL(line_xpos), Y_POS_STAFF_REL(0));
@@ -234,7 +240,7 @@ void NedMeasure::draw(cairo_t *cr, int special_position, double xpos, double con
 					line_xpos = (special_position == SPECIAL_POSITION_START) ? xpos : start;
 					repyoffs = staff_border_dist;
 					if (staff_border_dist > -MIN_STAFF_BORDER_DIST) repyoffs = -MIN_STAFF_BORDER_DIST;
-					repyoffs -= SEC_DIST;
+					repyoffs += SEC_DIST_ABOVE;
 					cairo_new_path(cr);
 					cairo_set_line_width(cr, zoom_factor *  MEASURE_LINE_THICK);
 					cairo_move_to(cr, X_POS_PAGE_REL(line_xpos), Y_POS_STAFF_REL(0));
@@ -264,7 +270,7 @@ void NedMeasure::draw(cairo_t *cr, int special_position, double xpos, double con
 			case REP1END:   if (special_position == SPECIAL_POSITION_START) break;
 					repyoffs = staff_border_dist;
 					if (staff_border_dist > -MIN_STAFF_BORDER_DIST) repyoffs = -MIN_STAFF_BORDER_DIST;
-					repyoffs -= SEC_DIST;
+					repyoffs += SEC_DIST_ABOVE;
 					cairo_new_path(cr);
 					cairo_set_line_width(cr, zoom_factor *  MEASURE_LINE_THICK);
 					cairo_move_to(cr, X_POS_PAGE_REL(start), Y_POS_STAFF_REL(0));
@@ -279,6 +285,7 @@ void NedMeasure::draw(cairo_t *cr, int special_position, double xpos, double con
 		switch (realtype & REP_TYPE_MASK) {
 #define REP_OPEN_START_LINE_DIST 0.2
 			case REPEAT_OPEN:
+				if (special_position == SPECIAL_POSITION_END) break;
 				line_xpos = (special_position == SPECIAL_POSITION_START) ? xpos + REP_OPEN_START_LINE_DIST : start;
 				if (special_position == SPECIAL_POSITION_START) {
 					normal_line_pos = line_xpos;
@@ -294,42 +301,41 @@ void NedMeasure::draw(cairo_t *cr, int special_position, double xpos, double con
 				sig_xpos += REP_DOTS_X_DIST;
 				break;
 			case REPEAT_CLOSE:
+				if (special_position == SPECIAL_POSITION_END && spec_measure_at_end) break;
 				line_xpos = (special_position == SPECIAL_POSITION_END) ? xpos : start;
 				cairo_new_path(cr);
-				cairo_set_line_width(cr, zoom_factor * ((special_position == SPECIAL_POSITION_END) ? REPEAT_MEASURE_LINE_THICK : MEASURE_LINE_THICK));
+				cairo_set_line_width(cr, zoom_factor * REPEAT_MEASURE_LINE_THICK);
+				cairo_move_to(cr, X_POS_PAGE_REL(line_xpos), Y_POS_SYS_REL(top));
+				cairo_line_to(cr, X_POS_PAGE_REL(line_xpos), Y_POS_SYS_REL(bottom));
+				cairo_stroke(cr);
+				cairo_new_path(cr);
+				cairo_set_line_width(cr, zoom_factor * MEASURE_LINE_THICK);
 				cairo_move_to(cr, X_POS_PAGE_REL(line_xpos - REP_THICK_LINE_DIST), Y_POS_SYS_REL(top));
 				cairo_line_to(cr, X_POS_PAGE_REL(line_xpos - REP_THICK_LINE_DIST), Y_POS_SYS_REL(bottom));
 				cairo_stroke(cr);
-				if (special_position != SPECIAL_POSITION_END) {
-					cairo_new_path(cr);
-					cairo_set_line_width(cr, zoom_factor * REPEAT_MEASURE_LINE_THICK);
-					cairo_move_to(cr, X_POS_PAGE_REL(line_xpos), Y_POS_SYS_REL(top));
-					cairo_line_to(cr, X_POS_PAGE_REL(line_xpos), Y_POS_SYS_REL(bottom));
-					cairo_stroke(cr);
-				}
 				cairo_arc(cr, X_POS_PAGE_REL(line_xpos - REP_THICK_LINE_DIST - REP_DOTS_X_DIST), Y_POS_SYS_REL(bottom_ori - REP_DOTS_Y1DIST), zoom_factor * REP_DOTS_RADIUS, 0.0, 2.0 * M_PI);
 				cairo_arc(cr, X_POS_PAGE_REL(line_xpos - REP_THICK_LINE_DIST - REP_DOTS_X_DIST), Y_POS_SYS_REL(bottom_ori - REP_DOTS_Y2DIST), zoom_factor * REP_DOTS_RADIUS, 0.0, 2.0 * M_PI);
 				cairo_fill(cr);
 				draw_default_line = false;
 				break;
 			case END_BAR:
+				if (special_position == SPECIAL_POSITION_END && spec_measure_at_end) break;
 				if (special_position == SPECIAL_POSITION_START) return;
 				line_xpos = (special_position == SPECIAL_POSITION_END) ? xpos : start;
 				cairo_new_path(cr);
-				cairo_set_line_width(cr, zoom_factor * ((special_position == SPECIAL_POSITION_END) ? REPEAT_MEASURE_LINE_THICK : MEASURE_LINE_THICK));
+				cairo_set_line_width(cr, zoom_factor * REPEAT_MEASURE_LINE_THICK);
+				cairo_move_to(cr, X_POS_PAGE_REL(line_xpos), Y_POS_SYS_REL(top));
+				cairo_line_to(cr, X_POS_PAGE_REL(line_xpos), Y_POS_SYS_REL(bottom));
+				cairo_stroke(cr);
+				cairo_new_path(cr);
+				cairo_set_line_width(cr, zoom_factor * MEASURE_LINE_THICK);
 				cairo_move_to(cr, X_POS_PAGE_REL(line_xpos - REP_THICK_LINE_DIST), Y_POS_SYS_REL(top));
-				cairo_line_to(cr, X_POS_PAGE_REL(line_xpos - REP_THICK_LINE_DIST), Y_POS_SYS_REL(bottom2));
+				cairo_line_to(cr, X_POS_PAGE_REL(line_xpos - REP_THICK_LINE_DIST), Y_POS_SYS_REL(bottom));
 				cairo_stroke(cr);
-				if (special_position != SPECIAL_POSITION_END) {
-					cairo_new_path(cr);
-					cairo_set_line_width(cr, zoom_factor * REPEAT_MEASURE_LINE_THICK);
-					cairo_move_to(cr, X_POS_PAGE_REL(line_xpos), Y_POS_SYS_REL(top));
-					cairo_line_to(cr, X_POS_PAGE_REL(line_xpos), Y_POS_SYS_REL(bottom2));
-					cairo_stroke(cr);
-				}
 				draw_default_line = false;
 				break;
 			case DOUBLE_BAR:
+				if (special_position == SPECIAL_POSITION_END && spec_measure_at_end) break;
 				if (special_position == SPECIAL_POSITION_START) return;
 				line_xpos = (special_position == SPECIAL_POSITION_END) ? xpos : start;
 				cairo_new_path(cr);
@@ -339,6 +345,7 @@ void NedMeasure::draw(cairo_t *cr, int special_position, double xpos, double con
 				cairo_stroke(cr);
 				break;
 			case REPEAT_OPEN_CLOSE:
+				if (special_position == SPECIAL_POSITION_END && spec_measure_at_end) break;
 				cairo_new_path(cr);
 				cairo_set_line_width(cr, zoom_factor * REPEAT_MEASURE_LINE_THICK);
 				cairo_move_to(cr, X_POS_PAGE_REL(start), Y_POS_SYS_REL(top));
@@ -356,59 +363,81 @@ void NedMeasure::draw(cairo_t *cr, int special_position, double xpos, double con
 				cairo_arc(cr, X_POS_PAGE_REL(start + REP_THICK_LINE_DIST + REP_DOTS_X_DIST), Y_POS_SYS_REL(bottom_ori - REP_DOTS_Y2DIST), zoom_factor * REP_DOTS_RADIUS, 0.0, 2.0 * M_PI);
 				cairo_fill(cr);
 				cairo_new_path(cr);
-				cairo_arc(cr, X_POS_PAGE_REL(start - REP_THICK_LINE_DIST - REP_DOTS_X_DIST), Y_POS_SYS_REL(bottom - REP_DOTS_Y1DIST), zoom_factor * REP_DOTS_RADIUS, 0.0, 2.0 * M_PI);
-				cairo_arc(cr, X_POS_PAGE_REL(start - REP_THICK_LINE_DIST - REP_DOTS_X_DIST), Y_POS_SYS_REL(bottom - REP_DOTS_Y2DIST), zoom_factor * REP_DOTS_RADIUS, 0.0, 2.0 * M_PI);
+				cairo_arc(cr, X_POS_PAGE_REL(start - REP_THICK_LINE_DIST - REP_DOTS_X_DIST), Y_POS_SYS_REL(bottom_ori - REP_DOTS_Y1DIST), zoom_factor * REP_DOTS_RADIUS, 0.0, 2.0 * M_PI);
+				cairo_arc(cr, X_POS_PAGE_REL(start - REP_THICK_LINE_DIST - REP_DOTS_X_DIST), Y_POS_SYS_REL(bottom_ori - REP_DOTS_Y2DIST), zoom_factor * REP_DOTS_RADIUS, 0.0, 2.0 * M_PI);
 				cairo_fill(cr);
 				sig_xpos += 2 * REP_DOTS_X_DIST;
-				draw_default_line = false;
+				//draw_default_line = false;
 				break;
 		}
 		switch (realtype & TIMESIG_TYPE_MASK) {
 			case TIMESIG: 
-				if (special_position == SPECIAL_POSITION_START || special_position == SPECIAL_POSITION_END) return;
+				if (special_position == SPECIAL_POSITION_START) {
+					if ((realtype & REP_TYPE_MASK) == 0) return;
+					break;
+				}
+				if (special_position == SPECIAL_POSITION_END && spec_measure_at_end) return;
 				cairo_glyph_t glyph[2];
 				int n;
-				cairo_new_path(cr);
-				n = m_special_descr->numerator;
-				if (n > 9) {
-					glyph[0].index = NUMBERBASE + n / 10;
-					glyph[0].x =  X_POS_PAGE_REL(sig_xpos - SIG_HALF);
-					glyph[0].y = Y_POS_STAFF_REL(Y_NUMRATOR_POS + 4 * LINE_DIST);
-					glyph[1].index = NUMBERBASE + n % 10;
-					glyph[1].x =  X_POS_PAGE_REL(sig_xpos + SIG_HALF);
-					glyph[1].y = Y_POS_STAFF_REL(Y_NUMRATOR_POS + 4 * LINE_DIST);
-					cairo_show_glyphs(cr, glyph, 2);
-				}
-				else {
-			
-					glyph[0].index = NUMBERBASE + n;
-					glyph[0].x =  X_POS_PAGE_REL(sig_xpos);
-					glyph[0].y = Y_POS_STAFF_REL(Y_NUMRATOR_POS + 4 * LINE_DIST);
-					cairo_show_glyphs(cr, glyph, 1);
-				}
-				n = m_special_descr->denominator;
-				if (n > 9) {
-					glyph[0].index = NUMBERBASE + n / 10;
-					glyph[0].x =  X_POS_PAGE_REL(sig_xpos - SIG_HALF);
-					glyph[0].y = Y_POS_STAFF_REL(Y_DENOMINATOR_POS + 4 * LINE_DIST);
-					glyph[1].index = NUMBERBASE + n % 10;
-					glyph[1].x =  X_POS_PAGE_REL(sig_xpos + SIG_HALF);
-					glyph[1].y = Y_POS_STAFF_REL(Y_DENOMINATOR_POS + 4 * LINE_DIST);
-					cairo_show_glyphs(cr, glyph, 2);
-				}
-				else {
-					glyph[0].index = NUMBERBASE + n;
-					glyph[0].x =  X_POS_PAGE_REL(sig_xpos);
-					glyph[0].y = Y_POS_STAFF_REL(Y_DENOMINATOR_POS + 4 * LINE_DIST);
-					cairo_show_glyphs(cr, glyph, 1);
-				}
-				cairo_stroke(cr);
+				switch (m_special_descr->symbol) {
+					case TIME_SYMBOL_COMMON_TIME:
+						glyph[0].index = BASE + 56;
+						glyph[0].x = X_POS_PAGE_REL(sig_xpos + m_staff_elements_width);
+						glyph[0].y = Y_POS_STAFF_REL(5 * LINE_DIST/2.0);
+						cairo_show_glyphs(cr, glyph, 1);
+						cairo_stroke(cr);
+						break;
+					case TIME_SYMBOL_CUT_TIME:
+						glyph[0].index = BASE + 57;
+						glyph[0].x = X_POS_PAGE_REL(sig_xpos + m_staff_elements_width);
+						glyph[0].y = Y_POS_STAFF_REL(5 * LINE_DIST/2.0);
+						cairo_show_glyphs(cr, glyph, 1);
+						cairo_stroke(cr);
+						break;
+					default:
+						cairo_new_path(cr);
+						n = m_special_descr->numerator;
+						if (n > 9) {
+							glyph[0].index = NUMBERBASE + n / 10;
+							glyph[0].x =  X_POS_PAGE_REL(sig_xpos + m_staff_elements_width - SIG_HALF);
+							glyph[0].y = Y_POS_STAFF_REL(Y_NUMRATOR_POS + 4 * LINE_DIST);
+							glyph[1].index = NUMBERBASE + n % 10;
+							glyph[1].x =  X_POS_PAGE_REL(sig_xpos + m_staff_elements_width + SIG_HALF);
+							glyph[1].y = Y_POS_STAFF_REL(Y_NUMRATOR_POS + 4 * LINE_DIST);
+							cairo_show_glyphs(cr, glyph, 2);
+						}
+						else {
+					
+							glyph[0].index = NUMBERBASE + n;
+							glyph[0].x =  X_POS_PAGE_REL(sig_xpos + m_staff_elements_width);
+							glyph[0].y = Y_POS_STAFF_REL(Y_NUMRATOR_POS + 4 * LINE_DIST);
+							cairo_show_glyphs(cr, glyph, 1);
+						}
+						n = m_special_descr->denominator;
+						if (n > 9) {
+							glyph[0].index = NUMBERBASE + n / 10;
+							glyph[0].x =  X_POS_PAGE_REL(sig_xpos + m_staff_elements_width - SIG_HALF);
+							glyph[0].y = Y_POS_STAFF_REL(Y_DENOMINATOR_POS + 4 * LINE_DIST);
+							glyph[1].index = NUMBERBASE + n % 10;
+							glyph[1].x =  X_POS_PAGE_REL(sig_xpos + m_staff_elements_width + SIG_HALF);
+							glyph[1].y = Y_POS_STAFF_REL(Y_DENOMINATOR_POS + 4 * LINE_DIST);
+							cairo_show_glyphs(cr, glyph, 2);
+						}
+						else {
+							glyph[0].index = NUMBERBASE + n;
+							glyph[0].x =  X_POS_PAGE_REL(sig_xpos + m_staff_elements_width);
+							glyph[0].y = Y_POS_STAFF_REL(Y_DENOMINATOR_POS + 4 * LINE_DIST);
+							cairo_show_glyphs(cr, glyph, 1);
+						}
+						cairo_stroke(cr);
+						break;
+					}
 				break;
 		}
 	}
-	if (special_position == SPECIAL_POSITION_END || !draw_default_line) return;
+	if ((special_position == SPECIAL_POSITION_END && spec_measure_at_end) || !draw_default_line) return;
 	cairo_new_path(cr);
-	cairo_set_line_width(cr, zoom_factor * MEASURE_LINE_THICK);
+	cairo_set_line_width(cr, zoom_factor * ((special_position == SPECIAL_POSITION_END) ? 2 * MEASURE_LINE_THICK : MEASURE_LINE_THICK));
 	cairo_move_to(cr, X_POS_PAGE_REL(normal_line_pos), Y_POS_SYS_REL(top));
 	cairo_line_to(cr, X_POS_PAGE_REL(normal_line_pos), Y_POS_SYS_REL(line_bottom));
 //#define SHOW_MEAS_NUM
