@@ -42,6 +42,8 @@ class NedMeasure {
 		void setSystem(NedSystem *system) {m_system = system;}
 		void setMeasureNumber(int num, GList *special_measures, bool force = false);
 		unsigned int getMeasureDuration() {return (unsigned int) (midi_end - midi_start);}
+		double m_staff_elements_width; // width of leading keysigs and timesigs
+		bool m_measure_has_only_staff_members;
 		int position;
 		int getSpecial();
 		void setSpecial(int type);
@@ -51,11 +53,11 @@ class NedMeasure {
 		char *getNumberString() {return m_measure_number_str;}
 		int getMeasureNumber() {return m_measure_number;}
 		void draw(cairo_t *cr, int special_position, double xpos, double content_x_pos, double sys_y_pos, double top, 
-			double bottom, double bottom2, double bottom_ori, double leftx, double topy, double staff_border_dist, double zoom_factor, int zoom_level, bool rep_line_needed, bool out);
+			double bottom, double bottom_ori, double leftx, double topy, double staff_border_dist, double zoom_factor, int zoom_level, bool rep_line_needed, int spec_measure_at_end, bool out);
 		double getNeededSpaceBefore();
 		double getNeededSpaceAfter();
 		double shiftXpos(double extra_space_divided, double shift, bool out);
-		double computeAndSetPositions(double start_position, int *num_elements, double *extra_space_for_accidentals, bool out);
+		double computeAndSetPositions(double start_position, int *num_elements, double *extra_space_for_accidentals, bool *measure_has_only_staff_members /* means keysig */, bool out);
 		bool isNearStart(double x);
 		bool isNearEnd(double x);
 		bool nearRepeatElement(double x, double y);
@@ -64,6 +66,7 @@ class NedMeasure {
 		NedPositionArray m_position_array;
 		int getStemDirectionOfTheMeasure(int staff_voice_offs) {return m_position_array.getStemDirectionOfTheMeasure(staff_voice_offs);}
 		double m_spread_fac;
+		bool m_special_spread;
 		bool m_hide_following;
 	private:
 		int m_measure_number;
