@@ -44,6 +44,7 @@
 
 
 static unsigned char trackend[] = {0x00, 0xff , 0x2f, 0x00};
+unsigned char NedMidiExport::m_channel_pgms[16];
 
 bool NedMidiExport::m_first_lyrics = true;
 
@@ -125,8 +126,17 @@ void NedMidiExport::writeTime(unsigned long long  time) {
 	writeByte(b);
 }
 
-void NedMidiExport::writeNoteOn(unsigned long long  time, unsigned char ch, unsigned char ptch, unsigned char vel) {
-	writeTime(time);
+void NedMidiExport::writeNoteOn(unsigned long long  time, unsigned char ch, unsigned char ptch, unsigned char vel, unsigned char pgm) {
+	if (m_channel_pgms[ch] != pgm) {
+		writeTime(time);
+		writeByte(0xc0 | ch);
+		writeByte(pgm);
+		writeTime(0);
+		m_channel_pgms[ch] = pgm;
+	}
+	else {
+		writeTime(time);
+	}
 	writeByte(0x90 | ch);
 	writeByte(ptch);
 	writeByte(vel);
@@ -143,6 +153,7 @@ void NedMidiExport::writePgmChange(unsigned long long  time, unsigned char chn,
 	writeTime(time);
 	writeByte(0xc0 | chn);
 	writeByte(pgm);
+	m_channel_pgms[chn] = pgm;
 }
 
 
@@ -159,6 +170,8 @@ void NedMidiExport::exportMidi(FILE *fp, NedMainWindow *main_window, char *midit
 	int track_nr;
 	m_first_lyrics = true;
 
+	for (track_nr = 0; track_nr < 16; m_channel_pgms[track_nr++] = 0);
+
 	
 	writeString(strdup("MThd"));
 	writeDWord(6);
@@ -319,6 +332,9 @@ void NedMidiExport::writeCtrlTrack(char *Title, char *miditext, NedMainWindow *m
 	for (lptr = g_list_first(spec_events); lptr; lptr = g_list_next(lptr)) {
 		delete ((special_events *) lptr->data);
 	}
+	for (lptr = g_list_first(tempo_chords); lptr; lptr = g_list_next(lptr)) {
+		g_free(lptr->data);
+	}
 	g_list_free(spec_events);
 	spec_events = NULL;
 	g_list_free(tempo_chords);
@@ -353,15 +369,14 @@ void NedMidiExport::writeTrack(GList *midi_events, int track_nr, int num, int de
 	}
 	writeTimeSig(0, m_main_window->getNumerator(), m_main_window->getDenominator());
 	writeKeySig(0, m_main_window->m_staff_contexts[track_nr].m_key_signature_number);
-	writePgmChange(0, channel, m_main_window->m_staff_contexts[track_nr].m_midi_program);
+	writePgmChange(0, channel, m_main_window->m_staff_contexts[track_nr].voices[0].m_midi_program);
 	writeCtlChange(0, channel, MIDI_CTL_REVERB, m_main_window->m_staff_contexts[track_nr].m_midi_reverb);
 	writeCtlChange(0, channel, MIDI_CTL_CHORUS, m_main_window->m_staff_contexts[track_nr].m_midi_chorus);
-	writeCtlChange(0, channel, MIDI_CTL_PAN, m_main_window->m_staff_contexts[track_nr].m_midi_pan);
+	writeCtlChange(0, channel, MIDI_CTL_PAN, m_main_window->m_staff_contexts[track_nr].voices[0].m_midi_pan);
 
 	for (lptr1 = g_list_first(midi_events); lptr1; lptr1 = g_list_next(lptr1)) {
 		time_written = FALSE;
-		lptr2 = (GList *) g_list_first((GList *) (lptr1->data));
-		for (lptr2 = (GList *) g_list_first((GList *) (lptr1->data)); lptr2; lptr2 = g_list_next(lptr2)) {
+		for (lptr2 = g_list_first(((MidiListStruct *) lptr1->data)->notes); lptr2; lptr2 = g_list_next(lptr2)) {
 			if (((MidiEventStruct *) lptr2->data)->channel != channel) continue;
 			switch (((MidiEventStruct *) lptr2->data)->type) {
 				case SND_SEQ_EVENT_NOTEOFF: if (((MidiEventStruct *) lptr2->data)->note->getTieForward() == NULL) {
@@ -378,7 +393,7 @@ void NedMidiExport::writeTrack(GList *midi_events, int track_nr, int num, int de
 							    break;
 			}
 		}
-		for (lptr2 = (GList *) g_list_first((GList *) (lptr1->data)); lptr2; lptr2 = g_list_next(lptr2)) {
+		for (lptr2 = g_list_first(((MidiListStruct *) lptr1->data)->notes); lptr2; lptr2 = g_list_next(lptr2)) {
 			if (((MidiEventStruct *) lptr2->data)->channel != channel) continue;
 			switch (((MidiEventStruct *) lptr2->data)->type) {
 				case PSEUDO_EVENT_KEY_CHANGE: if (time_written) {
@@ -391,20 +406,9 @@ void NedMidiExport::writeTrack(GList *midi_events, int track_nr, int num, int de
 							      writeKeySig(timedist, ((MidiEventStruct *) lptr2->data)->data1);
 							      newlasteventtime = ((MidiEventStruct *) lptr2->data)->midi_time;
 							      break;
-				case PSEUDO_EVENT_PGM_CHANGE: if (time_written) {
-									timedist = 0;
-								}
-								else {
-									timedist = MY2MIDITIME(((MidiEventStruct *) lptr2->data)->midi_time - lastEventTime);
-									time_written = TRUE;
-								}
-							      writePgmChange(timedist, ((MidiEventStruct *) lptr2->data)->channel, 
-										((MidiEventStruct *) lptr2->data)->data1);
-							      newlasteventtime = ((MidiEventStruct *) lptr2->data)->midi_time;
-							      break;
 			}
 		}
-		for (lptr2 = (GList *) g_list_first((GList *) (lptr1->data)); lptr2; lptr2 = g_list_next(lptr2)) {
+		for (lptr2 = g_list_first(((MidiListStruct *) lptr1->data)->notes); lptr2; lptr2 = g_list_next(lptr2)) {
 			if (((MidiEventStruct *) lptr2->data)->channel != channel) continue;
 			switch (((MidiEventStruct *) lptr2->data)->type) {
 				case SND_SEQ_EVENT_NOTEON: if (((MidiEventStruct *) lptr2->data)->note->getTieBackward() == NULL) {
@@ -416,7 +420,8 @@ void NedMidiExport::writeTrack(GList *midi_events, int track_nr, int num, int de
 									time_written = TRUE;
 								}
 							    	writeNoteOn(timedist, channel,
-							    		((MidiEventStruct *) lptr2->data)->data1, ((MidiEventStruct *) lptr2->data)->data2);
+							    		((MidiEventStruct *) lptr2->data)->data1, ((MidiEventStruct *) lptr2->data)->data2,
+									((MidiEventStruct *) lptr2->data)->pgm);
 							    	newlasteventtime = ((MidiEventStruct *) lptr2->data)->midi_time;
 							    }
 							    if (((MidiEventStruct *) lptr2->data)->note->isFirstNote()) {
