@@ -31,9 +31,10 @@ class NedIdiotsEditor;
 
 class NedMidiImporter : public NedImporter  {
 	public:
-		NedMidiImporter(bool with_triplets, int tempo_change_density, int volume_change_density, bool force_piano, bool sort_instruments, bool dont_split);
+		NedMidiImporter(bool with_triplets, int tempo_change_density, int volume_change_density, bool force_piano, bool sort_instruments, bool dont_split, bool use_id_ed);
 		virtual ~NedMidiImporter();
 		virtual bool import();
+		virtual bool convertToScore();
 		virtual const char *getErrorString() {return m_error_string;}
 	private:
 		void read_header(FILE *fp);
@@ -48,6 +49,7 @@ class NedMidiImporter : public NedImporter  {
 		bool m_with_triplets;
 		NedIdiotsEditor *m_idiots_editor;
 		int m_current_midi_instrument[16];
+		bool m_use_id_ed;
 };
 
 #endif /* MIDI_IMPORTER_H */
