@@ -864,7 +864,7 @@ void NedMusicXMLImport::internal_text(GMarkupParseContext *context,
 					sprintf(Str, _("Bad midi volume number: %s"), text);
 					im->produceSementicErrorString(Str);
 				      }
-				      if (tempo < 20 || vol > 300) {
+				      if (tempo < 20 || tempo > 300) {
 					sprintf(Str, _("Bad temo value: %d"), tempo);
 					im->produceSementicErrorString(Str);
 				      }
