@@ -73,7 +73,7 @@ class NedNote {
 		void computeBounds(int len, double *minx, double *miny, double *maxx, double *maxy);
 		void do_tie(NedNote *other_note);
 		void setTieSimple(NedNote *other_note);
-		void setTieIfSamePitch(NedNote *other_note);
+		void setTieIfSamePitch(NedNote *other_note, bool check_pitch);
 		void computeTie();
 		bool isTheSame(NedNote *other_note);
 		void tryTieBackward();
@@ -96,6 +96,7 @@ class NedNote {
 			 int octave_shift,  int pitch_offs, int voice_idx, unsigned int grace_time, bool is_grace, bool is_stacc, unsigned short segno_sign);
 		char m_active;
 		int getPitch(int clef, int keysig, int octave_shift, int pitch_offs, bool *flat, bool use_transpose);
+		int getPitch();
 		void removeUnneededAccidental(int clef, int keysig, int octave_shift);
 		int getNoteHead() {return m_head;}
 		void setNoteHead(int head) {m_head = head;}
