@@ -20,6 +20,7 @@
 /****************************************************************************************/
 
 #include <string.h>
+#include <math.h>
 #include <gdk/gdkkeysyms.h>
 #include "page.h"
 #include "system.h"
@@ -384,13 +385,6 @@ void NedPage::setAndUpdateClefTypeAndKeySig(int *clef_and_key_array, bool first)
 	}
 }
 
-void NedPage::determineVolume(unsigned int *vol, NedChordOrRest *element, int staff_nr) {
-	GList *lptr;
-	for (lptr = g_list_first(m_systems); lptr && *vol == 256; lptr = g_list_next(lptr)) {
-		((NedSystem *) lptr->data)->determineVolume(vol, element, staff_nr);
-	}
-}
-
 void NedPage::determineTempoInverse(NedChordOrRest *element, NedSystem* system, double *tempoinverse, bool *found) {
 	GList *lptr;
 	for (lptr = g_list_first(m_systems); lptr; lptr = g_list_next(lptr)) {
@@ -551,10 +545,10 @@ void NedPage::setInternalPitches() {
 	}
 }
 
-void NedPage::adjustAccidentals() {
+void NedPage::adjustAccidentals(int staff_nr) {
 	GList *lptr;
 	for (lptr = g_list_first(m_systems); lptr; lptr = g_list_next(lptr)) {
-		((NedSystem *) lptr->data)->adjustAccidentals();
+		((NedSystem *) lptr->data)->adjustAccidentals(staff_nr);
 	}
 }
 
@@ -598,10 +592,10 @@ bool NedPage::shiftNotes(unsigned long long start_time, int linedist, NedSystem
 	return true;
 }
 
-void NedPage::removeUnneededAccidentals() {
+void NedPage::removeUnneededAccidentals(int staff_nr /* = -1 */) {
 	GList *lptr;
 	for (lptr = g_list_first(m_systems); lptr; lptr = g_list_next(lptr)) {
-		((NedSystem *) lptr->data)->removeUnneededAccidentals();
+		((NedSystem *) lptr->data)->removeUnneededAccidentals(staff_nr);
 	}
 }
 
@@ -902,19 +896,27 @@ double NedPage::convertX(double xpos) {
 
 	return m_main_window->getCurrentScale() * X_POS_PAGE_REL(xpos);
 }
+
+bool NedPage::isXOnPage(double x) {
+	double zoom_factor = m_main_window->getCurrentZoomFactor();
+	double current_scale = m_main_window->getCurrentScale();
+	double leftx = m_main_window->getLeftX();
+	double xl = X_POS_INVERS(x);
+	if (xl < 0.0 || xl > m_width) return false;
+	return true;
+}
 	
 
 bool NedPage::tryInsertOrErease(double x, double y, int num_midi_input_notes, int *midi_input_chord /* given if insert from midikeyboard */, NedChordOrRest **newObj /*  = NULL */, bool force_rest /* = false */) {
 	double zoom_factor = m_main_window->getCurrentZoomFactor();
 	double current_scale = m_main_window->getCurrentScale();
 	double leftx = m_main_window->getLeftX();
-	NedChordOrRest *element, *element1, *element2;
+	NedChordOrRest *element;
 	NedChordName *chordname;
 	double dummy, dummy0;
-	double topy, xx, yy, yyy;
+	double topy, xx, yy;
 	double xx2, yy2;
 	unsigned int kind, tempo;
-	NedSlurPoint *sp[3];
 	NedCommandList *command_list;
 	NedLinePoint *lp0, *lp1, *lp2;
 	if (newObj != NULL) {
@@ -925,6 +927,8 @@ bool NedPage::tryInsertOrErease(double x, double y, int num_midi_input_notes, in
 
 
 #define LINE_START_X_DIST 2.0
+#define SLUR_START_X_DIST 1.0
+#define SLUR_START_Y_DIST ( 2 * LINE_DIST )
 
 	if (xl < 0.0 || xl > m_width) return FALSE;
 
@@ -1026,29 +1030,6 @@ bool NedPage::tryInsertOrErease(double x, double y, int num_midi_input_notes, in
 			m_main_window->getCommandHistory()->addCommandList(command_list);
 			m_main_window->resetSpecialType();
 			return TRUE;
-		case TYPE_SLUR:
-	#define SLUR_START_X_DIST 1.0
-	#define SLUR_START_Y_DIST ( 2 * LINE_DIST )
-			topy = m_main_window->getTopY();
-			xx = X_POS_INVERS_PAGE_REL(x);
-			if (xx > m_width / 2.0) xx -= (3 * SLUR_START_X_DIST) / zoom_factor;
-			yy = Y_POS_INVERS(y);
-			command_list = new NedCommandList(m_main_window);
-			element = findNearestElement(-1, xx, yy, NULL, &dummy);
-			yyy = element->getSystem()->getYPos() + element->getStaff()->getMidPos();
-			command_list->addCommand(new NedInsertFreePlaceableCommand(sp[0] = new NedSlurPoint(NULL, 0), element, xx, yyy));
-			dummy0 = 10000000.0;
-			element1 = element->getStaff()->findNearestElement(xx + SLUR_START_X_DIST, yyy - SLUR_START_Y_DIST, NULL, &dummy0, &dummy);
-			command_list->addCommand(new NedInsertFreePlaceableCommand(sp[1] = new NedSlurPoint(NULL, 1), element1, xx + SLUR_START_X_DIST, yyy - SLUR_START_Y_DIST));
-			dummy0 = 10000000.0;
-			element2 = element->getStaff()->findNearestElement(xx + 2 * SLUR_START_X_DIST, yyy - SLUR_START_Y_DIST / 2, NULL, &dummy0, &dummy);
-			command_list->addCommand(new NedInsertFreePlaceableCommand(sp[2] = new NedSlurPoint(NULL, 2), element2, xx + 2 * SLUR_START_X_DIST, yyy - SLUR_START_Y_DIST / 2));
-			command_list->execute();
-			new NedSlur(sp);
-			m_main_window->getCommandHistory()->addCommandList(command_list);
-			m_main_window->resetSpecialType();
-			m_main_window->m_selected_free_replaceable = sp[2];
-			return TRUE;
 		case TYPE_LINE:
 			topy = m_main_window->getTopY();
 			xx = X_POS_INVERS_PAGE_REL(x);
@@ -1115,6 +1096,100 @@ bool NedPage::tryInsertOrErease(double x, double y, int num_midi_input_notes, in
 	return false;
 }
 
+void NedPage::insertSlur(GdkRectangle *selection_rect) {
+	double zoom_factor = m_main_window->getCurrentZoomFactor();
+	double current_scale = m_main_window->getCurrentScale();
+	double leftx = m_main_window->getLeftX();
+	double topy, xx, yy, yyy;
+	double xx0, yy0, xx1, yy1, xx2, yy2;
+	double xdist, ydist, dist;
+	double dummy, dummy0;
+	int dir, l, mid;
+	NedSlurPoint *sp[3];
+	GList *lptr;
+	NedChordOrRest *element, *element0, *element1, *element2;
+	NedCommandList *command_list = new NedCommandList(m_main_window);
+
+	if (NedResource::m_main_clip_board == NULL) {
+		//printf("Paramater vom Rect\n"); fflush(stdout);
+		topy = m_main_window->getTopY();
+		xx = X_POS_INVERS_PAGE_REL(selection_rect->x);
+		if (xx > m_width / 2.0) xx -= (3 * SLUR_START_X_DIST) / zoom_factor;
+		yy = Y_POS_INVERS(selection_rect->y);
+		command_list = new NedCommandList(m_main_window);
+		element = findNearestElement(-1, xx, yy, NULL, &dummy);
+		yyy = element->getSystem()->getYPos() + element->getStaff()->getMidPos();
+		command_list->addCommand(new NedInsertFreePlaceableCommand(sp[0] = new NedSlurPoint(NULL, 0), element, xx, yyy));
+		dummy0 = 10000000.0;
+		element1 = element->getStaff()->findNearestElement(xx + SLUR_START_X_DIST, yyy - SLUR_START_Y_DIST, NULL, &dummy0, &dummy);
+		command_list->addCommand(new NedInsertFreePlaceableCommand(sp[1] = new NedSlurPoint(NULL, 1), element1, xx + SLUR_START_X_DIST, yyy - SLUR_START_Y_DIST));
+		dummy0 = 10000000.0;
+		element2 = element->getStaff()->findNearestElement(xx + 2 * SLUR_START_X_DIST, yyy - SLUR_START_Y_DIST / 2, NULL, &dummy0, &dummy);
+		command_list->addCommand(new NedInsertFreePlaceableCommand(sp[2] = new NedSlurPoint(NULL, 2), element2, xx + 2 * SLUR_START_X_DIST, yyy - SLUR_START_Y_DIST / 2));
+	}
+	else {
+		//printf("Paramater von Elementen\n"); fflush(stdout);
+		dir = 0;
+		l = g_list_length(NedResource::m_main_clip_board);
+		if (l < 2) {
+			NedResource::Abort("l > 2");
+		}
+		mid = l / 2;
+
+		lptr = g_list_last(NedResource::m_main_clip_board);
+		dir += ((NedChordOrRest *) lptr->data)->hasUpDir() ? 1 : -1;
+		element2 = (NedChordOrRest *) lptr->data;
+
+		lptr = g_list_first(NedResource::m_main_clip_board);
+		dir += ((NedChordOrRest *) lptr->data)->hasUpDir() ? 1 : -1;
+		element0 = (NedChordOrRest *) lptr->data;
+#define SLUR_X_DIST_PROLONG (LINE_DIST * 0.5)
+
+		xx2 = element2->getXPos() + element2->getBBox()->width_netto + element2->getBBox()->x + SLUR_X_DIST_PROLONG;
+		yy2 = element2->getStaff()->getTopPos() + element2->getSystem()->getYPos() +  element2->getStemBottom();
+
+		lptr = g_list_nth(NedResource::m_main_clip_board, mid);
+		dir += ((NedChordOrRest *) lptr->data)->hasUpDir() ? 1 : -1;
+		element1 = (NedChordOrRest *) lptr->data;
+/*
+		xx1 = element1->getXPos();
+		yy1 = element1->getStaff()->getTopPos() + element1->getSystem()->getYPos() +  element1->getStemBottom();
+*/
+
+		dir = (dir > 0.0) ? 1.0 : -1.0;
+#define SLUR_MIDDLE_DIST (LINE_DIST * 1.8)
+#define SLUR_Y_DIST_UP (LINE_DIST * 1.0)
+#define SLUR_Y_DIST_DOWN (LINE_DIST * 2.0)
+	
+		xx0 = element0->getXPos() + element2->getBBox()->x - SLUR_X_DIST_PROLONG;
+		yy0 = element0->getStaff()->getTopPos() + element0->getSystem()->getYPos() +  element0->getStemBottom();
+
+		yy2 += dir * ((dir > 0) ? SLUR_Y_DIST_DOWN : SLUR_Y_DIST_UP);
+		yy0 += dir * ((dir > 0) ? SLUR_Y_DIST_DOWN : SLUR_Y_DIST_UP);
+
+		command_list->addCommand(new NedInsertFreePlaceableCommand(sp[0] = new NedSlurPoint(NULL, 0), element2, xx2, yy2));
+		command_list->addCommand(new NedInsertFreePlaceableCommand(sp[2] = new NedSlurPoint(NULL, 0), element0, xx0, yy0));
+
+
+		xdist = xx2 - xx0;
+		ydist = yy2 - yy0;
+		xx1 = xx0 + xdist / 2.0;
+		yy1 = yy0 + ydist / 2.0;
+		dist = sqrt(xdist * xdist + ydist * ydist);
+		xdist /= dist;
+		ydist /= dist;
+		xx1 -= ydist * dir * SLUR_MIDDLE_DIST;
+		yy1 += xdist * dir * SLUR_MIDDLE_DIST;
+		command_list->addCommand(new NedInsertFreePlaceableCommand(sp[1] = new NedSlurPoint(NULL, 0), element1, xx1, yy1));
+		
+	}
+	
+	command_list->execute();
+	new NedSlur(sp);
+	m_main_window->getCommandHistory()->addCommandList(command_list);
+	m_main_window->resetSpecialType();
+	m_main_window->m_selected_free_replaceable = sp[2];
+}
 
 bool NedPage::findLine(double x, double y, double *ypos, int *line, double *bottom, NedStaff **staff) {
 	double zoom_factor = m_main_window->getCurrentZoomFactor();
