@@ -54,7 +54,7 @@
 #define HODDEN_HYPHEN_Y_OFFSET 0.3
 
 struct NedPangoCairoText::utf8_element NedPangoCairoText::utf8code_array[] = {
-{"_", {    0,    0,  0xc2,   0xa0}},     //		NO-BREAK SPACE                     
+{".", {    0,    0,  0xc2,   0xa0}},     //		NO-BREAK SPACE                     
 {NULL,  {    0,    0,  0xc2,   0xa1}},	//		INVERTED EXCLAMATION MARK	¡
 {NULL,  {    0,    0,  0xc2,   0xa2}},	//		CENT SIGN	¢
 {NULL,  {    0,    0,  0xc2,   0xa3}},	//		POUND SIGN	£
@@ -558,6 +558,7 @@ void NedPangoCairoText::computeCursorPosition() {
 	}
 }
 
+
 char *NedPangoCairoText::inspect_text(const char *text) {
 	char Str[1024];
 	char *cptr, *cptr2, *cptr3, *cptr4;
@@ -677,6 +678,47 @@ void NedPangoCairoText::handle_spec_utf8_chars(char *cptr, char *cptr2) {
 		}
 	}
 }
+
+void NedPangoCairoText::convert_bslash_text_to_utf8_text(const char *in_text, char *out_text) {
+	char Str[1024];
+	char *cptr, *cptr2;
+
+	strcpy(Str, in_text);
+	cptr = Str;
+	while (*cptr != '\0') {
+		if (*cptr == '\\') {
+			cptr2 = g_utf8_next_char(cptr);
+			if (*cptr2 != '\0') {
+				handle_spec_utf8_chars(cptr, cptr2);
+			}
+			else {
+				cptr = g_utf8_next_char(cptr);
+			}
+		}
+		else {
+			cptr = g_utf8_next_char(cptr);
+		}
+	}
+	strcpy(out_text, Str);
+}
+
+void NedPangoCairoText::makeLilyString(char *in_string, char *buffer) {
+	char *cori, *ori, buf1[1024];
+
+	buffer[0] = '"';
+	//strcpy(buf1, in_string);
+	convert_bslash_text_to_utf8_text(in_string, buf1);
+	ori = buf1;
+	cori = buffer + 1;
+	while (*ori != '\0') {
+		if (*ori == '"' || *ori == '\\') {
+			*cori++ = '\\';
+		}
+		*cori++ = *ori++;
+	}
+	*cori++ = '"';
+	*cori = '\0';
+}
 				
 			
 NedPangoCairoText::specLetter::specLetter(const char *let, int ix, double xo, double yo) :
