@@ -52,6 +52,8 @@ class NedPangoCairoText {
 		void drawCursor(cairo_t *cr, double xpos, double ypos, double zoom_factor);
 		static double getInternalFactor();
 		static void handle_spec_utf8_chars(char *cptr, char *cptr2);
+		static void convert_bslash_text_to_utf8_text(const char *in_text, char *out_text); 
+		static void makeLilyString(char *n_string, char *buffer);
 	private:
 		void createLayout(cairo_t *cr, double zoom, double scale);
 		void computeCursorPosition();
