@@ -29,7 +29,7 @@
 
 
 NedPosition::NedPosition(NedChordOrRest *element, int offs, unsigned int staff_count) : m_valid(true),
-	m_has_notes(false), m_has_only_staff_members(true), m_has_only_graces(true), m_max_microshift(0.0), m_step_width(0.0), m_min_duration(8* WHOLE_NOTE), m_midi_time(element->getMidiTime()),
+	m_has_notes(false), m_has_unhidden_elements(false), m_has_only_staff_members(true), m_has_only_graces(true), m_max_microshift(0.0), m_step_width(0.0), m_min_duration(8* WHOLE_NOTE), m_midi_time(element->getMidiTime()),
 	m_min_width_after(0.0), m_min_width_before(0.0), m_acc_dist(0.0), m_needed_width(0.0), m_min_needed_width(0.0), m_staff_count(staff_count) {
 	m_voice_members.setLen(VOICE_COUNT * staff_count, true);
 	m_staff_members.setLen(staff_count, true);
@@ -38,7 +38,7 @@ NedPosition::NedPosition(NedChordOrRest *element, int offs, unsigned int staff_c
 		return; // TODO: this shouldn't happen (???)
 		NedResource::Abort("TYPE_KEYSIG(1)");
 	}
-	if ((element->getType() & (TYPE_NOTE | TYPE_REST)) != 0) {
+	if ((element->getType() & (TYPE_CHORD | TYPE_REST)) != 0) {
 		m_voice_members.insert(offs, element);
 		m_has_only_staff_members = false;
 		m_has_only_graces = false;
@@ -61,6 +61,17 @@ void NedPosition::setNewStaffCount(unsigned int newstaffcount) {
 	m_staff_count = newstaffcount;
 }
 
+bool NedPosition::hasOtherStaffElements(int type) {
+	NedChordOrRest **ptr;
+
+	for (ptr = m_staff_members.getFirst(); ptr; ptr = m_staff_members.getNext()) {
+		if ((*ptr) == NULL) continue;
+		if ((*ptr)->getType() != type) return true;
+	}
+
+	return false;
+}
+
 void NedPosition::insertElement(NedChordOrRest *element, int offs) {
 	unsigned char c;
 	m_midi_time = element->getMidiTime();
@@ -70,8 +81,8 @@ void NedPosition::insertElement(NedChordOrRest *element, int offs) {
 		NedResource::Abort("TYPE_KEYSIG(2)");
 	}
 
-	if (element->getType() == TYPE_NOTE) {
-		m_has_notes = true;
+	if (element->getType() == TYPE_CHORD) {
+		m_has_unhidden_elements = m_has_notes = true;
 		m_has_only_graces = false;
 		m_element_has_arpeggio = m_element_has_arpeggio || ((element->getStatus() & STAT_ARPEGGIO) != 0);
 		if (element->getDuration() < m_min_duration) {
@@ -79,9 +90,12 @@ void NedPosition::insertElement(NedChordOrRest *element, int offs) {
 		}
 	}
 	else if (element->getType() == TYPE_REST) {
+		if (!element->isHidden() || (element->getStatus() & STAT_USER_HIDDEN_REST) == 0) {
+			m_has_unhidden_elements = true;
+		}
 		m_has_only_graces = false;
 	}
-	if (element->getType() != TYPE_REST || !element->isHidden()) {
+	if (element->getType() != TYPE_REST || (!element->isHidden() && (element->getStatus() & STAT_USER_HIDDEN_REST) == 0)) {
 		if (element->getBBox()->width > m_min_needed_width) {
 			m_min_needed_width = element->getBBox()->width;
 		}
@@ -93,7 +107,7 @@ void NedPosition::insertElement(NedChordOrRest *element, int offs) {
 		}
 	}
 	m_voice_members.insert(offs, element);
-	if (element->isRest() && element->isHidden()) return;
+	if (element->isRest() && (element->isHidden() || (element->getStatus() & STAT_USER_HIDDEN_REST))) return;
 	c = m_count_of_elements_per_staff.getAt(offs / VOICE_COUNT);
 	m_count_of_elements_per_staff.insert(offs / VOICE_COUNT, c + 1);
 }
@@ -107,6 +121,7 @@ bool NedPosition::insertStaffElement(NedChordOrRest *element, int staff_offs) {
 	*/
 	m_has_only_graces = false;
 	m_midi_time = element->getMidiTime();
+	m_has_unhidden_elements =
 	m_valid = true;
 
 	if (element->getBBox()->width > m_min_needed_width) {
@@ -114,7 +129,9 @@ bool NedPosition::insertStaffElement(NedChordOrRest *element, int staff_offs) {
 	}
 	if (element->getBBox()->width + element->getBBox()->x > m_min_width_after) {
 		m_min_width_after = element->getBBox()->width + element->getBBox()->x;
+
 	}
+
 	if (-element->getBBox()->x > m_min_width_before) {
 		m_min_width_before = -element->getBBox()->x;
 	}
@@ -132,7 +149,7 @@ bool NedPosition::isUsed(int offs) {
 
 
 void NedPosition::empty() {
-	m_has_notes = m_valid = false;
+	m_has_unhidden_elements = m_has_notes = m_valid = false;
 	m_has_only_graces = m_has_only_staff_members = true;
 	m_max_microshift = m_min_needed_width = m_needed_width = m_min_width_after = m_min_width_before = 0.0;
 	m_min_duration = 8 * WHOLE_NOTE;
@@ -225,15 +242,15 @@ void NedPosition::computeMicroShifts(int mnum, int pos, bool out) {
 	for (p_staff = m_voice_members.getFirst(); p_staff; p_staff = m_voice_members.skip(VOICE_COUNT)) {
 		for (p_voice1 = m_voice_members.getFirst2(VOICE_COUNT); p_voice1; p_voice1 = m_voice_members.getNext2()) {
 			if (*p_voice1 == NULL) continue;
-			if ((*p_voice1)->getType() != TYPE_NOTE) continue;
+			if ((*p_voice1)->getType() != TYPE_CHORD) continue;
 			(*p_voice1)->resetMicroshift();
 		}
 		for (p_voice1 = m_voice_members.getFirst2(VOICE_COUNT); p_voice1; p_voice1 = m_voice_members.getNext2()) {
 			if (*p_voice1 == NULL) continue;
-			if ((*p_voice1)->getType() != TYPE_NOTE) continue;
+			if ((*p_voice1)->getType() != TYPE_CHORD) continue;
 			for (p_voice2 = m_voice_members.getFirst3(); p_voice2; p_voice2 = m_voice_members.getNext3()) {
 				if (*p_voice2 == NULL) continue;
-				if ((*p_voice2)->getType() != TYPE_NOTE) continue;
+				if ((*p_voice2)->getType() != TYPE_CHORD) continue;
 				/*
 				if (out) {
 					printf("mnum = %d, voi1 = %d, voi2 = %d\n", mnum, (*p_voice1)->getVoice()->getVoiceNumber(), (*p_voice2)->getVoice()->getVoiceNumber()); fflush(stdout);
@@ -297,12 +314,12 @@ void NedPosition::placeRests(struct voice_properties *vprops) {
 		pterm2 = st_ptr + VOICE_COUNT;
 		for (i = 0, ptr1 = st_ptr; ptr1 < pterm1; ptr1++, i++) {
 			if (*ptr1 == NULL) continue;
-			if ((*ptr1)->isRest() && ((*ptr1)->isHidden() || ((*ptr1)->getStatus() & STAT_USER_PLACED_REST))) continue;
+			if ((*ptr1)->isRest() && ((*ptr1)->isHidden() || ((*ptr1)->getStatus() & (STAT_USER_PLACED_REST | STAT_USER_HIDDEN_REST)))) continue;
 			for (j = i+1, ptr2 = ptr1 + 1; ptr2 < pterm2; ptr2++, j++) {
 				if (*ptr2 == NULL) continue;
 				if (!(*ptr2)->isRest()) continue;
 				if ((*ptr2)->isHidden()) continue;
-				if ((*ptr2)->getStatus() & STAT_USER_PLACED_REST) continue;
+				if ((*ptr2)->getStatus() & (STAT_USER_PLACED_REST | STAT_USER_HIDDEN_REST)) continue;
 				shift = (*ptr1)->compute_y_shift(*ptr2, vprops[st * VOICE_COUNT + j].m_stem_decision);
 				if (shift > 0.0) {
 					if (vprops[st * VOICE_COUNT + j].m_stem_decision == STEM_DIR_DOWN) {
@@ -316,13 +333,13 @@ void NedPosition::placeRests(struct voice_properties *vprops) {
 		}
 		for (i = VOICE_COUNT - 1, ptr1 = st_ptr + VOICE_COUNT - 1; ptr1 > st_ptr; ptr1--, i--) {
 			if (*ptr1 == NULL) continue;
-			if ((*ptr1)->isRest() && ((*ptr1)->isHidden() || ((*ptr1)->getStatus() & STAT_USER_PLACED_REST))) continue;
+			if ((*ptr1)->isRest() && ((*ptr1)->isHidden() || ((*ptr1)->getStatus() & (STAT_USER_PLACED_REST | STAT_USER_HIDDEN_REST)))) continue;
 			pterm2 = notes_available[st] ? st_ptr : st_ptr + 1;
 			for (j = i - 1, ptr2 = ptr1 - 1; ptr2 >= st_ptr; ptr2--, j--) {
 				if (*ptr2 == NULL) continue;
 				if (!(*ptr2)->isRest()) continue;
 				if ((*ptr2)->isHidden()) continue;
-				if ((*ptr2)->getStatus() & STAT_USER_PLACED_REST) continue;
+				if ((*ptr2)->getStatus() & (STAT_USER_PLACED_REST | STAT_USER_HIDDEN_REST)) continue;
 				shift = (*ptr1)->compute_y_shift(*ptr2, vprops[st * VOICE_COUNT + j].m_stem_decision);
 				if (shift > 0.0) {
 					if (vprops[st * VOICE_COUNT + j].m_stem_decision == STEM_DIR_DOWN) {
@@ -345,7 +362,7 @@ bool NedPosition::print() {
 
 	printf("-----------------------\n");
 	for (i = 0; i < m_voice_members->len; i++) {
-		//if (((NedChordOrRest *) m_members->pdata[i])->getType() != TYPE_NOTE) continue;
+		//if (((NedChordOrRest *) m_members->pdata[i])->getType() != TYPE_CHORD) continue;
 		if (((NedChordOrRest *) m_voice_members->pdata[i])->getVoice()->getVoiceNumber() != 0) continue;
 		b = true;
 		printf("\t%s: TIME: %llu dur: %u pos = %f\n", ((NedChordOrRest *) m_voice_members->pdata[i])->isRest() ? "Rest" : "Note", 
@@ -391,11 +408,14 @@ void NedPositionArray::insertElement(NedChordOrRest *element, int offs, int mnum
 	struct voice_properties *np_ptr;
 
 	np_ptr = m_voice_properties.getPointerAt(offs);
-	if (element->getType() & TYPE_NOTE) {
+	if (element->getType() & TYPE_CHORD) {
 		np_ptr->m_note_count++;
 		np_ptr->m_line_sum += element->getLineOfLowestNote();
 	}
-	if ((element->getType() & TYPE_REST) && !element->isHidden()) {
+	if ((element->getType() & TYPE_REST) && !element->isHidden() && (element->getStatus() & STAT_USER_HIDDEN_REST) == 0) {
+		if (np_ptr == NULL) {
+			printf("(element->getType() = 0x%x\n", element->getType()); fflush(stdout);
+		}
 		np_ptr->m_rests_count++;
 	}
 
@@ -405,7 +425,7 @@ void NedPositionArray::insertElement(NedChordOrRest *element, int offs, int mnum
 		if ((*ptr)->m_has_only_graces) continue;
 		if ((*ptr)->m_midi_time == element->getMidiTime()) {
 			(*ptr)->insertElement(element, offs);
-			if (element->getType() == TYPE_NOTE && (*ptr)->m_min_duration < m_min_duration) {
+			if (element->getType() == TYPE_CHORD && (*ptr)->m_min_duration < m_min_duration) {
 				m_min_duration = (*ptr)->m_min_duration;
 			}
 			//m_positions.sort((gint (*)(const void*, const void*)) compare_positions);
@@ -415,7 +435,7 @@ void NedPositionArray::insertElement(NedChordOrRest *element, int offs, int mnum
 	for (ptr = m_positions.getFirst(); ptr; ptr = m_positions.getNext()) {
 		if (!(*ptr)->m_valid) {
 			(*ptr)->insertElement(element, offs);
-			if (element->getType() == TYPE_NOTE && (*ptr)->m_min_duration < m_min_duration) {
+			if (element->getType() == TYPE_CHORD && (*ptr)->m_min_duration < m_min_duration) {
 				m_min_duration = (*ptr)->m_min_duration;
 			}
 			//m_positions.sort((gint (*)(const void*, const void*)) compare_positions);
@@ -425,7 +445,7 @@ void NedPositionArray::insertElement(NedChordOrRest *element, int offs, int mnum
 
 	pos_ptr = new NedPosition(element, offs, m_staff_count);
 	m_positions.append(pos_ptr);
-	if (element->getType() == TYPE_NOTE && element->getDuration() < m_min_duration) {
+	if (element->getType() == TYPE_CHORD && element->getDuration() < m_min_duration) {
 		m_min_duration = element->getDuration();
 	}
 	//m_positions.sort((gint (*)(const void*, const void*)) compare_positions);
@@ -435,11 +455,14 @@ void NedPositionArray::insertElement(NedChordOrRest *element, int offs, int mnum
 void NedPositionArray::insertStaffElement(NedChordOrRest *element, int staff_offs, int mnum) {
 	NedPosition *pos_ptr;
 	NedPosition **ptr;
+	int type = element->getType();
+
 
 	for (ptr = m_positions.getFirst(); ptr; ptr = m_positions.getNext()) {
 		if (!(*ptr)->m_valid) continue;
 		if ((*ptr)->m_has_only_graces) continue;
 		if (!(*ptr)->m_has_only_staff_members) continue;
+		if ((*ptr)->hasOtherStaffElements(type)) continue;
 		if ((*ptr)->m_midi_time == element->getMidiTime()) {
 			if (!(*ptr)->insertStaffElement(element, staff_offs)) break;
 			//m_positions.sort((gint (*)(const void*, const void*)) compare_positions);
@@ -471,12 +494,14 @@ void NedPositionArray::insertGraceElement(NedChordOrRest *element, int offs, int
 		if ((*ptr)->m_midi_time == element->getMidiTime()) {
 			if ((*ptr)->isUsed(offs)) break;
 			(*ptr)->insertElement(element, offs);
+			(*ptr)->m_has_unhidden_elements = true;
 			//m_positions.sort((gint (*)(const void*, const void*)) compare_positions);
 			return;
 		}
 	}
 	for (ptr = m_positions.getFirst(); ptr; ptr = m_positions.getNext()) {
 		if (!(*ptr)->m_valid) {
+			(*ptr)->m_has_unhidden_elements = true;
 			(*ptr)->insertElement(element, offs);
 			//m_positions.sort((gint (*)(const void*, const void*)) compare_positions);
 			return;
@@ -542,7 +567,7 @@ struct v_params_str{
 	double av;
 };
 
-double NedPositionArray::computeAndSetPositions(double start_position, int *num_elements, double *extra_space_for_accidentals, int mnum, double spread_fac, bool out) {
+double NedPositionArray::computeAndSetPositions(double start_position, int *num_elements, double *extra_space_for_accidentals, bool *measure_has_only_staff_members /* means keysig */, double timesig_space, int mnum, double spread_fac, bool out) {
 	NedPosition **p_first_valid = NULL, **p_last_valid, **p_next_valid;
 	struct voice_properties *p_vp;
 	struct v_params_str vparams[VOICE_COUNT];
@@ -654,7 +679,7 @@ double NedPositionArray::computeAndSetPositions(double start_position, int *num_
 		}
 		p_next_valid = m_positions.getNext();
 	}
-	if (num_distances == 0 && p_first_valid != NULL && (*p_first_valid) != NULL) {
+	if (num_distances == 0 && p_first_valid != NULL && (*p_first_valid) != NULL && /* staff members i.e. keysigs have teir own values */ !(*p_first_valid)->m_has_only_staff_members ) {
 		(*p_first_valid)->m_needed_width = 2 * WHOLE_EXTRA_SPACE;
 		(*p_first_valid)->m_min_needed_width = 2 * WHOLE_EXTRA_SPACE;
 		(*p_first_valid)->m_min_width_after = WHOLE_EXTRA_SPACE;
@@ -666,6 +691,7 @@ double NedPositionArray::computeAndSetPositions(double start_position, int *num_
 		if (m_min_durations_dist > MAX_MINDURATIONS_DIST) m_min_durations_dist = MAX_MINDURATIONS_DIST;
 	}
 	last_width_after = last_micro_shifts = 0.0;
+	bool last_round_had_a_grace = false;
 	int pos = 0;
 	for (i = 0, p_next_valid = m_positions.getFirst(); p_next_valid; p_next_valid = m_positions.getNext()) {
 		if (!(*p_next_valid)->m_valid) continue;
@@ -674,19 +700,55 @@ double NedPositionArray::computeAndSetPositions(double start_position, int *num_
 		min_step_width = last_width_after + last_micro_shifts + (*p_next_valid)->m_min_width_before;
 		if (p_next_valid != NULL) {
 			if ((*p_next_valid)->m_has_notes) {
-				step_width = 1.2 * HEAD_THICK + (double) ((*p_next_valid)->m_min_duration) / (double) (m_min_duration) * 0.4 * HEAD_THICK;
+				*measure_has_only_staff_members = false;
+				if (i == 0) {
+					step_width = 0.0; // avoid additional gap behind bar line
+				}
+				timesig_space = 0.0; // add only if staff element is at first place
+				step_width = 1.4 * HEAD_THICK + (double) ((*p_next_valid)->m_min_duration) / (double) (m_min_duration) * 0.2 * HEAD_THICK;
+				if (step_width < min_step_width) step_width = min_step_width;
+				if (last_round_had_a_grace) {
+					step_width = 1.5 * HEAD_THICK;
+					last_round_had_a_grace = false;
+				}
+			}
+			else if ((*p_next_valid)->m_has_only_staff_members) {
+				if (i == 0) {
+					step_width = 0.0; // avoid additional gap behind bar line
+				}
+				else  {
+					step_width = min_step_width;
+					timesig_space = 0.0; // add only if staff element is at first place
+				}
+				last_round_had_a_grace = false;
+
+			}
+			else if ((*p_next_valid)->m_has_only_graces) {
+				step_width = 0.9 * HEAD_THICK; // rest
+				timesig_space = 0.0; // add only if staff element is at first place
+				*measure_has_only_staff_members = false;
+				last_round_had_a_grace = true;
 			}
 			else {
-				step_width = 1.2 * HEAD_THICK; // rest
+				step_width = 1.4 * HEAD_THICK; // rest
+				timesig_space = 0.0; // add only if staff element is at first place
+				*measure_has_only_staff_members = false;
+				if (step_width < min_step_width) step_width = min_step_width;
+				last_round_had_a_grace = false;
 			}
-			if (step_width < min_step_width) step_width = min_step_width;
 		}
 		else {
 			step_width = min_step_width;
+			*measure_has_only_staff_members = false;
+			timesig_space = 0.0; // add only if staff element is at first place
+			last_round_had_a_grace = false;
 		}
 		step_width *= spread_fac;
-		start_position += step_width;
+		if ((*p_next_valid)->m_has_unhidden_elements) {
+			start_position += step_width;
+		}
 		(*p_next_valid)->placeAt(start_position, num_voices, m_voice_properties.getArray(), mnum, out);
+		start_position += timesig_space; // If bar has a timesig then additional space is needed after an eventuall staff element (keysig)
 
 		/*
 #define EXTRA_DIST 0.01
@@ -694,7 +756,7 @@ double NedPositionArray::computeAndSetPositions(double start_position, int *num_
 		if (out) {
 			printf("mnum = %d, pos = %d, need = %f, step = %f\n",
 				mnum, i, (*p_last_valid)->m_min_needed_width, step_width);
-			fflush(stdout);
+			fflush(stderr);
 		}
 		*/
 		(*p_next_valid)->m_step_width = step_width - last_micro_shifts;
@@ -704,10 +766,13 @@ double NedPositionArray::computeAndSetPositions(double start_position, int *num_
 		/*
 		if (out) {
 			printf("mnum = %d, pos = %d, m_acc_dist = %f\n",
-				mnum, i, (*p_last_valid)->m_acc_dist); fflush(stdout);
+				mnum, i, (*p_last_valid)->m_acc_dist); fflush(stderr);
 		}
 		*/
 		//(*extra_space_for_accidentals) += (*p_last_valid)->m_acc_dist;
+		if ((*p_next_valid)->m_has_only_graces) {
+			last_round_had_a_grace = true;
+		}
 		last_width_after = (*p_next_valid)->m_min_width_after;
 		last_micro_shifts = (*p_next_valid)->m_max_microshift;
 		i++;
