@@ -126,6 +126,9 @@
 #define AUX_LINE_OVER (0.435 * LINE_DIST)
 #define AUX_LINE_THICK (0.087 * LINE_DIST)
 
+#define MAX_LINE 30
+#define MIN_LINE -MAX_LINE
+
 #define TIE_X_START (0.456 * LINE_DIST)
 #define TIE_X_START_LARGE (0.6 * LINE_DIST)
 #define MIN_TIE_LEN 1.2
