@@ -281,9 +281,14 @@ void NedStaff::checkForElementsToSplit(NedCommandList *command_list) {
 }
 
 void NedStaff::findSelectedStaffs(double yp, NedBbox *sel_rect, int *number_of_first_selected_staff, int *number_of_last_selected_staff) {
-	 if (m_ypos + 4 * LINE_DIST < yp || yp + sel_rect->height < m_ypos) return;
+
+	if (m_ypos < yp || m_ypos + 4 * LINE_DIST > yp + sel_rect->height) return;
 	if (*number_of_first_selected_staff < 0) {
 		*number_of_first_selected_staff = *number_of_last_selected_staff = m_staff_number;
+/*
+		printf("num = %d, sys_m_ypos = %f m_ypos = %f, m_ypos - 4 * LINE_DIST = %f, sys_m_ypos + m_ypos = %f yp = %f, yp + 4 * LINE_DIST = %f\n",
+			m_staff_number, m_system->getYPos(),m_ypos, m_ypos - 4 * LINE_DIST, m_system->getYPos() + m_ypos,  yp, yp + 4 * LINE_DIST); fflush(stdout);
+*/
 		return;
 	}
 	*number_of_last_selected_staff = m_staff_number;
@@ -1009,14 +1014,6 @@ void NedStaff::getCurrentClefAndKeysig(unsigned long long miditime, int *clef, i
 }
 
 
-void NedStaff::prepareMutedReplay() {
-	int i;
-
-	for (i = 0; i < VOICE_COUNT; i++) {
-		m_voices[i]->prepareMutedReplay();
-	}
-}
-
 void NedStaff::resetActiveFlags() {
 	int i;
 
@@ -1030,7 +1027,12 @@ void NedStaff::prepareReplay(bool with_keysig) {
 	GList *lptr;
 
 	for (i = 0; i < VOICE_COUNT; i++) {
-		m_voices[i]->prepareReplay(getMainWindow()->m_staff_contexts[m_staff_number].m_different_voices ? i : 0);
+		if (getMainWindow()->m_staff_contexts[m_staff_number].m_muted[i]) {
+			m_voices[i]->prepareMutedReplay();
+		}
+		else {
+			m_voices[i]->prepareReplay(getMainWindow()->m_staff_contexts[m_staff_number].m_different_voices ? i : 0);
+		}
 	}
 
 	if (with_keysig) {
