@@ -235,10 +235,12 @@ void NedSystem::draw(cairo_t *cr, bool first_page, bool show_measure_numbers, bo
 #else
 	cairo_set_line_width(cr, zoom_factor * MEASURE_LINE_THICK);
 #endif
-	cairo_move_to(cr, X_POS_PAGE_REL(indent),
-		 Y_POS(m_ypos + firststaff->getTopPos() - LINE_THICK / 2.0));
-	cairo_line_to(cr,  X_POS_PAGE_REL(indent),
-		 Y_POS(m_ypos + laststaff->getBottomPos() + LINE_THICK / 2.0));
+	if (g_list_length(m_staffs) > 1) {
+		cairo_move_to(cr, X_POS_PAGE_REL(indent),
+		 	Y_POS(m_ypos + firststaff->getTopPos() - LINE_THICK / 2.0));
+		cairo_line_to(cr,  X_POS_PAGE_REL(indent),
+		 	Y_POS(m_ypos + laststaff->getBottomPos() + LINE_THICK / 2.0));
+	}
 #ifdef BADLINEPOLICY
 	if (!m_special_measure_at_end) { // i.e there is a key signature at the end
 			cairo_move_to(cr, X_POS_PAGE_REL(m_width),
@@ -1149,7 +1151,12 @@ void NedSystem::findSelectedSystems(NedBbox *sel_rect, int *number_of_first_sele
 		*number_of_last_selected_staff = g_list_length(m_staffs) - 1;
 	}
 	else {
-		double yp = sel_rect->y - (firststaff->getTopPos() + m_ypos);
+		double yp = sel_rect->y - m_ypos;
+/*
+		if (m_page->getPageNumber() == 0) {
+			printf("yp = %f, m_ypos = %f, m_ypos + 4 * LINE_DIST = %f\n", yp, m_ypos, m_ypos + 4 * LINE_DIST); fflush(stdout);
+		}
+*/
 		for (lptr = g_list_first(m_staffs); lptr; lptr = g_list_next(lptr)) {
 			((NedStaff *) lptr->data)->findSelectedStaffs(yp, sel_rect, number_of_first_selected_staff, number_of_last_selected_staff);
 		}
@@ -1565,12 +1572,7 @@ void NedSystem::prepareReplay(bool with_keysig) {
 	GList *lptr;
 
 	for (lptr = g_list_first(m_staffs); lptr; lptr = g_list_next(lptr)) {
-		if (getMainWindow()->m_staff_contexts[((NedStaff *) lptr->data)->getStaffNumber()].m_muted){
-			((NedStaff *) lptr->data)->prepareMutedReplay();
-		}
-		else {
-			((NedStaff *) lptr->data)->prepareReplay(with_keysig);
-		}
+		((NedStaff *) lptr->data)->prepareReplay(with_keysig);
 	}
 }
 
