@@ -66,10 +66,10 @@ class NedSystem {
 		void transpose(int pitchdist, bool *staff_list, GList *selected_group);
 		void hideRests(NedCommandList *command_list, bool unhide, int staff_nr, int voice_nr);
 		bool shiftNotes(unsigned long long start_time, int linedist, int staff_number);
-		void adjustAccidentals();
+		void adjustAccidentals(int staff_nr);
 		void changeAccidentals(NedCommandList *command_list, int preferred_offs, bool *staff_list, GList *selected_group);
 		void testBeams(char *s);
-		void removeUnneededAccidentals();
+		void removeUnneededAccidentals(int staff_nr);
 		bool trySelect (double x, double y, bool only_free_placeables);
 		NedChordOrRest *findNearestElement(int staff_nr, double x, double y, NedStaff *oldstaff, double *mindist, double *ydist);
 		NedChordOrRest *getFirstObjectInNextSystem(int staff_nr);
@@ -145,7 +145,6 @@ class NedSystem {
 		GList *getFirstChordOrRest(int staff_nr, int voice_nr, int lyrics_line, bool lyrics_required, bool note_required);
 		GList *getLastChordOrRest(int staff_nr, int voice_nr, int lyrics_line, bool lyrics_required, bool note_required);
 		NedStaff *getStaff(int nr);
-		void determineVolume(unsigned int *vol, NedChordOrRest *element, int staff_nr);
 		void determineTempoInverse(NedChordOrRest *element, unsigned long long till, double *tempoinverse, bool *found);
 		void detectVoices(int staff_nr, unsigned int *voice_mask, NedSystem **last_system, unsigned long long *end_time);
 		void exportLilyPond(FILE *fp, int staff_nr, int voice_nr, int *last_line, unsigned int *midi_len,
