@@ -38,12 +38,14 @@ class NedTempoSign : public NedFreeReplaceable {
 		void setTempo(unsigned int kind, unsigned int tempo);
 		virtual void startContextDialog(GtkWidget *ref);
 		double getTempoInverse();
+		bool getDot() {return m_dot;}
 	private: 
 		void computeGlypths();
 		unsigned int m_kind;
 		unsigned int m_tempo;
 		cairo_glyph_t m_glyphs[3];
 		int m_number_len;
+		bool m_dot;
 
 };
 
